(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["oxygen-icons-react"] = {}, global.React));
})(this, (function (exports, React) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

  /**
   * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com). All Rights Reserved.
   *
   * WSO2 LLC. licenses this file to you under the Apache License,
   * Version 2.0 (the "License"); you may not use this file except
   * in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing,
   * software distributed under the License is distributed on an
   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   * KIND, either express or implied. See the License for the
   * specific language governing permissions and limitations
   * under the License.
   */
  var sizeMap = {
    large: 64,
    medium: 32,
    small: 16
  };

  /**
   * Calculates the closes height from a list of provided heights.
   *
   * @param naturalHeights - Set of natural heights.
   * @param height - Height to check.
   * @returns Closest natural height.
   */
  var getClosestNaturalHeight = function getClosestNaturalHeight(naturalHeights, height) {
    return naturalHeights.reduce(function (acc, naturalHeight) {
      return naturalHeight <= height ? naturalHeight : acc;
    }, naturalHeights[0]);
  };

  /**
   * Creates a React component from a `SVG`.
   *
   * @param name - Name for the Component.
   * @param defaultClassName - Default CSS class name.
   * @param getSVGData - Function to get the SVG data.
   * @returns A React component created from an SVG.
   */
  var createIconComponent = function createIconComponent(name, defaultClassName, getSVGData) {
    var svgDataByHeight = getSVGData();
    var heights = Object.keys(svgDataByHeight).map(function (height) {
      return parseInt(height, 10);
    });
    var Icon = function Icon(_ref) {
      var ariaLabel = _ref['aria-label'],
        tabIndex = _ref.tabIndex,
        _ref$className = _ref.className,
        className = _ref$className === void 0 ? defaultClassName : _ref$className,
        _ref$fill = _ref.fill,
        fill = _ref$fill === void 0 ? 'currentColor' : _ref$fill,
        _ref$size = _ref.size,
        size = _ref$size === void 0 ? 16 : _ref$size,
        _ref$verticalAlign = _ref.verticalAlign,
        verticalAlign = _ref$verticalAlign === void 0 ? 'text-bottom' : _ref$verticalAlign;
      var height = sizeMap[size] || size;
      var naturalHeight = getClosestNaturalHeight(heights, height);
      var naturalWidth = svgDataByHeight[naturalHeight].width;
      var width = height * (naturalWidth / naturalHeight);
      var path = svgDataByHeight[naturalHeight].path;
      return /*#__PURE__*/React__default["default"].createElement("svg", {
        "aria-hidden": ariaLabel ? 'false' : 'true',
        tabIndex: tabIndex,
        focusable: tabIndex !== undefined && tabIndex >= 0 ? 'true' : 'false',
        "aria-label": ariaLabel,
        role: "img",
        className: className,
        viewBox: "0 0 ".concat(naturalWidth, " ").concat(naturalHeight),
        width: width,
        height: height,
        fill: fill,
        style: {
          display: 'inline-block',
          overflow: 'visible',
          userSelect: 'none',
          verticalAlign: verticalAlign
        }
      }, path);
    };
    Icon.displayName = name;
    return Icon;
  };

  /* THIS FILE IS GENERATED. DO NOT EDIT IT. */
  var AppleIcon = /*#__PURE__*/createIconComponent("AppleIcon", "oxygen-icon oxygen-icon-apple", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M14.0539 12.4689C13.8145 13.0279 13.5311 13.5424 13.2028 14.0155C12.7553 14.6604 12.3889 15.1068 12.1066 15.3547C11.6688 15.7616 11.1998 15.97 10.6976 15.9818C10.337 15.9818 9.90224 15.8781 9.39611 15.6678C8.88832 15.4584 8.42166 15.3547 7.99497 15.3547C7.54746 15.3547 7.06752 15.4584 6.55416 15.6678C6.04001 15.8781 5.62582 15.9878 5.30915 15.9986C4.82754 16.0194 4.3475 15.8051 3.86834 15.3547C3.56251 15.0851 3.17998 14.6229 2.72173 13.9681C2.23006 13.2688 1.82583 12.458 1.50916 11.5336C1.17001 10.5351 1 9.5682 1 8.63213C1 7.55987 1.22922 6.63506 1.68836 5.86007C2.0492 5.23757 2.52924 4.74652 3.13005 4.38604C3.73086 4.02556 4.38004 3.84186 5.07914 3.83011C5.46167 3.83011 5.96331 3.94971 6.58669 4.18476C7.20832 4.42061 7.60746 4.54021 7.78245 4.54021C7.91328 4.54021 8.35669 4.40036 9.10836 4.12156C9.81919 3.863 10.4191 3.75594 10.9106 3.79811C12.2424 3.90675 13.2429 4.4374 13.9083 5.39342C12.7172 6.12288 12.128 7.14458 12.1398 8.45525C12.1505 9.47616 12.5169 10.3257 13.237 11.0003C13.5634 11.3133 13.9278 11.5553 14.3333 11.7272C14.2454 11.9849 14.1526 12.2318 14.0539 12.4689ZM10.9995 0.320091C10.9995 1.12027 10.7103 1.8674 10.1338 2.55894C9.43813 3.38104 8.59666 3.85608 7.68416 3.78112C7.67253 3.68512 7.66579 3.58409 7.66579 3.47792C7.66579 2.70975 7.99663 1.88765 8.58415 1.21547C8.87747 0.875136 9.25053 0.592152 9.70292 0.36641C10.1543 0.144037 10.5813 0.0210593 10.9829 0C10.9946 0.106972 10.9995 0.213951 10.9995 0.320081V0.320091Z",
          fill: ""
        })
      }
    };
  });
  var ArrowDownIcon = /*#__PURE__*/createIconComponent("ArrowDownIcon", "oxygen-icon oxygen-icon-arrow-down", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.5 1C8.5 0.723858 8.27614 0.5 8 0.5C7.72386 0.5 7.5 0.723858 7.5 1V13.7929L3.85355 10.1464C3.65829 9.95118 3.34171 9.95118 3.14645 10.1464C2.95118 10.3417 2.95118 10.6583 3.14645 10.8536L7.64645 15.3536L8 15.7071L8.35355 15.3536L12.8536 10.8536C13.0488 10.6583 13.0488 10.3417 12.8536 10.1464C12.6583 9.95118 12.3417 9.95118 12.1464 10.1464L8.5 13.7929V1Z",
          fill: ""
        })
      }
    };
  });
  var ArrowLeftIcon = /*#__PURE__*/createIconComponent("ArrowLeftIcon", "oxygen-icon oxygen-icon-arrow-left", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.85363 3.85355C6.04889 3.65829 6.04889 3.34171 5.85363 3.14645C5.65837 2.95118 5.34178 2.95118 5.14652 3.14645L0.646522 7.64645L0.292969 8L0.646522 8.35355L5.14652 12.8536C5.34178 13.0488 5.65837 13.0488 5.85363 12.8536C6.04889 12.6583 6.04889 12.3417 5.85363 12.1464L2.20718 8.5H15.0001C15.2762 8.5 15.5001 8.27614 15.5001 8C15.5001 7.72386 15.2762 7.5 15.0001 7.5H2.20718L5.85363 3.85355Z",
          fill: ""
        })
      }
    };
  });
  var ArrowLeftArrowRightIcon = /*#__PURE__*/createIconComponent("ArrowLeftArrowRightIcon", "oxygen-icon oxygen-icon-arrow-left-arrow-right", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M4.06066 2.35355C4.25592 2.15829 4.25592 1.84171 4.06066 1.64645C3.8654 1.45118 3.54882 1.45118 3.35355 1.64645L0 5L3.35355 8.35355C3.54882 8.54882 3.8654 8.54882 4.06066 8.35355C4.25592 8.15829 4.25592 7.84171 4.06066 7.64645L1.91421 5.5H10.2071C10.4832 5.5 10.7071 5.27614 10.7071 5C10.7071 4.72386 10.4832 4.5 10.2071 4.5H1.91421L4.06066 2.35355ZM11.9393 13.6464C11.7441 13.8417 11.7441 14.1583 11.9393 14.3536C12.1346 14.5488 12.4512 14.5488 12.6464 14.3536L16 11L12.6464 7.64645C12.4512 7.45118 12.1346 7.45118 11.9393 7.64645C11.7441 7.84171 11.7441 8.15829 11.9393 8.35355L14.0858 10.5L5.79289 10.5C5.51675 10.5 5.29289 10.7239 5.29289 11C5.29289 11.2761 5.51675 11.5 5.79289 11.5L14.0858 11.5L11.9393 13.6464Z",
          fill: ""
        })
      }
    };
  });
  var ArrowLoopRightUserIcon = /*#__PURE__*/createIconComponent("ArrowLoopRightUserIcon", "oxygen-icon oxygen-icon-arrow-loop-right-user", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.0481 5C8.66741 5 7.54812 3.88071 7.54812 2.5C7.54812 1.11929 8.66741 0 10.0481 0C11.4288 0 12.5481 1.11929 12.5481 2.5C12.5481 3.88071 11.4288 5 10.0481 5ZM10.0481 4C9.21969 4 8.54812 3.32843 8.54812 2.5C8.54812 1.67157 9.21969 1 10.0481 1C10.8765 1 11.5481 1.67157 11.5481 2.5C11.5481 3.32843 10.8765 4 10.0481 4Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M15.9895 11.5381C15.5796 8.25514 13.0914 6 10.0487 6C9.77255 6 9.54869 6.22386 9.54869 6.5C9.54869 6.77614 9.77255 7 10.0487 7C12.5476 7 14.6447 8.83933 14.9973 11.662C15.0165 11.8159 14.8886 12 14.6469 12L11.0022 11.9998C10.7261 11.9998 10.5022 12.2236 10.5022 12.4997C10.5022 12.7759 10.7261 12.9998 11.0022 12.9998L14.6468 13C15.4017 13 16.0938 12.3731 15.9895 11.5381Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.35355 6.64645C6.15829 6.45118 5.84171 6.45118 5.64645 6.64645C5.45118 6.84171 5.45118 7.15829 5.64645 7.35355L7.79289 9.5H3.25C1.45507 9.5 0 10.9551 0 12.75C0 14.5449 1.45507 16 3.25 16H4.5C4.77614 16 5 15.7761 5 15.5C5 15.2239 4.77614 15 4.5 15H3.25C2.00736 15 1 13.9926 1 12.75C1 11.5074 2.00736 10.5 3.25 10.5H7.79289L5.64645 12.6464C5.45118 12.8417 5.45118 13.1583 5.64645 13.3536C5.84171 13.5488 6.15829 13.5488 6.35355 13.3536L9.70711 10L6.35355 6.64645Z",
          fill: ""
        }))
      }
    };
  });
  var ArrowRightIcon = /*#__PURE__*/createIconComponent("ArrowRightIcon", "oxygen-icon oxygen-icon-arrow-right", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.8536 3.14645C10.6583 2.95118 10.3417 2.95118 10.1464 3.14645C9.95118 3.34171 9.95118 3.65829 10.1464 3.85355L13.7929 7.5H1C0.723858 7.5 0.5 7.72386 0.5 8C0.5 8.27614 0.723858 8.5 1 8.5H13.7929L10.1464 12.1464C9.95118 12.3417 9.95118 12.6583 10.1464 12.8536C10.3417 13.0488 10.6583 13.0488 10.8536 12.8536L15.3536 8.35355L15.7071 8L15.3536 7.64645L10.8536 3.14645Z",
          fill: ""
        })
      }
    };
  });
  var ArrowRightFromBracketIcon = /*#__PURE__*/createIconComponent("ArrowRightFromBracketIcon", "oxygen-icon oxygen-icon-arrow-right-from-bracket", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M16 8.5L13.6464 6.14645C13.4512 5.95118 13.1346 5.95118 12.9393 6.14645C12.7441 6.34171 12.7441 6.65829 12.9393 6.85355L14.0858 8H7.29289C7.01675 8 6.79289 8.22386 6.79289 8.5C6.79289 8.77614 7.01675 9 7.29289 9H14.0858L12.9393 10.1464C12.7441 10.3417 12.7441 10.6583 12.9393 10.8536C13.1346 11.0488 13.4512 11.0488 13.6464 10.8536L16 8.5ZM2.5 2C1.67157 2 1 2.67157 1 3.5V13.5C1 14.3284 1.67157 15 2.5 15H11C11.8284 15 12.5 14.3284 12.5 13.5C12.5 13.2239 12.7239 13 13 13C13.2761 13 13.5 13.2239 13.5 13.5C13.5 14.8807 12.3807 16 11 16H2.5C1.11929 16 0 14.8807 0 13.5V3.5C0 2.11929 1.11929 1 2.5 1H11C12.3807 1 13.5 2.11929 13.5 3.5C13.5 3.77614 13.2761 4 13 4C12.7239 4 12.5 3.77614 12.5 3.5C12.5 2.67157 11.8284 2 11 2H2.5Z",
          fill: ""
        })
      }
    };
  });
  var ArrowRightToBracketIcon = /*#__PURE__*/createIconComponent("ArrowRightToBracketIcon", "oxygen-icon oxygen-icon-arrow-right-to-bracket", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M15 3.5C15 2.67157 14.3284 2 13.5 2H5C4.17157 2 3.5 2.67157 3.5 3.5C3.5 3.77614 3.27614 4 3 4C2.72386 4 2.5 3.77614 2.5 3.5C2.5 2.11929 3.61929 1 5 1H13.5C14.8807 1 16 2.11929 16 3.5V13.5C16 14.8807 14.8807 16 13.5 16H5C3.61929 16 2.5 14.8807 2.5 13.5C2.5 13.2239 2.72386 13 3 13C3.27614 13 3.5 13.2239 3.5 13.5C3.5 14.3284 4.17157 15 5 15H13.5C14.3284 15 15 14.3284 15 13.5V3.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.85355 5.97978C6.65829 5.78452 6.34171 5.78452 6.14645 5.97978C5.95118 6.17504 5.95118 6.49162 6.14645 6.68689L7.29289 7.83333H0.5C0.223857 7.83333 0 8.05719 0 8.33333C0 8.60948 0.223857 8.83333 0.5 8.83333H7.29289L6.14645 9.97978C5.95118 10.175 5.95118 10.4916 6.14645 10.6869C6.34171 10.8821 6.65829 10.8821 6.85355 10.6869L9.20711 8.33333L6.85355 5.97978Z",
          fill: ""
        }))
      }
    };
  });
  var ArrowRightToBracketPencilIcon = /*#__PURE__*/createIconComponent("ArrowRightToBracketPencilIcon", "oxygen-icon oxygen-icon-arrow-right-to-bracket-pencil", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M4.5 1C2.567 1 1 2.567 1 4.5V4.75C1 5.02614 1.22386 5.25 1.5 5.25C1.77614 5.25 2 5.02614 2 4.75V4.5C2 3.11929 3.11929 2 4.5 2H11.5C12.8807 2 14 3.11929 14 4.5V5C14 5.27614 14.2239 5.5 14.5 5.5C14.7761 5.5 15 5.27614 15 5V4.5C15 2.567 13.433 1 11.5 1H4.5ZM6.35355 4.64645C6.15829 4.45118 5.84171 4.45118 5.64645 4.64645C5.45118 4.84171 5.45118 5.15829 5.64645 5.35355L7.79289 7.5H1.5C1.22386 7.5 1 7.72386 1 8C1 8.27614 1.22386 8.5 1.5 8.5H7.79289L5.64645 10.6464C5.45118 10.8417 5.45118 11.1583 5.64645 11.3536C5.84171 11.5488 6.15829 11.5488 6.35355 11.3536L9.35355 8.35355L9.70711 8L9.35355 7.64645L6.35355 4.64645ZM2 11.25C2 10.9739 1.77614 10.75 1.5 10.75C1.22386 10.75 1 10.9739 1 11.25V11.5C1 13.433 2.567 15 4.5 15H5C5.27614 15 5.5 14.7761 5.5 14.5C5.5 14.2239 5.27614 14 5 14H4.5C3.11929 14 2 12.8807 2 11.5V11.25ZM14.2846 8.56002C14.0894 8.36476 13.7728 8.36476 13.5775 8.56002L13.1543 8.98326L14.4258 10.2548L14.8491 9.83157C15.0443 9.63631 15.0443 9.31972 14.8491 9.12446L14.2846 8.56002ZM7.64156 13.0818L12.0874 8.63596L12.0936 8.62965L12.0999 8.62345L12.8704 7.85291C13.4562 7.26713 14.406 7.26713 14.9917 7.85291L15.5562 8.41735C16.142 9.00314 16.142 9.95289 15.5562 10.5387L10.3273 15.7675L10.1809 15.914H9.97377H7.99512H7.49512V15.414V13.4353V13.2282L7.64156 13.0818ZM13.7187 10.9619L12.4472 9.69036L8.49512 13.6424V14.914H9.76666L13.7187 10.9619Z",
          fill: ""
        })
      }
    };
  });
  var ArrowUpIcon = /*#__PURE__*/createIconComponent("ArrowUpIcon", "oxygen-icon oxygen-icon-arrow-up", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.35355 0.646522L8 0.292969L7.64645 0.646522L3.14645 5.14652C2.95118 5.34178 2.95118 5.65837 3.14645 5.85363C3.34171 6.04889 3.65829 6.04889 3.85355 5.85363L7.5 2.20718V15.0001C7.5 15.2762 7.72386 15.5001 8 15.5001C8.27614 15.5001 8.5 15.2762 8.5 15.0001V2.20718L12.1464 5.85363C12.3417 6.04889 12.6583 6.04889 12.8536 5.85363C13.0488 5.65837 13.0488 5.34178 12.8536 5.14652L8.35355 0.646522Z",
          fill: ""
        })
      }
    };
  });
  var ArrowUpRightFromSquareIcon = /*#__PURE__*/createIconComponent("ArrowUpRightFromSquareIcon", "oxygen-icon oxygen-icon-arrow-up-right-from-square", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6.09375 0C6.35263 0 6.5625 0.209867 6.5625 0.46875C6.5625 0.698869 6.39668 0.890258 6.17801 0.929948L6.09375 0.9375H3.28125C2.03861 0.9375 1.02184 1.90456 0.942485 3.12715L0.9375 3.28125V12.7188C0.9375 13.9614 1.90456 14.9782 3.12715 15.0575L3.28125 15.0625H12.7188C13.9614 15.0625 14.9782 14.0954 15.0575 12.8729L15.0625 12.7188V9.90625C15.0625 9.64737 15.2724 9.4375 15.5312 9.4375C15.7614 9.4375 15.9528 9.60332 15.9924 9.82199L16 9.90625V12.7188C16 14.4705 14.6272 15.9017 12.8988 15.9951L12.7188 16H3.28125C1.52947 16 0.098319 14.6272 0.00485518 12.8988L0 12.7188V3.28125C0 1.52947 1.37276 0.098319 3.10122 0.00485518L3.28125 0H6.09375ZM16 0.500474V4.5C16 4.77614 15.7761 5 15.5 5C15.2545 5 15.0504 4.82312 15.0081 4.58988L15 4.5V1.70711L8.35355 8.35355C8.15829 8.54882 7.84171 8.54882 7.64645 8.35355C7.47288 8.17999 7.4536 7.91056 7.58859 7.71569L7.64645 7.64645L14.2929 1H11.5C11.2545 1 11.0504 0.823125 11.0081 0.589876L11 0.5C11 0.25454 11.1769 0.0503916 11.4101 0.00805569L11.5 0H15.4999H16V0.500474Z",
          fill: ""
        })
      }
    };
  });
  var BanIcon = /*#__PURE__*/createIconComponent("BanIcon", "oxygen-icon oxygen-icon-ban", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8 0C3.582 0 0 3.5815 0 8C0 12.4185 3.5815 16 8 16C12.4185 16 16 12.4185 16 8C16 3.5815 12.4185 0 8 0ZM1 8C1 6.246 1.65 4.6415 2.7205 3.4115L12.593 13.284C11.363 14.36 9.7565 15.0155 8 15.0155C4.14 15.0155 1 11.8595 1 7.9995V8ZM13.297 12.575L3.428 2.706C4.656 1.6445 6.2535 1 7.9995 1C11.8595 1 14.9995 4.14 14.9995 8C14.9995 9.7445 14.3565 11.3445 13.2965 12.5745L13.297 12.575Z",
          fill: ""
        })
      }
    };
  });
  var BarsIcon = /*#__PURE__*/createIconComponent("BarsIcon", "oxygen-icon oxygen-icon-bars", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2.44444C2 2.19899 2.19899 2 2.44444 2H13.5556C13.801 2 14 2.19899 14 2.44444V2.55556C14 2.80101 13.801 3 13.5556 3H2.44444C2.19899 3 2 2.80101 2 2.55556V2.44444ZM2 7.94444C2 7.69899 2.19899 7.5 2.44444 7.5H13.5556C13.801 7.5 14 7.69899 14 7.94444V8.05556C14 8.30101 13.801 8.5 13.5556 8.5H2.44444C2.19899 8.5 2 8.30101 2 8.05556V7.94444ZM2.44444 13C2.19899 13 2 13.199 2 13.4444V13.5556C2 13.801 2.19899 14 2.44444 14H8.01709C8.26255 14 8.46154 13.801 8.46154 13.5556V13.4444C8.46154 13.199 8.26255 13 8.01709 13H2.44444Z",
          fill: ""
        })
      }
    };
  });
  var BoltIcon = /*#__PURE__*/createIconComponent("BoltIcon", "oxygen-icon oxygen-icon-bolt", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.75005 7.25223L12.456 7.2523L7.25105 13.3053L7.25194 9.74367H3.41205L8.75005 2.90338V7.25223ZM9.75005 6.25576L14.6303 6.25611L6.25261 16L6.25205 10.7402H1.36938L9.75005 0V6.25576Z",
          fill: ""
        })
      }
    };
  });
  var BriefcaseIcon = /*#__PURE__*/createIconComponent("BriefcaseIcon", "oxygen-icon oxygen-icon-briefcase", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11.3333 3.3V3.95H14.6667C15.403 3.95 16 4.53203 16 5.25V13.7C16 14.418 15.403 15 14.6667 15H1.33333C0.596953 15 0 14.418 0 13.7V5.25C0 4.53203 0.596954 3.95 1.33333 3.95H4.66667V3.3C4.66667 2.58203 5.26362 2 6 2H10C10.7364 2 11.3333 2.58203 11.3333 3.3ZM6 2.975H10C10.1841 2.975 10.3333 3.12051 10.3333 3.3V3.95H5.66667V3.3C5.66667 3.12051 5.81591 2.975 6 2.975ZM15 5.25V8.5C15 8.67949 14.8508 8.825 14.6667 8.825H9.66667V8.63C9.66667 8.01972 9.15926 7.525 8.53333 7.525H7.46667C6.84074 7.525 6.33333 8.01973 6.33333 8.63V8.825H1.33333C1.14924 8.825 1 8.67949 1 8.5V5.25C1 5.07051 1.14924 4.925 1.33333 4.925H14.6667C14.8508 4.925 15 5.07051 15 5.25ZM6.34109 9.8H1.33333C1.21823 9.8 1.10654 9.78578 1 9.75904V13.7C1 13.8795 1.14924 14.025 1.33333 14.025H14.6667C14.8508 14.025 15 13.8795 15 13.7V9.75904C14.8935 9.78578 14.7818 9.8 14.6667 9.8H9.65891C9.59292 10.349 9.11415 10.775 8.53333 10.775H7.46667C6.88585 10.775 6.40708 10.349 6.34109 9.8ZM7.33333 8.63C7.33333 8.5582 7.39303 8.5 7.46667 8.5H8.53333C8.60697 8.5 8.66667 8.5582 8.66667 8.63V9.67C8.66667 9.7418 8.60697 9.8 8.53333 9.8H7.46667C7.39303 9.8 7.33333 9.7418 7.33333 9.67V8.63Z",
          fill: ""
        })
      }
    };
  });
  var BriefcaseBuildingIcon = /*#__PURE__*/createIconComponent("BriefcaseBuildingIcon", "oxygen-icon oxygen-icon-briefcase-building", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M1.33333 1H6.66667C6.85076 1 7 1.14924 7 1.33333V5.78473C7.24432 5.50792 7.60177 5.33333 8 5.33333V1.33333C8 0.596954 7.40305 0 6.66667 0H1.33333C0.596954 0 0 0.596953 0 1.33333V16H4.67177C4.31369 15.795 4.05982 15.4286 4.00925 15H1V1.33333C1 1.14924 1.14924 1 1.33333 1Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.66667 7V8H6C5.26362 8 4.66667 8.59695 4.66667 9.33333V14.6667C4.66667 15.403 5.26362 16 6 16H14.6667C15.403 16 16 15.403 16 14.6667V9.33333C16 8.59695 15.403 8 14.6667 8H13V7C13 6.26362 12.403 5.66667 11.6667 5.66667H9C8.26362 5.66667 7.66667 6.26362 7.66667 7ZM11.6667 6.66667H9C8.81591 6.66667 8.66667 6.81591 8.66667 7V8H12V7C12 6.81591 11.8508 6.66667 11.6667 6.66667ZM14.6667 9C14.8508 9 15 9.14924 15 9.33333V11.3333C15 11.5174 14.8508 11.6667 14.6667 11.6667H6C5.81591 11.6667 5.66667 11.5174 5.66667 11.3333V9.33333C5.66667 9.14924 5.81591 9 6 9H14.6667ZM15 12.6247V14.6667C15 14.8508 14.8508 15 14.6667 15H6C5.81591 15 5.66667 14.8508 5.66667 14.6667V12.6247C5.77321 12.6521 5.8849 12.6667 6 12.6667H14.6667C14.7818 12.6667 14.8935 12.6521 15 12.6247Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6 3.16667H2V2.16667H6V3.16667Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2 5.83333H6V4.83333H2V5.83333Z",
          fill: ""
        }))
      }
    };
  });
  var BuildingIcon = /*#__PURE__*/createIconComponent("BuildingIcon", "oxygen-icon oxygen-icon-building", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2H5.5V5H2L2 2ZM2 6H5.5V9.5H2V6ZM2 10.5V14H5.5V10.5H2ZM6.5 10.5V14H10V10.5H6.5ZM10 9.5V6H6.5V9.5H10ZM10 4.5V5H6.5V2H10V4.38197C10 4.4215 10.0012 4.46086 10.0035 4.5H10ZM11 6.11403V14H14V7.61803L11.1056 6.17082C11.0697 6.15287 11.0345 6.13393 11 6.11403ZM11 15H10H2C1.44772 15 1 14.5523 1 14V2C1 1.44772 1.44772 1 2 1H10C10.5523 1 11 1.44772 11 2V4.38197C11 4.76074 11.214 5.107 11.5528 5.27639L14.4472 6.72361C14.786 6.893 15 7.23926 15 7.61803V14C15 14.5523 14.5523 15 14 15H11Z",
          fill: ""
        })
      }
    };
  });
  var BuildingAltIcon = /*#__PURE__*/createIconComponent("BuildingAltIcon", "oxygen-icon oxygen-icon-building-alt", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M5.35265 2.6665C5.06027 2.6665 4.82324 2.89035 4.82324 3.1665C4.82324 3.44264 5.06027 3.6665 5.35265 3.6665H10.6468C10.9391 3.6665 11.1762 3.44264 11.1762 3.1665C11.1762 2.89035 10.9391 2.6665 10.6468 2.6665H5.35265Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M5.35265 5.6665C5.06027 5.6665 4.82324 5.89035 4.82324 6.1665C4.82324 6.44264 5.06027 6.6665 5.35265 6.6665H10.6468C10.9391 6.6665 11.1762 6.44264 11.1762 6.1665C11.1762 5.89035 10.9391 5.6665 10.6468 5.6665H5.35265Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M14 16V1.33333C14 0.596954 13.3679 0 12.5882 0H3.41176C2.63207 0 2 0.596953 2 1.33333V16H14ZM12.5882 1H3.41176C3.21684 1 3.05882 1.14924 3.05882 1.33333V15H4.82353V10C4.82353 9.26362 5.4556 8.66667 6.23529 8.66667H9.76471C10.5444 8.66667 11.1765 9.26362 11.1765 10V15H12.9412V1.33333C12.9412 1.14924 12.7832 1 12.5882 1ZM10.1176 15V10C10.1176 9.81591 9.95963 9.66667 9.76471 9.66667H6.23529C6.04037 9.66667 5.88235 9.81591 5.88235 10V15H10.1176Z",
          fill: ""
        }))
      }
    };
  });
  var BuildingAsteriskIcon = /*#__PURE__*/createIconComponent("BuildingAsteriskIcon", "oxygen-icon oxygen-icon-building-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M1.5 2C1.22386 2 1 2.22386 1 2.5V5H5V2H1.5ZM1 9.5V6H5V9.5H1ZM1 10.5V13.5C1 13.7761 1.22386 14 1.5 14H2.5C2.77614 14 3 14.2239 3 14.5C3 14.7761 2.77614 15 2.5 15H1.5C0.671573 15 0 14.3284 0 13.5V2.5C0 1.67157 0.671573 1 1.5 1H5.5H9.5C10.3284 1 11 1.67157 11 2.5V9C11 9.27614 10.7761 9.5 10.5 9.5C10.2239 9.5 10 9.27614 10 9V6H6V10C6 10.2761 5.77614 10.5 5.5 10.5H1ZM10 5H6V2H9.5C9.77614 2 10 2.22386 10 2.5V5ZM14.1272 11.3369C14.0821 10.8877 13.4179 10.8877 13.3728 11.3369L13.2426 12.6336L12.0386 12.0964C11.6215 11.9103 11.2895 12.4774 11.6615 12.7405L12.7353 13.5L11.6615 14.2595C11.2895 14.5226 11.6215 15.0897 12.0386 14.9036L13.2426 14.3664L13.3728 15.6631C13.4179 16.1123 14.0821 16.1123 14.1272 15.6631L14.2574 14.3664L15.4614 14.9036C15.8785 15.0897 16.2105 14.5226 15.8385 14.2595L14.7647 13.5L15.8385 12.7405C16.2105 12.4774 15.8785 11.9103 15.4614 12.0964L14.2574 12.6336L14.1272 11.3369ZM7.87282 11.3369C7.91792 10.8877 8.58208 10.8877 8.62718 11.3369L8.75736 12.6336L9.96137 12.0964C10.3785 11.9103 10.7105 12.4774 10.3385 12.7405L9.26472 13.5L10.3385 14.2595C10.7105 14.5226 10.3785 15.0897 9.96137 14.9036L8.75736 14.3664L8.62718 15.6631C8.58208 16.1123 7.91792 16.1123 7.87282 15.6631L7.74264 14.3664L6.53863 14.9036C6.12154 15.0897 5.78945 14.5226 6.16145 14.2595L7.23528 13.5L6.16145 12.7405C5.78945 12.4774 6.12154 11.9103 6.53863 12.0964L7.74264 12.6336L7.87282 11.3369Z",
          fill: ""
        })
      }
    };
  });
  var BuildingCheckIcon = /*#__PURE__*/createIconComponent("BuildingCheckIcon", "oxygen-icon oxygen-icon-building-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2.5C2 2.22386 2.22386 2 2.5 2H6V5H2V2.5ZM2 6V9.5H6V6H2ZM2 13.5V10.5H6.5C6.77614 10.5 7 10.2761 7 10V6H11V8C11 8.27614 11.2239 8.5 11.5 8.5C11.7761 8.5 12 8.27614 12 8V2.5C12 1.67157 11.3284 1 10.5 1H6.5H2.5C1.67157 1 1 1.67157 1 2.5V13.5C1 14.3284 1.67157 15 2.5 15H5.5C5.77614 15 6 14.7761 6 14.5C6 14.2239 5.77614 14 5.5 14H2.5C2.22386 14 2 13.7761 2 13.5ZM7 5H11V2.5C11 2.22386 10.7761 2 10.5 2H7V5ZM10.8536 15.3536L15.8536 10.3536C16.0488 10.1583 16.0488 9.84171 15.8536 9.64645C15.6583 9.45118 15.3417 9.45118 15.1464 9.64645L10.5 14.2929L7.85355 11.6464C7.65829 11.4512 7.34171 11.4512 7.14645 11.6464C6.95118 11.8417 6.95118 12.1583 7.14645 12.3536L10.1464 15.3536L10.5 15.7071L10.8536 15.3536Z",
          fill: ""
        })
      }
    };
  });
  var BuildingCircleCheckIcon = /*#__PURE__*/createIconComponent("BuildingCircleCheckIcon", "oxygen-icon oxygen-icon-building-circle-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.33333 1H7.66667C7.85076 1 8 1.14924 8 1.33333V10C8.24431 9.72319 8.60177 9 9 9V1.33333C9 0.596954 8.40305 0 7.66667 0H2.33333C1.59695 0 1 0.596953 1 1.33333V16H8.5C8.14191 15.795 7.55057 15.4286 7.5 15H2V1.33333C2 1.14924 2.14924 1 2.33333 1Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M7 3.16667H3V2.16667H7V3.16667Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M3 5.83333H7V4.83333H3V5.83333Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M11.5 9C9.5701 9 8 10.5701 8 12.5C8 14.4299 9.5701 16 11.5 16C13.4299 16 15 14.4299 15 12.5C15 10.5701 13.4299 9 11.5 9ZM11.5 15C10.0654 15.0397 9.05822 13.9778 9 12.5C9.07828 10.9988 10.0414 10.0464 11.5 10C12.9506 10.0117 13.9001 10.9687 14 12.5C13.9487 13.9381 12.9883 14.9588 11.5 15Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.1854 11.5669C12.1837 11.569 12.182 11.5713 12.1805 11.5737L11.3256 12.9359L10.8105 12.2913C10.7755 12.2505 10.7292 12.2283 10.6814 12.2294C10.6335 12.2304 10.5879 12.2547 10.5541 12.297C10.5202 12.3393 10.5009 12.3963 10.5 12.4561C10.4992 12.516 10.5169 12.5739 10.5495 12.6176L11.2008 13.4325C11.2184 13.4544 11.2393 13.4717 11.2623 13.4833C11.2853 13.4949 11.3099 13.5005 11.3347 13.5C11.3595 13.4994 11.3839 13.4926 11.4065 13.4799C11.4292 13.4673 11.4496 13.4491 11.4664 13.4264L12.449 11.8902C12.4825 11.8462 12.5008 11.7876 12.5 11.727C12.4991 11.6663 12.4793 11.6085 12.4446 11.566C12.41 11.5235 12.3634 11.4998 12.3149 11.5C12.2664 11.5002 12.2199 11.5242 12.1854 11.5669Z",
          fill: "",
          stroke: "black",
          strokeWidth: "0.6"
        }))
      }
    };
  });
  var BuildingGearIcon = /*#__PURE__*/createIconComponent("BuildingGearIcon", "oxygen-icon oxygen-icon-building-gear", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2.5C2 2.22386 2.22386 2 2.5 2H6V5H2V2.5ZM2 6V9.5H5.5C5.77614 9.5 6 9.72386 6 10C6 10.2761 5.77614 10.5 5.5 10.5H2V13.5C2 13.7761 2.22386 14 2.5 14H6C6.27614 14 6.5 14.2239 6.5 14.5C6.5 14.7761 6.27614 15 6 15H2.5C1.67157 15 1 14.3284 1 13.5V2.5C1 1.67157 1.67157 1 2.5 1H6.5H10.5C11.3284 1 12 1.67157 12 2.5V5C12 5.27614 11.7761 5.5 11.5 5.5C11.2239 5.5 11 5.27614 11 5V2.5C11 2.22386 10.7761 2 10.5 2H7V5.5C7 5.77614 6.77614 6 6.5 6H2ZM12.5532 7.67V7.91723L12.6346 7.94155C12.8349 8.00535 13.029 8.08594 13.2151 8.18232L13.2881 8.22208L13.4634 8.04721C13.6889 7.82166 14.0386 7.78862 14.3118 7.96719L14.3621 8.00315L14.4112 8.04721L14.9528 8.58883C15.1924 8.82847 15.2148 9.20825 14.9968 9.48759L14.9529 9.53657L14.7775 9.71149L14.8177 9.78493C14.9141 9.97102 14.9947 10.1651 15.0584 10.3654L15.0824 10.4464L15.3298 10.4468C15.6519 10.4468 15.9245 10.6751 15.988 10.9979L15.9969 11.0558L16 11.117V11.883C16 12.2241 15.744 12.5096 15.391 12.5501L15.3298 12.5532L15.0824 12.5528L15.0585 12.6343C14.9947 12.8347 14.9141 13.0288 14.8177 13.215L14.7775 13.2877L14.9528 13.4634C15.1991 13.7097 15.2136 14.1001 14.9963 14.3634L14.9528 14.4112L14.4112 14.9528C14.1494 15.2145 13.7251 15.2145 13.4634 14.9529L13.2877 14.7775L13.215 14.8177C13.0288 14.9141 12.8347 14.9947 12.6343 15.0585L12.5528 15.0824L12.5532 15.3298C12.5532 15.6814 12.2824 15.9698 11.9379 15.9978L11.883 16H11.117C10.7469 16 10.4468 15.6999 10.4468 15.33L10.4464 15.0824L10.3654 15.0584C10.1651 14.9947 9.97102 14.9141 9.78493 14.8177L9.71149 14.7775L9.53665 14.9528C9.29031 15.1991 8.89992 15.2136 8.63664 14.9963L8.58883 14.9528L8.04721 14.4112C7.78548 14.1494 7.78548 13.7251 8.04713 13.4634L8.22208 13.2877L8.18227 13.215C8.08586 13.0288 8.00526 12.8347 7.94145 12.6343L7.91723 12.5528L7.67021 12.5532C7.31857 12.5532 7.03018 12.2824 7.00222 11.9379L7 11.883V11.117C7 10.7469 7.30006 10.4468 7.67 10.4468L7.91723 10.4464L7.94155 10.3654C8.00535 10.1651 8.08594 9.97102 8.18232 9.78493L8.22208 9.71149L8.04721 9.53665C7.82166 9.3111 7.78862 8.96142 7.96719 8.68818L8.00315 8.63789L8.04721 8.58883L8.58883 8.04721C8.82847 7.80757 9.20825 7.78525 9.48759 8.00315L9.53657 8.04713L9.71187 8.22208L9.78502 8.18227C9.97118 8.08586 10.1653 8.00526 10.3657 7.94145L10.4468 7.91723V7.67021C10.4468 7.34805 10.6751 7.07547 10.9979 7.01204L11.0558 7.00305L11.117 7H11.883C12.2241 7 12.5096 7.25598 12.5501 7.60901L12.5532 7.67ZM11.735 8.52685L12.393 8.72326C12.5441 8.77183 12.6908 8.83271 12.8318 8.90523L13.4336 9.23279L13.9372 8.73028L14.2695 9.06261L13.7653 9.56557L14.0951 10.1688C14.1673 10.3092 14.2279 10.4554 14.2764 10.6059L14.4706 11.2637L15.1818 11.2648V11.7348L14.4694 11.7337L14.2761 12.3948C14.2279 12.5445 14.1676 12.6899 14.0959 12.8296L13.764 13.4304L14.2697 13.9372L13.9372 14.2697L13.4304 13.764L12.8296 14.0959C12.6899 14.1676 12.5445 14.2279 12.3948 14.2761L11.7337 14.4694L11.7348 15.1818H11.2648L11.2637 14.4706L10.6059 14.2764C10.4554 14.2279 10.3092 14.1673 10.1688 14.0951L9.56557 13.7653L9.06261 14.2695L8.73017 13.937L9.23344 13.4317L8.9048 12.831C8.83251 12.6903 8.7718 12.544 8.72334 12.3932L8.52743 11.7337L7.81818 11.7348V11.2648L8.52631 11.2637L8.72312 10.6075C8.77179 10.4559 8.83285 10.3088 8.90561 10.1675L9.23214 9.56438L8.73039 9.06273L9.06284 8.73028L9.56635 9.23278L10.1683 8.90519C10.3093 8.83265 10.4561 8.77176 10.6073 8.72319L11.265 8.52689V7.81818H11.735V8.52685ZM13.1875 11.5C13.1875 12.432 12.432 13.1875 11.5 13.1875C10.568 13.1875 9.8125 12.432 9.8125 11.5C9.8125 10.568 10.568 9.8125 11.5 9.8125C12.432 9.8125 13.1875 10.568 13.1875 11.5ZM12.3693 11.5C12.3693 11.9801 11.9801 12.3693 11.5 12.3693C11.0199 12.3693 10.6307 11.9801 10.6307 11.5C10.6307 11.0199 11.0199 10.6307 11.5 10.6307C11.9801 10.6307 12.3693 11.0199 12.3693 11.5Z",
          fill: ""
        })
      }
    };
  });
  var BuildingPenIcon = /*#__PURE__*/createIconComponent("BuildingPenIcon", "oxygen-icon oxygen-icon-building-pen", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2.5C2 2.22386 2.22386 2 2.5 2H6V5H2V2.5ZM2 6V9.5H6V6H2ZM2 13.5V10.5H6.5H7.5C7.77614 10.5 8 10.2761 8 10C8 9.72386 7.77614 9.5 7.5 9.5H7V6H11V7C11 7.27614 11.2239 7.5 11.5 7.5C11.7761 7.5 12 7.27614 12 7V5.5V2.5C12 1.67157 11.3284 1 10.5 1H6.5H2.5C1.67157 1 1 1.67157 1 2.5V13.5C1 14.3284 1.67157 15 2.5 15H6C6.27614 15 6.5 14.7761 6.5 14.5C6.5 14.2239 6.27614 14 6 14H2.5C2.22386 14 2 13.7761 2 13.5ZM7 5H11V2.5C11 2.22386 10.7761 2 10.5 2H7V5ZM14.253 8.56051C14.0577 8.36525 13.7411 8.36525 13.5459 8.56051L13.1065 8.99985L14.3994 10.2927L14.8388 9.8534C15.034 9.65814 15.034 9.34156 14.8388 9.1463L14.253 8.56051ZM12.8388 7.8534L12.0459 8.6463L7.54586 13.1463L7.39941 13.2927V13.4998V15.4998V15.9998H7.89941H9.89941H10.1065L10.253 15.8534L14.7528 11.3535L14.753 11.3534L14.7531 11.3533L15.5459 10.5605C16.1316 9.97472 16.1316 9.02498 15.5459 8.43919L14.9601 7.8534C14.3743 7.26762 13.4245 7.26762 12.8388 7.8534ZM9.69231 14.9998L13.6923 10.9998L12.3994 9.70696L8.39941 13.707V14.9998H9.69231Z",
          fill: ""
        })
      }
    };
  });
  var CalenderBoltIcon = /*#__PURE__*/createIconComponent("CalenderBoltIcon", "oxygen-icon oxygen-icon-calender-bolt", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M4.5 0.5C4.5 0.223858 4.27614 0 4 0C3.72386 0 3.5 0.223858 3.5 0.5V1H2.5C1.11929 1 0 2.11929 0 3.5V10.5C0 11.8807 1.11929 13 2.5 13H5.5C5.77614 13 6 12.7761 6 12.5C6 12.2239 5.77614 12 5.5 12H2.5C1.67157 12 1 11.3284 1 10.5V6.5H9C9.27614 6.5 9.5 6.27614 9.5 6C9.5 5.72386 9.27614 5.5 9 5.5H1V3.5C1 2.67157 1.67157 2 2.5 2H3.5C3.5 2.27614 3.72386 2.5 4 2.5C4.27614 2.5 4.5 2.27614 4.5 2H10.5C10.5 2.27614 10.7239 2.5 11 2.5C11.2761 2.5 11.5 2.27614 11.5 2H12.5C13.3284 2 14 2.67157 14 3.5C14 3.77614 14.2239 4 14.5 4C14.7761 4 15 3.77614 15 3.5C15 2.11929 13.8807 1 12.5 1H11.5V0.5C11.5 0.223858 11.2761 0 11 0C10.7239 0 10.5 0.223858 10.5 0.5V1H4.5V0.5ZM12 7.15139L9.43426 11H11.5H12V11.5V13.8486L14.5657 10H12.5H12V9.5V7.15139ZM11.9008 5.49746C12.2301 5.00352 13 5.23663 13 5.83028V9H15.3131C15.7924 9 16.0782 9.53408 15.8124 9.93282L12.0992 15.5025C11.7699 15.9965 11 15.7634 11 15.1697V12H8.68685C8.20764 12 7.9218 11.4659 8.18762 11.0672L11.9008 5.49746Z",
          fill: ""
        })
      }
    };
  });
  var CameraIcon = /*#__PURE__*/createIconComponent("CameraIcon", "oxygen-icon oxygen-icon-camera", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8 13.3333C10.2091 13.3333 12 11.5425 12 9.33333C12 7.12419 10.2091 5.33333 8 5.33333C5.79086 5.33333 4 7.12419 4 9.33333C4 11.5425 5.79086 13.3333 8 13.3333ZM8 12.3333C9.65685 12.3333 11 10.9902 11 9.33333C11 7.67648 9.65685 6.33333 8 6.33333C6.34315 6.33333 5 7.67648 5 9.33333C5 10.9902 6.34315 12.3333 8 12.3333Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6.93836 0C6.4097 0 5.90677 0.228213 5.55864 0.626074L3.77312 2.66667H2.66667C1.19391 2.66667 0 3.86057 0 5.33333V13.3333C0 14.8061 1.19391 16 2.66667 16H13.3333C14.8061 16 16 14.8061 16 13.3333V5.33333C16 3.86057 14.8061 2.66667 13.3333 2.66667H12.2269L10.4414 0.626074C10.0932 0.228213 9.59031 0 9.06165 0H6.93836ZM12.0028 3.66667C12.0011 3.66668 11.9993 3.66668 11.9976 3.66667H4.00242C4.00068 3.66668 3.99893 3.66668 3.99719 3.66667H2.66667C1.74619 3.66667 1 4.41286 1 5.33333V13.3333C1 14.2538 1.74619 15 2.66667 15H13.3333C14.2538 15 15 14.2538 15 13.3333V5.33333C15 4.41286 14.2538 3.66667 13.3333 3.66667H12.0028ZM5.10189 2.66667H10.8981L9.6888 1.28458C9.53056 1.10373 9.30195 1 9.06165 1H6.93836C6.69806 1 6.46946 1.10373 6.31122 1.28458L5.10189 2.66667Z",
          fill: ""
        }))
      }
    };
  });
  var CheckIcon = /*#__PURE__*/createIconComponent("CheckIcon", "oxygen-icon oxygen-icon-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.35395 10.9506C7.33041 10.995 7.29974 11.0365 7.26196 11.0735C7.06463 11.2667 6.74807 11.2633 6.55489 11.066L2.35755 6.77849C2.16438 6.58116 2.16774 6.2646 2.36507 6.07142C2.56239 5.87824 2.87896 5.88161 3.07213 6.07893L6.90973 9.99894L13.1922 3.57045C13.3852 3.37296 13.7018 3.36932 13.8993 3.56233C14.0968 3.75534 14.1004 4.0719 13.9074 4.26939L7.4572 10.8695C7.42572 10.9017 7.39095 10.9288 7.35395 10.9506Z",
          fill: ""
        })
      }
    };
  });
  var ChevronDownIcon = /*#__PURE__*/createIconComponent("ChevronDownIcon", "oxygen-icon oxygen-icon-chevron-down", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.10987 5.58825C2.1099 5.58827 2.10985 5.58823 2.10987 5.58825C1.96343 5.4537 1.96335 5.23547 2.1098 5.10092C2.25624 4.96636 2.49368 4.96636 2.64013 5.10092C2.64003 5.10083 2.64022 5.101 2.64013 5.10092L7.99998 10.0255L13.3598 5.10092C13.5063 4.96636 13.7437 4.96636 13.8902 5.10092C14.0366 5.23547 14.0366 5.45362 13.8902 5.58818L7.99998 11L2.10987 5.58825Z",
          fill: ""
        })
      }
    };
  });
  var ChevronLeftIcon = /*#__PURE__*/createIconComponent("ChevronLeftIcon", "oxygen-icon oxygen-icon-chevron-left", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.4118 2.10987C10.4117 2.1099 10.4118 2.10985 10.4118 2.10987C10.5463 1.96343 10.7645 1.96335 10.8991 2.1098C11.0336 2.25624 11.0336 2.49368 10.8991 2.64013C10.899 2.64022 10.8992 2.64003 10.8991 2.64013L5.97452 7.99998L10.8991 13.3598C11.0336 13.5063 11.0336 13.7437 10.8991 13.8902C10.7645 14.0366 10.5464 14.0366 10.4118 13.8902L5 7.99998L10.4118 2.10987Z",
          fill: ""
        })
      }
    };
  });
  var ChevronRightIcon = /*#__PURE__*/createIconComponent("ChevronRightIcon", "oxygen-icon oxygen-icon-chevron-right", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.58825 2.10987C5.58827 2.1099 5.58822 2.10985 5.58825 2.10987C5.45369 1.96343 5.23547 1.96335 5.10091 2.1098C4.96636 2.25624 4.96636 2.49368 5.10091 2.64013C5.101 2.64022 5.10083 2.64003 5.10091 2.64013L10.0255 7.99998L5.10091 13.3598C4.96636 13.5063 4.96636 13.7437 5.10091 13.8902C5.23547 14.0366 5.45362 14.0366 5.58818 13.8902L11 7.99998L5.58825 2.10987Z",
          fill: ""
        })
      }
    };
  });
  var ChevronUpIcon = /*#__PURE__*/createIconComponent("ChevronUpIcon", "oxygen-icon oxygen-icon-chevron-up", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.10987 10.4118C2.1099 10.4117 2.10985 10.4118 2.10987 10.4118C1.96343 10.5463 1.96335 10.7645 2.1098 10.8991C2.25624 11.0336 2.49368 11.0336 2.64013 10.8991C2.64022 10.899 2.64003 10.8992 2.64013 10.8991L7.99998 5.97452L13.3598 10.8991C13.5063 11.0336 13.7437 11.0336 13.8902 10.8991C14.0366 10.7645 14.0366 10.5464 13.8902 10.4118L7.99998 5L2.10987 10.4118Z",
          fill: ""
        })
      }
    };
  });
  var ChevronsLeftIcon = /*#__PURE__*/createIconComponent("ChevronsLeftIcon", "oxygen-icon oxygen-icon-chevrons-left", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8.14215 7.55926L8.23338 7.45031L14.6331 1.22901C14.7742 1.09122 14.9633 1.00982 15.163 1.00083C15.3628 0.991844 15.5588 1.05592 15.7124 1.18044C15.866 1.30496 15.966 1.48089 15.9928 1.67355C16.0196 1.86621 15.9712 2.06164 15.857 2.22131L15.7658 2.33019L9.93093 8.00091L15.7658 13.6718C15.8981 13.8006 15.9797 13.9704 15.9964 14.1518C16.0131 14.3331 15.9637 14.5145 15.857 14.6641L15.7658 14.7729C15.6333 14.9015 15.4585 14.9808 15.272 14.9969C15.0855 15.0131 14.899 14.9652 14.7451 14.8615L14.6331 14.7729L8.23338 8.5515C8.10108 8.42263 8.01953 8.25279 8.00282 8.07141C7.98622 7.89011 8.03546 7.70882 8.14215 7.55926ZM0.142493 7.55926L0.23369 7.45031L6.63343 1.22901C6.7745 1.09122 6.96357 1.00982 7.1634 1.00083C7.36316 0.991844 7.55916 1.05592 7.71275 1.18044C7.86634 1.30496 7.96635 1.48089 7.99314 1.67355C8.01985 1.86621 7.97145 2.06164 7.85741 2.22131L7.76618 2.33019L1.93126 8.00091L7.76618 13.6718C7.89849 13.8006 7.98004 13.9704 7.99673 14.1518C8.01335 14.3331 7.96409 14.5145 7.85741 14.6641L7.76618 14.7729C7.63362 14.9015 7.45883 14.9808 7.27234 14.9969C7.08577 15.0131 6.89937 14.9652 6.74543 14.8615L6.63343 14.7729L0.23369 8.5515C0.101455 8.42263 0.0198582 8.25279 0.00317894 8.07141C-0.0135004 7.89011 0.0358179 7.70882 0.142493 7.55926Z",
          fill: ""
        })
      }
    };
  });
  var ChevronsRightIcon = /*#__PURE__*/createIconComponent("ChevronsRightIcon", "oxygen-icon oxygen-icon-chevrons-right", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M7.85785 7.55926L7.76662 7.45031L1.36694 1.22901C1.22579 1.09122 1.03671 1.00982 0.836955 1.00083C0.6372 0.991844 0.4412 1.05592 0.287606 1.18044C0.134013 1.30496 0.0340089 1.48089 0.00721405 1.67355C-0.0195808 1.86621 0.0288371 2.06164 0.142952 2.22131L0.234185 2.33019L6.06907 8.00091L0.234185 13.6718C0.101878 13.8006 0.0203295 13.9704 0.00362619 14.1518C-0.0130651 14.3331 0.0362648 14.5145 0.142952 14.6641L0.234185 14.7729C0.366743 14.9015 0.541456 14.9808 0.728024 14.9969C0.914508 15.0131 1.10099 14.9652 1.25491 14.8615L1.36694 14.7729L7.76662 8.5515C7.89892 8.42263 7.98047 8.25279 7.99718 8.07141C8.01378 7.89011 7.96454 7.70882 7.85785 7.55926ZM15.8575 7.55926L15.7663 7.45031L9.36657 1.22901C9.2255 1.09122 9.03643 1.00982 8.8366 1.00083C8.63684 0.991844 8.44084 1.05592 8.28725 1.18044C8.13366 1.30496 8.03365 1.48089 8.00686 1.67355C7.98015 1.86621 8.02855 2.06164 8.14259 2.22131L8.23382 2.33019L14.0687 8.00091L8.23382 13.6718C8.10151 13.8006 8.01996 13.9704 8.00327 14.1518C7.98665 14.3331 8.03591 14.5145 8.14259 14.6641L8.23382 14.7729C8.36638 14.9015 8.54117 14.9808 8.72766 14.9969C8.91423 15.0131 9.10063 14.9652 9.25457 14.8615L9.36657 14.7729L15.7663 8.5515C15.8985 8.42263 15.9801 8.25279 15.9968 8.07141C16.0135 7.89011 15.9642 7.70882 15.8575 7.55926Z",
          fill: ""
        })
      }
    };
  });
  var CircleCheckFilledIcon = /*#__PURE__*/createIconComponent("CircleCheckFilledIcon", "oxygen-icon oxygen-icon-circle-check-filled", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8 16C12.4183 16 16 12.4183 16 8C16 3.58172 12.4183 0 8 0C3.58172 0 0 3.58172 0 8C0 12.4183 3.58172 16 8 16ZM12.7105 6.70372C13.0991 6.31133 13.0961 5.67817 12.7037 5.28952C12.3113 4.90087 11.6782 4.9039 11.2895 5.29628L7.04762 9.57897L4.71048 7.21936C4.32183 6.82697 3.68867 6.82394 3.29628 7.21259C2.9039 7.60125 2.90087 8.2344 3.28952 8.62679L6.33714 11.7037L7.04762 12.421L7.7581 11.7037L12.7105 6.70372Z",
          fill: ""
        })
      }
    };
  });
  var CircleDotIcon = /*#__PURE__*/createIconComponent("CircleDotIcon", "oxygen-icon oxygen-icon-circle-dot", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8 0C3.58172 0 0 3.58172 0 8C0 12.4183 3.58172 16 8 16C12.4183 16 16 12.4183 16 8C16 3.58172 12.4183 0 8 0ZM8 1C11.866 1 15 4.13401 15 8C15 11.866 11.866 15 8 15C4.13401 15 1 11.866 1 8C1 4.13401 4.13401 1 8 1ZM8 5.5C6.61929 5.5 5.5 6.61929 5.5 8C5.5 9.38071 6.61929 10.5 8 10.5C9.38071 10.5 10.5 9.38071 10.5 8C10.5 6.61929 9.38071 5.5 8 5.5ZM8 6.5C8.82843 6.5 9.5 7.17157 9.5 8C9.5 8.82843 8.82843 9.5 8 9.5C7.17157 9.5 6.5 8.82843 6.5 8C6.5 7.17157 7.17157 6.5 8 6.5Z",
          fill: ""
        })
      }
    };
  });
  var CircleInfoIcon = /*#__PURE__*/createIconComponent("CircleInfoIcon", "oxygen-icon oxygen-icon-circle-info", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.00921 0.00927734C3.59166 0.00927734 0.00976562 3.59117 0.00976562 8.00872C0.00976562 12.4263 3.59166 16.0082 8.00921 16.0082C12.4268 16.0082 16.0086 12.4263 16.0086 8.00872C16.0086 3.59117 12.4268 0.00927734 8.00921 0.00927734ZM1.00977 8.00872C1.00977 4.14346 4.14395 1.00928 8.00921 1.00928C11.8745 1.00928 15.0086 4.14346 15.0086 8.00872C15.0086 11.874 11.8745 15.0082 8.00921 15.0082C4.14395 15.0082 1.00977 11.874 1.00977 8.00872ZM6.86841 6.36792C6.59226 6.36792 6.36841 6.59177 6.36841 6.86792C6.36841 7.14406 6.59226 7.36792 6.86841 7.36792H7.67266V11.2586H6.3786C6.10246 11.2586 5.8786 11.4825 5.8786 11.7586C5.8786 12.0348 6.10246 12.2586 6.3786 12.2586H9.96529C10.2414 12.2586 10.4653 12.0348 10.4653 11.7586C10.4653 11.4825 10.2414 11.2586 9.96529 11.2586H8.67266V6.86792C8.67266 6.59177 8.4488 6.36792 8.17266 6.36792H6.86841ZM7.42051 3.37788C7.59478 3.26143 7.79966 3.19928 8.00925 3.19928C8.29031 3.19928 8.55984 3.31093 8.75858 3.50966C8.95731 3.7084 9.06896 3.97794 9.06896 4.25899C9.06896 4.46858 9.00681 4.67346 8.89037 4.84773C8.77392 5.02199 8.60842 5.15782 8.41479 5.23803C8.22115 5.31823 8.00808 5.33922 7.80252 5.29833C7.59695 5.25744 7.40813 5.15651 7.25993 5.00831C7.11173 4.86011 7.0108 4.67129 6.96991 4.46572C6.92902 4.26016 6.95001 4.04709 7.03022 3.85346C7.11042 3.65982 7.24625 3.49432 7.42051 3.37788Z",
          fill: ""
        })
      }
    };
  });
  var CircleInfoFilledIcon = /*#__PURE__*/createIconComponent("CircleInfoFilledIcon", "oxygen-icon oxygen-icon-circle-info-filled", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8 0C3.5888 0 0 3.5888 0 8C0 12.4112 3.5888 16 8 16C12.4112 16 16 12.4112 16 8C16 3.5888 12.4112 0 8 0ZM8 3.28C8.20569 3.28 8.40677 3.34099 8.57779 3.45527C8.74882 3.56955 8.88212 3.73197 8.96083 3.92201C9.03955 4.11204 9.06015 4.32115 9.02002 4.52289C8.97989 4.72463 8.88084 4.90994 8.73539 5.05539C8.58994 5.20084 8.40463 5.29989 8.20289 5.34002C8.00115 5.38014 7.79204 5.35955 7.60201 5.28083C7.41197 5.20212 7.24955 5.06882 7.13527 4.89779C7.02099 4.72677 6.96 4.52569 6.96 4.32C6.96 4.04417 7.06957 3.77965 7.26461 3.58461C7.45965 3.38957 7.72417 3.28 8 3.28ZM9.92 12.32H6.4C6.23026 12.32 6.06747 12.2526 5.94745 12.1325C5.82743 12.0125 5.76 11.8497 5.76 11.68C5.76 11.5103 5.82743 11.3475 5.94745 11.2275C6.06747 11.1074 6.23026 11.04 6.4 11.04H7.52V7.52H6.88C6.71026 7.52 6.54747 7.45257 6.42745 7.33255C6.30743 7.21252 6.24 7.04974 6.24 6.88C6.24 6.71026 6.30743 6.54747 6.42745 6.42745C6.54747 6.30743 6.71026 6.24 6.88 6.24H8.16C8.32974 6.24 8.49253 6.30743 8.61255 6.42745C8.73257 6.54747 8.8 6.71026 8.8 6.88V11.04H9.92C10.0897 11.04 10.2525 11.1074 10.3725 11.2275C10.4926 11.3475 10.56 11.5103 10.56 11.68C10.56 11.8497 10.4926 12.0125 10.3725 12.1325C10.2525 12.2526 10.0897 12.32 9.92 12.32Z",
          fill: ""
        })
      }
    };
  });
  var CirclePlusRaysIcon = /*#__PURE__*/createIconComponent("CirclePlusRaysIcon", "oxygen-icon oxygen-icon-circle-plus-rays", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15.8536 0.853553C16.0488 0.658291 16.0488 0.341709 15.8536 0.146447C15.6583 -0.0488155 15.3417 -0.0488156 15.1464 0.146447L13.1464 2.14645C12.9512 2.34171 12.9512 2.65829 13.1464 2.85355C13.3417 3.04882 13.6583 3.04882 13.8536 2.85355L15.8536 0.853553ZM0.146447 0.146447C0.341709 -0.0488155 0.658291 -0.0488155 0.853553 0.146447L2.85355 2.14645C3.04882 2.34171 3.04882 2.65829 2.85355 2.85355C2.65829 3.04882 2.34171 3.04882 2.14645 2.85355L0.146447 0.853553C-0.0488155 0.658291 -0.0488155 0.341709 0.146447 0.146447ZM8 2.5C4.96243 2.5 2.5 4.96243 2.5 8C2.5 11.0376 4.96243 13.5 8 13.5C11.0376 13.5 13.5 11.0376 13.5 8C13.5 4.96243 11.0376 2.5 8 2.5ZM1.5 8C1.5 4.41015 4.41015 1.5 8 1.5C11.5899 1.5 14.5 4.41015 14.5 8C14.5 11.5899 11.5899 14.5 8 14.5C4.41015 14.5 1.5 11.5899 1.5 8ZM8 5.5C8.27614 5.5 8.5 5.72386 8.5 6V7.5H10C10.2761 7.5 10.5 7.72386 10.5 8C10.5 8.27614 10.2761 8.5 10 8.5H8.5V10C8.5 10.2761 8.27614 10.5 8 10.5C7.72386 10.5 7.5 10.2761 7.5 10V8.5H6C5.72386 8.5 5.5 8.27614 5.5 8C5.5 7.72386 5.72386 7.5 6 7.5H7.5V6C7.5 5.72386 7.72386 5.5 8 5.5ZM15.8536 15.8536C15.6583 16.0488 15.3417 16.0488 15.1464 15.8536L13.1464 13.8536C12.9512 13.6583 12.9512 13.3417 13.1464 13.1464C13.3417 12.9512 13.6583 12.9512 13.8536 13.1464L15.8536 15.1464C16.0488 15.3417 16.0488 15.6583 15.8536 15.8536ZM0.146447 15.1464C-0.0488155 15.3417 -0.0488156 15.6583 0.146447 15.8536C0.341709 16.0488 0.658291 16.0488 0.853553 15.8536L2.85355 13.8536C3.04882 13.6583 3.04882 13.3417 2.85355 13.1464C2.65829 12.9512 2.34171 12.9512 2.14645 13.1464L0.146447 15.1464Z",
          fill: ""
        })
      }
    };
  });
  var CircleStarIcon = /*#__PURE__*/createIconComponent("CircleStarIcon", "oxygen-icon oxygen-icon-circle-star", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15 8C15 11.866 11.866 15 8 15C4.13401 15 1 11.866 1 8C1 4.13401 4.13401 1 8 1C11.866 1 15 4.13401 15 8ZM16 8C16 12.4183 12.4183 16 8 16C3.58172 16 0 12.4183 0 8C0 3.58172 3.58172 0 8 0C12.4183 0 16 3.58172 16 8ZM8.53405 3.92309L9.36102 6.12672L11.7123 6.23225L13.2308 6.30041L12.0424 7.24807L10.2022 8.71553L10.8284 10.9844L11.2328 12.4496L9.96429 11.6122L8 10.3155L6.0357 11.6122L4.76718 12.4496L5.1716 10.9844L5.79783 8.71553L3.9576 7.24807L2.76919 6.30041L4.28766 6.23225L6.63898 6.12672L7.46595 3.92309L8 2.5L8.53405 3.92309ZM9.31618 7.12572L10.5239 7.17992L9.5787 7.93368L9.06258 8.34525L9.23822 8.98159L9.55988 10.147L8.55092 9.48094L8 9.11726L7.44908 9.48094L6.44012 10.147L6.76178 8.98159L6.93742 8.34525L6.4213 7.93368L5.47606 7.17992L6.68382 7.12572L7.34329 7.09612L7.57523 6.47807L8 5.34617L8.42477 6.47807L8.65671 7.09612L9.31618 7.12572Z",
          fill: ""
        })
      }
    };
  });
  var CircleUserIcon = /*#__PURE__*/createIconComponent("CircleUserIcon", "oxygen-icon oxygen-icon-circle-user", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15 8C15 11.866 11.866 15 8 15C4.13401 15 1 11.866 1 8C1 4.13401 4.13401 1 8 1C11.866 1 15 4.13401 15 8ZM16 8C16 12.4183 12.4183 16 8 16C3.58172 16 0 12.4183 0 8C0 3.58172 3.58172 0 8 0C12.4183 0 16 3.58172 16 8ZM7.95682 6.05638C8.41993 6.05638 8.8826 5.64549 8.8826 5.02819C8.8826 4.41088 8.41993 4 7.95682 4C7.49371 4 7.03104 4.41088 7.03104 5.02819C7.03104 5.64549 7.49371 6.05638 7.95682 6.05638ZM7.95682 7.05638C9.0204 7.05638 9.8826 6.14832 9.8826 5.02819C9.8826 3.90805 9.0204 3 7.95682 3C6.89324 3 6.03104 3.90805 6.03104 5.02819C6.03104 6.14832 6.89324 7.05638 7.95682 7.05638ZM3.41278 10.9422C3.74421 8.83181 5.71725 7.5028 7.957 7.5028C10.1968 7.5028 12.1692 8.83189 12.5006 10.9422C12.6024 11.5903 12.0596 12.0519 11.5139 12.0519L4.39982 12.0521C3.85399 12.0521 3.31098 11.5904 3.41278 10.9422ZM4.40816 11.0521L11.5052 11.0519C11.2478 9.57381 9.82045 8.5028 7.957 8.5028C6.09335 8.5028 4.66547 9.574 4.40816 11.0521Z",
          fill: ""
        })
      }
    };
  });
  var CirclesOverlapIcon = /*#__PURE__*/createIconComponent("CirclesOverlapIcon", "oxygen-icon oxygen-icon-circles-overlap", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5 13C2.23858 13 0 10.7614 0 8C0 5.23858 2.23858 3 5 3C6.05416 3 7.03213 3.32623 7.83846 3.88323C7.86453 3.90125 7.89043 3.91951 7.91615 3.938C7.94284 3.95719 7.96933 3.97664 7.99562 3.99635C7.99708 3.99744 7.99854 3.99854 8 3.99963C8.00146 3.99854 8.00292 3.99744 8.00439 3.99634C8.03068 3.97664 8.05717 3.95719 8.08385 3.938C8.10938 3.91964 8.13509 3.90152 8.16097 3.88363C8.96741 3.32638 9.94559 3 11 3C13.7614 3 16 5.23858 16 8C16 10.7614 13.7614 13 11 13C9.94561 13 8.96744 12.6736 8.16101 12.1164C8.13512 12.0985 8.1094 12.0804 8.08385 12.062C8.05717 12.0428 8.03068 12.0234 8.00439 12.0037C8.00292 12.0026 8.00146 12.0015 8 12.0004C7.99854 12.0015 7.99708 12.0026 7.99562 12.0037C7.96933 12.0234 7.94283 12.0428 7.91615 12.062C7.89045 12.0805 7.86456 12.0987 7.8385 12.1167C7.03217 12.6738 6.05418 13 5 13ZM9.66611 11.7722C10.0833 11.9197 10.5323 12 11 12C13.2091 12 15 10.2091 15 8C15 5.79086 13.2091 4 11 4C10.5323 4 10.0833 4.08028 9.66611 4.22781C9.33905 4.34347 9.03152 4.50045 8.74979 4.69249C8.97031 4.94229 9.16624 5.2143 9.33382 5.50473C9.75756 6.2391 10 7.09124 10 8C10 8.90876 9.75756 9.7609 9.33382 10.4953C9.16624 10.7857 8.97031 11.0577 8.74979 11.3075C9.03152 11.4996 9.33905 11.6565 9.66611 11.7722ZM6.3339 4.22781C5.9167 4.08028 5.46772 4 5 4C2.79086 4 1 5.79086 1 8C1 10.2091 2.79086 12 5 12C5.46773 12 5.9167 11.9197 6.3339 11.7722C6.66096 11.6565 6.96849 11.4996 7.25021 11.3075C7.0297 11.0577 6.83376 10.7857 6.66618 10.4953C6.24245 9.7609 6 8.90876 6 8C6 7.09123 6.24244 6.23909 6.66618 5.50473C6.83376 5.2143 7.0297 4.94229 7.25021 4.69248C6.96849 4.50045 6.66095 4.34346 6.3339 4.22781ZM7.41622 9.77864C7.14981 9.24289 7 8.63894 7 8C7 7.36106 7.14981 6.75711 7.41622 6.22136C7.57279 5.9065 7.76963 5.61519 8 5.35418C8.23038 5.61519 8.42722 5.9065 8.58378 6.22136C8.85019 6.75711 9 7.36106 9 8C9 8.63894 8.85019 9.24289 8.58378 9.77864C8.42722 10.0935 8.23038 10.3848 8 10.6458C7.76963 10.3848 7.57279 10.0935 7.41622 9.77864Z",
          fill: ""
        })
      }
    };
  });
  var ClockAsteriskIcon = /*#__PURE__*/createIconComponent("ClockAsteriskIcon", "oxygen-icon oxygen-icon-clock-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.329 1.05295C4.76848 0.595017 1.51088 3.11017 1.05295 6.67069C0.713673 9.30864 2.0063 11.7814 4.1491 13.0717C4.38567 13.2141 4.46197 13.5214 4.31952 13.758C4.17707 13.9945 3.86982 14.0708 3.63326 13.9284C1.16291 12.4409 -0.330567 9.58858 0.0611182 6.54313C0.5895 2.43483 4.34827 -0.467264 8.45657 0.0611178C12.5649 0.5895 15.467 4.34827 14.9386 8.45657C14.9034 8.73045 14.6528 8.92393 14.3789 8.8887C14.105 8.85348 13.9115 8.60289 13.9467 8.329C14.4047 4.76848 11.8895 1.51088 8.329 1.05295ZM7.8726 11.3369C7.91769 10.8877 8.58186 10.8877 8.62696 11.3369L8.75714 12.6336L9.96115 12.0964C10.3782 11.9103 10.7103 12.4774 10.3383 12.7405L9.2645 13.5L10.3383 14.2595C10.7103 14.5226 10.3782 15.0897 9.96115 14.9037L8.75714 14.3665L8.62696 15.6631C8.58186 16.1123 7.91769 16.1123 7.8726 15.6631L7.74242 14.3665L6.53841 14.9037C6.12132 15.0897 5.78923 14.5226 6.16123 14.2595L7.23506 13.5L6.16123 12.7405C5.78923 12.4774 6.12131 11.9103 6.53841 12.0964L7.74242 12.6336L7.8726 11.3369ZM13.3726 11.3369C13.4177 10.8877 14.0819 10.8877 14.127 11.3369L14.2571 12.6336L15.4611 12.0964C15.8782 11.9103 16.2103 12.4774 15.8383 12.7405L14.7645 13.5L15.8383 14.2595C16.2103 14.5226 15.8782 15.0897 15.4611 14.9037L14.2571 14.3665L14.127 15.6631C14.0819 16.1123 13.4177 16.1123 13.3726 15.6631L13.2424 14.3665L12.0384 14.9037C11.6213 15.0897 11.2892 14.5226 11.6612 14.2595L12.7351 13.5L11.6612 12.7405C11.2892 12.4774 11.6213 11.9103 12.0384 12.0964L13.2424 12.6336L13.3726 11.3369ZM7.99978 2.50003C7.99978 2.22389 7.77592 2.00003 7.49978 2.00003C7.22363 2.00003 6.99978 2.22389 6.99978 2.50003V7.50003V8.00003H7.49978H10.4998C10.7759 8.00003 10.9998 7.77617 10.9998 7.50003C10.9998 7.22389 10.7759 7.00003 10.4998 7.00003H7.99978V2.50003Z",
          fill: ""
        })
      }
    };
  });
  var CloneIcon = /*#__PURE__*/createIconComponent("CloneIcon", "oxygen-icon oxygen-icon-clone", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11.9947 2.33562C11.91 1.03154 10.8255 0 9.5 0H2.5L2.33562 0.00531768C1.03154 0.0899613 0 1.17452 0 2.5V9.5L0.00531768 9.66438C0.0899613 10.9685 1.17452 12 2.5 12H4V13.5L4.00532 13.6644C4.08996 14.9685 5.17452 16 6.5 16H13.5L13.6644 15.9947C14.9685 15.91 16 14.8255 16 13.5V5.5L15.9947 5.33562C15.91 4.03154 14.8255 3 13.5 3H12V2.5L11.9947 2.33562ZM11 3V2.5C11 1.7203 10.4051 1.07955 9.64446 1.00687L9.5 1H2.5C1.7203 1 1.07955 1.59489 1.00687 2.35554L1 2.5V9.5C1 10.2797 1.59489 10.9204 2.35554 10.9931L2.5 11H4V10.5C4 10.2239 4.22386 10 4.5 10C4.74546 10 4.94961 10.1769 4.99194 10.4101L5 10.5V13.5C5 14.2797 5.59489 14.9204 6.35554 14.9931L6.5 15H13.5C14.2797 15 14.9204 14.4051 14.9931 13.6445L15 13.5V5.5C15 4.7203 14.4051 4.07955 13.6445 4.00687L13.5 4H9.5C9.22386 4 9 3.77614 9 3.5C9 3.25454 9.17688 3.05039 9.41012 3.00806L9.5 3H11ZM4.5 3.5C4.77614 3.5 5 3.72386 5 4C5 6.50123 6.83659 8.5735 9.23477 8.94181L8.14645 7.85355C7.97288 7.67999 7.9536 7.41056 8.08859 7.21569L8.14645 7.14645C8.32001 6.97288 8.58944 6.9536 8.78431 7.08859L8.85355 7.14645L11.2071 9.5L8.85355 11.8536C8.65829 12.0488 8.34171 12.0488 8.14645 11.8536C7.97288 11.68 7.9536 11.4106 8.08859 11.2157L8.14645 11.1464L9.32996 9.96301C6.33162 9.62985 4 7.08721 4 4C4 3.72386 4.22386 3.5 4.5 3.5Z",
          fill: ""
        })
      }
    };
  });
  var CloudNodesIcon = /*#__PURE__*/createIconComponent("CloudNodesIcon", "oxygen-icon oxygen-icon-cloud-nodes", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.22831 0.380868C8.95926 0.729269 9.53325 1.25641 9.86567 1.68324C10.3416 1.55219 11.0109 1.49343 11.658 1.70061C12.0809 1.83599 12.4972 2.08653 12.8313 2.50378C13.1198 2.86398 13.3308 3.32802 13.4442 3.90718C14.2553 4.17382 15.4596 4.74042 15.8184 6.18047C16.2201 7.79225 14.9945 9.81343 12.6667 9.81343H11.1666V11.6527C11.1666 11.819 11.1697 12.0714 11.2598 12.3126C11.3417 12.5317 11.4926 12.7378 11.8248 12.8489L12.2644 12.9959C12.6094 12.3931 13.2574 11.9871 14 11.9871C15.1046 11.9871 16 12.8854 16 13.9935C16 15.1017 15.1046 16 14 16C12.8954 16 12 15.1017 12 13.9935L12.0002 13.965L11.5085 13.8006C10.8407 13.5773 10.4916 13.1145 10.3235 12.6648C10.1665 12.2448 10.1666 11.8356 10.1666 11.6619L10.1666 9.81343H8.5V16H7.5V9.81343H5.83336L5.83336 11.6619C5.83341 11.8356 5.83354 12.2448 5.67652 12.6648C5.50843 13.1145 5.15932 13.5773 4.49147 13.8006L3.9998 13.965L4 13.9935C4 15.1017 3.10457 16 2 16C0.895431 16 0 15.1017 0 13.9935C0 12.8854 0.895431 11.9871 2 11.9871C2.74256 11.9871 3.39061 12.3931 3.73562 12.9959L4.17524 12.8489C4.50739 12.7378 4.65829 12.5317 4.74019 12.3126C4.83033 12.0714 4.83336 11.819 4.83336 11.6527V9.81343H3C2.34957 9.81343 1.65108 9.4967 1.122 9.01416C0.586209 8.52551 0.166667 7.81373 0.166667 6.97095C0.166667 5.25167 1.37632 4.0981 2.53272 3.84604C2.65569 2.93499 3.16756 1.42434 4.75193 0.51606C6.05555 -0.231268 7.28754 -0.0675376 8.22831 0.380868ZM5.24807 1.38711C6.21336 0.833734 7.09269 0.950291 7.79917 1.28702C8.53253 1.63657 9.04718 2.21155 9.20201 2.48123C9.34745 2.73456 9.65955 2.83796 9.92693 2.72075C10.2069 2.59805 10.8111 2.48255 11.354 2.65635C11.6135 2.73943 11.8554 2.88692 12.0517 3.13212C12.2493 3.37881 12.4224 3.75156 12.4987 4.31786C12.5268 4.5269 12.6736 4.72281 12.9026 4.78953C13.6755 5.01472 14.5937 5.40215 14.8483 6.42379C15.0934 7.40741 14.3388 8.8102 12.6667 8.8102H3C2.65043 8.8102 2.18225 8.62532 1.79467 8.27183C1.41379 7.92446 1.16667 7.46581 1.16667 6.97095C1.16667 5.60944 2.22592 4.8299 2.95514 4.79827C3.25072 4.78546 3.49173 4.54642 3.50081 4.24393C3.51916 3.63183 3.83864 2.19509 5.24807 1.38711ZM2 14.9968C2.55228 14.9968 3 14.5476 3 13.9935C3 13.4395 2.55228 12.9903 2 12.9903C1.44772 12.9903 1 13.4395 1 13.9935C1 14.5476 1.44772 14.9968 2 14.9968ZM13 13.9935C13 14.5476 13.4477 14.9968 14 14.9968C14.5523 14.9968 15 14.5476 15 13.9935C15 13.4395 14.5523 12.9903 14 12.9903C13.4477 12.9903 13 13.4395 13 13.9935Z",
          fill: ""
        })
      }
    };
  });
  var CommentLinesIcon = /*#__PURE__*/createIconComponent("CommentLinesIcon", "oxygen-icon oxygen-icon-comment-lines", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15.9948 3.80796C15.8951 1.96428 14.3686 0.5 12.5 0.5H3.5L3.30796 0.505179C1.46428 0.604874 0 2.13144 0 4V14.1L0.00792224 14.2688C0.0552149 14.7713 0.312075 15.2341 0.72 15.54L0.855483 15.6324L0.996242 15.7109C1.63875 16.0324 1.70518 15.9373 2.02646 15.4774C2.08681 15.3911 2.15616 15.2918 2.24 15.18L4.25 12.5H12.5L12.692 12.4948C14.5357 12.3951 16 10.8686 16 9V4L15.9948 3.80796ZM3.5 1.5H12.5L12.6644 1.50532C13.9685 1.58996 15 2.67452 15 4V9L14.9947 9.16438C14.91 10.4685 13.8255 11.5 12.5 11.5H3.75L1.44 14.58L1.36715 14.6643C1.34176 14.6899 1.32454 14.7134 1.31384 14.735L1.28351 14.7139L1.21587 14.6538C1.0871 14.5209 1 14.3158 1 14.1V4L1.00532 3.83562C1.08996 2.53154 2.17452 1.5 3.5 1.5ZM1.38117 14.7817L1.31384 14.735C1.21552 14.9328 1.66748 14.9587 1.38117 14.7817ZM4 5C4 4.72386 4.22386 4.5 4.5 4.5H11.5C11.7761 4.5 12 4.72386 12 5C12 5.27614 11.7761 5.5 11.5 5.5H4.5C4.22386 5.5 4 5.27614 4 5ZM4.5 8C4.22386 8 4 8.22386 4 8.5C4 8.77614 4.22386 9 4.5 9H8.5C8.77614 9 9 8.77614 9 8.5C9 8.22386 8.77614 8 8.5 8H4.5Z",
          fill: ""
        })
      }
    };
  });
  var CopyIcon = /*#__PURE__*/createIconComponent("CopyIcon", "oxygen-icon oxygen-icon-copy", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15 11.5867C15 11.5864 15 11.5861 15 11.5858V5.5C15 5.49955 15 5.49909 15 5.49863C14.9993 4.67083 14.328 4 13.5 4H7C6.17158 4 5.5 4.67157 5.5 5.5V14.5C5.5 15.3285 6.17158 16 7 16H10.5858C10.9836 16 11.3652 15.8419 11.6465 15.5607L14.5607 12.6465C14.8417 12.3654 14.9998 11.9842 15 11.5867ZM1 1.5V11.5C1 12.3285 1.67158 13 2.5 13H4C4.27614 13 4.5 12.7761 4.5 12.5C4.5 12.2239 4.27614 12 4 12H2.5C2.22386 12 2 11.7762 2 11.5V1.5C2 1.22386 2.22386 1 2.5 1H10C10.2762 1 10.5 1.22385 10.5 1.5V2.5C10.5 2.77614 10.7239 3 11 3C11.2761 3 11.5 2.77614 11.5 2.5V1.5C11.5 0.671578 10.8284 0 10 0H2.5C1.67158 0 1 0.671571 1 1.5ZM6.5 5.5C6.5 5.22386 6.72386 5 7 5H13.5C13.7762 5 14 5.22385 14 5.5V11.5H11.2C10.8134 11.5 10.5 11.8134 10.5 12.2V15H7C6.72386 15 6.5 14.7762 6.5 14.5V5.5ZM11.5 12.5H13.2929L11.5 14.2929V12.5Z",
          fill: ""
        })
      }
    };
  });
  var CrescentBrightIcon = /*#__PURE__*/createIconComponent("CrescentBrightIcon", "oxygen-icon oxygen-icon-crescent-bright", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.5 0.5C8.5 0.223858 8.27614 0 8 0C7.72386 0 7.5 0.223858 7.5 0.5V1.5C7.5 1.77614 7.72386 2 8 2C8.27614 2 8.5 1.77614 8.5 1.5V0.5ZM8.5 14.5C8.5 14.2239 8.27614 14 8 14C7.72386 14 7.5 14.2239 7.5 14.5V15.5C7.5 15.7761 7.72386 16 8 16C8.27614 16 8.5 15.7761 8.5 15.5V14.5ZM1.5 8.5C1.77614 8.5 2 8.27614 2 8C2 7.72386 1.77614 7.5 1.5 7.5H0.5C0.223858 7.5 0 7.72386 0 8C0 8.27614 0.223858 8.5 0.5 8.5H1.5ZM15.5 8.5C15.7761 8.5 16 8.27614 16 8C16 7.72386 15.7761 7.5 15.5 7.5H14.5C14.2239 7.5 14 7.72386 14 8C14 8.27614 14.2239 8.5 14.5 8.5H15.5ZM12.4464 2.83936C12.2512 3.03463 12.2512 3.35121 12.4464 3.54647C12.6417 3.74173 12.9583 3.74173 13.1535 3.54647L13.8606 2.83936C14.0559 2.6441 14.0559 2.32752 13.8606 2.13226C13.6654 1.937 13.3488 1.937 13.1535 2.13226L12.4464 2.83936ZM2.14645 2.86065C1.95118 2.66539 1.95118 2.3488 2.14645 2.15354C2.34171 1.95828 2.65829 1.95828 2.85355 2.15354L3.56066 2.86065C3.75592 3.05591 3.75592 3.37249 3.56066 3.56775C3.3654 3.76302 3.04882 3.76302 2.85355 3.56775L2.14645 2.86065ZM2.14645 13.1394C1.95118 13.3346 1.95118 13.6512 2.14645 13.8465C2.34171 14.0417 2.65829 14.0417 2.85355 13.8465L3.56066 13.1394C3.75592 12.9441 3.75592 12.6275 3.56066 12.4322C3.3654 12.237 3.04882 12.237 2.85355 12.4322L2.14645 13.1394ZM12.4464 13.1606C12.2512 12.9654 12.2512 12.6488 12.4464 12.4535C12.6417 12.2583 12.9583 12.2583 13.1535 12.4535L13.8606 13.1606C14.0559 13.3559 14.0559 13.6725 13.8606 13.8677C13.6654 14.063 13.3488 14.063 13.1535 13.8677L12.4464 13.1606ZM6.14708 3.35455C4.303 4.09075 3 5.8932 3 7.99998C3 10.7614 5.23858 13 8 13C10.6789 13 12.8657 10.8933 12.994 8.2462C12.998 8.16463 13 8.08254 13 7.99999C13 7.67166 12.9684 7.35072 12.9079 7.04005C12.2805 7.63501 11.4329 7.99999 10.5 7.99999C8.567 7.99999 7 6.43299 7 4.49999C7 3.98143 7.11277 3.48921 7.31514 3.04651C6.90813 3.10226 6.51674 3.20699 6.14708 3.35457C6.14708 3.35456 6.14708 3.35456 6.14708 3.35455ZM6.00013 4.53503C4.80446 5.22663 4 6.51936 4 7.99998C4 10.2091 5.79086 12 8 12C9.94598 12 11.5674 10.6104 11.9261 8.76934C11.478 8.91895 10.9984 8.99999 10.5 8.99999C8.02641 8.99999 6.01896 7.00418 6.00013 4.53503Z",
          fill: ""
        })
      }
    };
  });
  var DatabaseIcon = /*#__PURE__*/createIconComponent("DatabaseIcon", "oxygen-icon oxygen-icon-database", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M16 3.66667C16 1.64162 12.4183 0 8 0C3.58172 0 0 1.64162 0 3.66667V12.3333C0 14.3584 3.58172 16 8 16C12.4183 16 16 14.3584 16 12.3333V3.66667ZM13.2402 5.35033C14.6171 4.71926 15 4.05032 15 3.66667C15 3.28302 14.6171 2.61407 13.2402 1.98301C11.9507 1.39198 10.099 1 8 1C5.90103 1 4.04932 1.39198 2.7598 1.98301C1.38293 2.61407 1 3.28302 1 3.66667C1 4.05032 1.38293 4.71926 2.7598 5.35033C4.04932 5.94135 5.90103 6.33333 8 6.33333C10.099 6.33333 11.9507 5.94135 13.2402 5.35033ZM15 5.44317C13.6353 6.5704 11.012 7.33333 8 7.33333C4.98797 7.33333 2.36473 6.5704 1 5.44317V7.66667C1 8.05032 1.38293 8.71926 2.7598 9.35033C4.04932 9.94135 5.90103 10.3333 8 10.3333C10.099 10.3333 11.9507 9.94135 13.2402 9.35033C14.6171 8.71926 15 8.05032 15 7.66667V5.44317ZM15 9.44317C13.6353 10.5704 11.012 11.3333 8 11.3333C4.98797 11.3333 2.36473 10.5704 1 9.44317V12.3333C1 12.717 1.38293 13.3859 2.7598 14.017C4.04932 14.608 5.90103 15 8 15C10.099 15 11.9507 14.608 13.2402 14.017C14.6171 13.3859 15 12.717 15 12.3333V9.44317Z",
          fill: ""
        })
      }
    };
  });
  var DatabaseDocumentIcon = /*#__PURE__*/createIconComponent("DatabaseDocumentIcon", "oxygen-icon oxygen-icon-database-document", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M1.281 2.11422C1.03437 2.30858 1 2.44272 1 2.5C1 2.55728 1.03437 2.69142 1.281 2.88578C1.52199 3.07571 1.9017 3.26861 2.41547 3.43987C3.4378 3.78065 4.88193 4 6.5 4C8.11807 4 9.5622 3.78065 10.5845 3.43987C11.0983 3.26861 11.478 3.07571 11.719 2.88578C11.9656 2.69142 12 2.55728 12 2.5C12 2.44272 11.9656 2.30858 11.719 2.11422C11.478 1.92429 11.0983 1.73139 10.5845 1.56013C9.5622 1.21935 8.11807 1 6.5 1C4.88193 1 3.4378 1.21935 2.41547 1.56013C1.9017 1.73139 1.52199 1.92429 1.281 2.11422ZM0.662023 1.3288C0.30142 1.61299 0 2.00499 0 2.5V6.5V10.4999V10.5C0 10.9439 0.243909 11.3063 0.550557 11.5781C0.858171 11.8508 1.27647 12.0777 1.75409 12.2641C2.7132 12.6384 4.01887 12.8903 5.47208 12.9716C5.74779 12.987 5.9838 12.776 5.99922 12.5003C6.01464 12.2246 5.80363 11.9885 5.52792 11.9731C4.14342 11.8957 2.94909 11.657 2.11763 11.3325C1.69996 11.1695 1.40033 10.995 1.21384 10.8298C1.02638 10.6636 1 10.5516 1 10.5V10.4999V7.90209C1.22534 8.03676 1.47995 8.1571 1.75409 8.26408C2.7132 8.63836 4.01887 8.8903 5.47208 8.97157C5.74779 8.98699 5.9838 8.77598 5.99922 8.50027C6.01464 8.22455 5.80363 7.98855 5.52792 7.97313C4.14342 7.8957 2.94909 7.65697 2.11763 7.3325C1.69996 7.16951 1.40033 6.99504 1.21384 6.82975C1.02638 6.66361 1 6.55158 1 6.5V3.90208C1.31375 4.08957 1.68758 4.25134 2.09925 4.38856C3.24849 4.77164 4.80436 5 6.5 5C8.19564 5 9.75151 4.77164 10.9008 4.38856C11.3124 4.25134 11.6862 4.08957 12 3.90208V5C12 5.27614 12.2239 5.5 12.5 5.5C12.7761 5.5 13 5.27614 13 5V2.5C13 2.00499 12.6986 1.61299 12.338 1.3288C11.9717 1.04017 11.4728 0.802115 10.9008 0.611445C9.75151 0.228362 8.19564 0 6.5 0C4.80436 0 3.24849 0.228362 2.09925 0.611445C1.52724 0.802115 1.02826 1.04017 0.662023 1.3288ZM9.5 6.5C8.39543 6.5 7.5 7.39543 7.5 8.5V14C7.5 15.1046 8.39543 16 9.5 16H12.4159C12.762 16 13.0975 15.8803 13.3655 15.6612L14.9496 14.3657C15.2979 14.0808 15.5 13.6546 15.5 13.2045V8.5C15.5 7.39543 14.6046 6.5 13.5 6.5H9.5ZM8.5 8.5C8.5 7.94772 8.94771 7.5 9.5 7.5H13.5C14.0523 7.5 14.5 7.94772 14.5 8.5V13.2045C14.5 13.3546 14.4326 13.4966 14.3165 13.5916L12.7324 14.8871C12.6431 14.9601 12.5313 15 12.4159 15H9.5C8.94772 15 8.5 14.5523 8.5 14V8.5ZM10 10C10 9.72386 10.2239 9.5 10.5 9.5H12.5C12.7761 9.5 13 9.72386 13 10C13 10.2761 12.7761 10.5 12.5 10.5H10.5C10.2239 10.5 10 10.2761 10 10ZM10.5 12C10.2239 12 10 12.2239 10 12.5C10 12.7761 10.2239 13 10.5 13H11.5C11.7761 13 12 12.7761 12 12.5C12 12.2239 11.7761 12 11.5 12H10.5Z",
          fill: ""
        })
      }
    };
  });
  var DiamondIcon = /*#__PURE__*/createIconComponent("DiamondIcon", "oxygen-icon oxygen-icon-diamond", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M7.9995 13.1673C7.85967 13.1673 7.72515 13.1383 7.59596 13.0803C7.46687 13.0224 7.35053 12.9361 7.24693 12.8216L2.27673 7.20947C2.19108 7.11651 2.12355 7.01186 2.07413 6.89551C2.02471 6.77928 2 6.659 2 6.53468C2 6.47141 2.01213 6.4169 2.0364 6.37114C2.06078 6.32537 2.07806 6.26582 2.08825 6.19247L3.08864 3.64571C3.15557 3.45435 3.27756 3.29889 3.45463 3.17934C3.63169 3.05978 3.82504 3 4.03468 3H11.9685C12.176 3 12.3683 3.05978 12.5454 3.17934C12.7224 3.29889 12.8444 3.45435 12.9114 3.64571L13.9149 6.19247C13.923 6.26582 13.9392 6.32537 13.9636 6.37114C13.9879 6.4169 14 6.47141 14 6.53468C14 6.659 13.9753 6.77928 13.9259 6.89551C13.8765 7.01186 13.8089 7.11651 13.7233 7.20947L8.75623 12.8216C8.65053 12.9361 8.53296 13.0224 8.40355 13.0803C8.27402 13.1383 8.13934 13.1673 7.9995 13.1673ZM6.24837 6.39058H9.75163L8.45573 3.79712H7.54676L6.24837 6.39058ZM7.6031 12.0487V7.1877H3.32133L7.6031 12.0487ZM8.40022 12.0487L12.6818 7.1877H8.40022V12.0487ZM10.6382 6.39058H13.1755L12.1704 3.9123C12.1535 3.87817 12.1279 3.85047 12.0938 3.8292C12.0597 3.80781 12.0234 3.79712 11.9851 3.79712H9.33978L10.6382 6.39058ZM2.82454 6.39058H5.36499L6.66022 3.79712H4.03468C3.99424 3.79712 3.95695 3.80781 3.92283 3.8292C3.8887 3.85047 3.86421 3.87817 3.84936 3.9123L2.82454 6.39058Z",
          fill: ""
        })
      }
    };
  });
  var DiscordIcon = /*#__PURE__*/createIconComponent("DiscordIcon", "oxygen-icon oxygen-icon-discord", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M13.5535 3.03729C12.5178 2.55271 11.4104 2.20053 10.2526 2C10.1104 2.25707 9.94429 2.60284 9.82976 2.8779C8.599 2.69281 7.37956 2.69281 6.17144 2.8779C6.05693 2.60284 5.88704 2.25707 5.74357 2C4.58454 2.20053 3.47584 2.554 2.44013 3.03985C0.351095 6.19666 -0.215207 9.27505 0.0679444 12.3097C1.4535 13.3444 2.79627 13.973 4.11638 14.3843C4.44233 13.9357 4.73302 13.4588 4.98345 12.9563C4.5065 12.775 4.04969 12.5514 3.61805 12.2917C3.73256 12.2069 3.84457 12.1182 3.95279 12.027C6.58546 13.2583 9.44593 13.2583 12.0472 12.027C12.1566 12.1182 12.2686 12.2069 12.3819 12.2917C11.949 12.5527 11.4909 12.7763 11.014 12.9576C11.2644 13.4588 11.5538 13.937 11.881 14.3856C13.2024 13.9743 14.5464 13.3457 15.932 12.3097C16.2642 8.79176 15.3644 5.74164 13.5535 3.03729ZM5.34212 10.4434C4.55181 10.4434 3.9037 9.70563 3.9037 8.80718C3.9037 7.90873 4.53797 7.16966 5.34212 7.16966C6.14628 7.16966 6.79437 7.90743 6.78053 8.80718C6.78178 9.70563 6.14628 10.4434 5.34212 10.4434ZM10.6578 10.4434C9.86752 10.4434 9.21941 9.70563 9.21941 8.80718C9.21941 7.90873 9.85366 7.16966 10.6578 7.16966C11.462 7.16966 12.1101 7.90743 12.0962 8.80718C12.0962 9.70563 11.462 10.4434 10.6578 10.4434Z",
          fill: ""
        })
      }
    };
  });
  var DocumentIcon = /*#__PURE__*/createIconComponent("DocumentIcon", "oxygen-icon oxygen-icon-document", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3 1C2.44772 1 2 1.44772 2 2V14C2 14.5523 2.44772 15 3 15H13C13.5523 15 14 14.5523 14 14V2C14 1.44772 13.5523 1 13 1H3ZM1 2C1 0.89543 1.89543 0 3 0H13C14.1046 0 15 0.89543 15 2V14C15 15.1046 14.1046 16 13 16H3C1.89543 16 1 15.1046 1 14V2ZM4.5 4C4.22386 4 4 4.22386 4 4.5C4 4.77614 4.22386 5 4.5 5H11.5C11.7761 5 12 4.77614 12 4.5C12 4.22386 11.7761 4 11.5 4H4.5ZM4.5 10C4.22386 10 4 10.2239 4 10.5C4 10.7761 4.22386 11 4.5 11H11.5C11.7761 11 12 10.7761 12 10.5C12 10.2239 11.7761 10 11.5 10H4.5ZM4 7.5C4 7.22386 4.22386 7 4.5 7H11.5C11.7761 7 12 7.22386 12 7.5C12 7.77614 11.7761 8 11.5 8H4.5C4.22386 8 4 7.77614 4 7.5Z",
          fill: ""
        })
      }
    };
  });
  var DocumentCheckIcon = /*#__PURE__*/createIconComponent("DocumentCheckIcon", "oxygen-icon oxygen-icon-document-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0.5 2.5C0.5 1.11929 1.61929 0 3 0H10C11.3807 0 12.5 1.11929 12.5 2.5V6C12.5 6.27614 12.2761 6.5 12 6.5C11.7239 6.5 11.5 6.27614 11.5 6V2.5C11.5 1.67157 10.8284 1 10 1H3C2.17157 1 1.5 1.67157 1.5 2.5V13.5C1.5 14.3284 2.17157 15 3 15H5.5C5.77614 15 6 15.2239 6 15.5C6 15.7761 5.77614 16 5.5 16H3C1.61929 16 0.5 14.8807 0.5 13.5V2.5ZM3.5 4C3.5 3.72386 3.72386 3.5 4 3.5H9C9.27614 3.5 9.5 3.72386 9.5 4C9.5 4.27614 9.27614 4.5 9 4.5H4C3.72386 4.5 3.5 4.27614 3.5 4ZM4 6.5C3.72386 6.5 3.5 6.72386 3.5 7C3.5 7.27614 3.72386 7.5 4 7.5H9C9.27614 7.5 9.5 7.27614 9.5 7C9.5 6.72386 9.27614 6.5 9 6.5H4ZM3.5 10C3.5 9.72386 3.72386 9.5 4 9.5H6C6.27614 9.5 6.5 9.72386 6.5 10C6.5 10.2761 6.27614 10.5 6 10.5H4C3.72386 10.5 3.5 10.2761 3.5 10ZM10.8536 15.3536L15.8536 10.3536C16.0488 10.1583 16.0488 9.84171 15.8536 9.64645C15.6583 9.45118 15.3417 9.45118 15.1464 9.64645L10.5 14.2929L7.85355 11.6464C7.65829 11.4512 7.34171 11.4512 7.14645 11.6464C6.95118 11.8417 6.95118 12.1583 7.14645 12.3536L10.1464 15.3536L10.5 15.7071L10.8536 15.3536Z",
          fill: ""
        })
      }
    };
  });
  var DocumentGearIcon = /*#__PURE__*/createIconComponent("DocumentGearIcon", "oxygen-icon oxygen-icon-document-gear", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M1 2.5C1 1.11929 2.11929 0 3.5 0H10.5C11.8807 0 13 1.11929 13 2.5V5C13 5.27614 12.7761 5.5 12.5 5.5C12.2239 5.5 12 5.27614 12 5V2.5C12 1.67157 11.3284 1 10.5 1H3.5C2.67157 1 2 1.67157 2 2.5V13.5C2 14.3284 2.67157 15 3.5 15H6C6.27614 15 6.5 15.2239 6.5 15.5C6.5 15.7761 6.27614 16 6 16H3.5C2.11929 16 1 14.8807 1 13.5V2.5ZM4 4C4 3.72386 4.22386 3.5 4.5 3.5H9.5C9.77614 3.5 10 3.72386 10 4C10 4.27614 9.77614 4.5 9.5 4.5H4.5C4.22386 4.5 4 4.27614 4 4ZM4.5 6.5C4.22386 6.5 4 6.72386 4 7C4 7.27614 4.22386 7.5 4.5 7.5H7.5C7.77614 7.5 8 7.27614 8 7C8 6.72386 7.77614 6.5 7.5 6.5H4.5ZM4 10C4 9.72386 4.22386 9.5 4.5 9.5H5.5C5.77614 9.5 6 9.72386 6 10C6 10.2761 5.77614 10.5 5.5 10.5H4.5C4.22386 10.5 4 10.2761 4 10ZM12.5532 7.67V7.91723L12.6346 7.94155C12.8349 8.00535 13.029 8.08594 13.2151 8.18232L13.2881 8.22208L13.4634 8.04721C13.6889 7.82166 14.0386 7.78862 14.3118 7.96719L14.3621 8.00315L14.4112 8.04721L14.9528 8.58883C15.1924 8.82847 15.2148 9.20825 14.9968 9.48759L14.9529 9.53657L14.7775 9.71149L14.8177 9.78493C14.9141 9.97102 14.9947 10.1651 15.0584 10.3654L15.0824 10.4464L15.3298 10.4468C15.6519 10.4468 15.9245 10.6751 15.988 10.9979L15.9969 11.0558L16 11.117V11.883C16 12.2241 15.744 12.5096 15.391 12.5501L15.3298 12.5532L15.0824 12.5528L15.0585 12.6343C14.9947 12.8347 14.9141 13.0288 14.8177 13.215L14.7775 13.2877L14.9528 13.4634C15.1991 13.7097 15.2136 14.1001 14.9963 14.3634L14.9528 14.4112L14.4112 14.9528C14.1494 15.2145 13.7251 15.2145 13.4634 14.9529L13.2877 14.7775L13.215 14.8177C13.0288 14.9141 12.8347 14.9947 12.6343 15.0585L12.5528 15.0824L12.5532 15.3298C12.5532 15.6814 12.2824 15.9698 11.9379 15.9978L11.883 16H11.117C10.7469 16 10.4468 15.6999 10.4468 15.33L10.4464 15.0824L10.3654 15.0584C10.1651 14.9947 9.97102 14.9141 9.78493 14.8177L9.71149 14.7775L9.53665 14.9528C9.29031 15.1991 8.89992 15.2136 8.63664 14.9963L8.58883 14.9528L8.04721 14.4112C7.78548 14.1494 7.78548 13.7251 8.04713 13.4634L8.22208 13.2877L8.18227 13.215C8.08586 13.0288 8.00526 12.8347 7.94145 12.6343L7.91723 12.5528L7.67021 12.5532C7.31857 12.5532 7.03018 12.2824 7.00222 11.9379L7 11.883V11.117C7 10.7469 7.30006 10.4468 7.67 10.4468L7.91723 10.4464L7.94155 10.3654C8.00535 10.1651 8.08594 9.97102 8.18232 9.78493L8.22208 9.71149L8.04721 9.53665C7.82166 9.3111 7.78862 8.96142 7.96719 8.68818L8.00315 8.63789L8.04721 8.58883L8.58883 8.04721C8.82847 7.80757 9.20825 7.78525 9.48759 8.00315L9.53657 8.04713L9.71187 8.22208L9.78502 8.18227C9.97118 8.08586 10.1653 8.00526 10.3657 7.94145L10.4468 7.91723V7.67021C10.4468 7.34805 10.6751 7.07547 10.9979 7.01204L11.0558 7.00305L11.117 7H11.883C12.2241 7 12.5096 7.25598 12.5501 7.60901L12.5532 7.67ZM11.735 8.52685L12.393 8.72326C12.5441 8.77183 12.6908 8.83271 12.8318 8.90523L13.4336 9.23279L13.9372 8.73028L14.2695 9.06261L13.7653 9.56557L14.0951 10.1688C14.1673 10.3092 14.2279 10.4554 14.2764 10.6059L14.4706 11.2637L15.1818 11.2648V11.7348L14.4694 11.7337L14.2761 12.3948C14.2279 12.5445 14.1676 12.6899 14.0959 12.8296L13.764 13.4304L14.2697 13.9372L13.9372 14.2697L13.4304 13.764L12.8296 14.0959C12.6899 14.1676 12.5445 14.2279 12.3948 14.2761L11.7337 14.4694L11.7348 15.1818H11.2648L11.2637 14.4706L10.6059 14.2764C10.4554 14.2279 10.3092 14.1673 10.1688 14.0951L9.56557 13.7653L9.06261 14.2695L8.73017 13.937L9.23344 13.4317L8.9048 12.831C8.83251 12.6903 8.7718 12.544 8.72334 12.3932L8.52743 11.7337L7.81818 11.7348V11.2648L8.52631 11.2637L8.72312 10.6075C8.77179 10.4559 8.83285 10.3088 8.90561 10.1675L9.23214 9.56438L8.73039 9.06273L9.06284 8.73028L9.56635 9.23278L10.1683 8.90519C10.3093 8.83265 10.4561 8.77176 10.6073 8.72319L11.265 8.52689V7.81818H11.735V8.52685ZM13.1875 11.5C13.1875 12.432 12.432 13.1875 11.5 13.1875C10.568 13.1875 9.8125 12.432 9.8125 11.5C9.8125 10.568 10.568 9.8125 11.5 9.8125C12.432 9.8125 13.1875 10.568 13.1875 11.5ZM12.3693 11.5C12.3693 11.9801 11.9801 12.3693 11.5 12.3693C11.0199 12.3693 10.6307 11.9801 10.6307 11.5C10.6307 11.0199 11.0199 10.6307 11.5 10.6307C11.9801 10.6307 12.3693 11.0199 12.3693 11.5Z",
          fill: ""
        })
      }
    };
  });
  var DocumentPenIcon = /*#__PURE__*/createIconComponent("DocumentPenIcon", "oxygen-icon oxygen-icon-document-pen", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_1138_37)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11.8761 6.43545L6.81904 11.9344L6 15.9821L9.90239 15.0222L14.9712 9.5491C15.7967 8.65771 15.7662 7.27213 14.902 6.41801C14.0617 5.58722 12.7068 5.59503 11.8761 6.43545ZM14.1896 7.33224C14.5239 7.75487 14.5079 8.36738 14.1327 8.77254L9.28205 14.008L7.31633 14.5543L7.85348 12.4971L12.6961 7.23146C13.0759 6.84736 13.7071 6.84371 14.0986 7.23078L14.1896 7.33224Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11 0C12.1046 0 13 0.839466 13 1.875V4.5L12 5V1.875C12 1.39422 11.4973 1.05415 11 1H2C1.48716 1 1.06449 1.29941 1.00673 1.76567L1 1.875V13.125C1 13.6058 1.50266 13.9458 2 14H4.5C4.5 14.0417 4.49966 14.0831 4.49933 14.1241V14.1241V14.1241V14.1241V14.1241C4.4955 14.5923 4.49217 15 5 15H2C0.89543 15 0 14.1605 0 13.125V1.875C0 0.839466 0.89543 0 2 0H11ZM3.5 3.75C3.22386 3.75 3 3.95987 3 4.21875C3 4.47763 3.22386 4.6875 3.5 4.6875H7.5C7.77614 4.6875 8 4.47763 8 4.21875C8 3.95987 7.77614 3.75 7.5 3.75H3.5ZM3 7.03125C3 6.77237 3.22386 6.5625 3.5 6.5625H4.5C4.77614 6.5625 5 6.77237 5 7.03125C5 7.29013 4.77614 7.5 4.5 7.5H3.5C3.22386 7.5 3 7.29013 3 7.03125ZM3.5 9.375C3.22386 9.375 3 9.58487 3 9.84375C3 10.1026 3.22386 10.3125 3.5 10.3125C3.77614 10.3125 4 10.1026 4 9.84375C4 9.58487 3.77614 9.375 3.5 9.375Z",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_1138_37"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "16",
          height: "16",
          fill: "white"
        }))))
      }
    };
  });
  var DocumentPencilIcon = /*#__PURE__*/createIconComponent("DocumentPencilIcon", "oxygen-icon oxygen-icon-document-pencil", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.2279 15.734C10.2093 15.7537 10.19 15.7725 10.1699 15.7902C10.1504 15.8075 10.1301 15.8238 10.1093 15.839C9.98889 15.9275 9.84864 15.9818 9.70204 15.9962C9.67609 15.9987 9.64994 16 9.62367 16H7.28545C7.26195 16 7.23874 15.9987 7.21587 15.9962C6.90439 15.9617 6.65686 15.6986 6.62445 15.3676C6.62207 15.3433 6.62085 15.3186 6.62085 15.2936V12.8085C6.62085 12.7806 6.62206 12.7528 6.62445 12.7252C6.63795 12.5694 6.68908 12.4204 6.77229 12.2923C6.78666 12.2702 6.80199 12.2487 6.81824 12.228C6.8349 12.2067 6.85254 12.1861 6.87112 12.1663L11.948 6.77044C12.875 5.78526 14.3779 5.78526 15.3048 6.77044C16.2317 7.75562 16.2317 9.35291 15.3048 10.3381L12.7663 13.036L10.2279 15.734ZM7.57028 13.1459L9.30626 14.9909H7.57028L7.57028 13.1459ZM10.1166 14.4252L14.6334 9.62456C15.1896 9.03346 15.1896 8.07508 14.6334 7.48397C14.0773 6.89286 13.1756 6.89286 12.6194 7.48397L8.10259 12.2846L10.1166 14.4252Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11 0C12.1046 0 13 0.839466 13 1.875V4.5L12 5V1.875C12 1.39422 11.4973 1.05415 11 1H2C1.48716 1 1.06449 1.29941 1.00673 1.76567L1 1.875V13.125C1 13.6058 1.50266 13.9458 2 14H4.5C4.5 14.0417 4.49966 14.0831 4.49933 14.1241V14.1241V14.1241V14.1241V14.1241C4.4955 14.5923 4.49217 15 5 15H2C0.89543 15 0 14.1605 0 13.125V1.875C0 0.839466 0.89543 0 2 0H11ZM3.5 3.75C3.22386 3.75 3 3.95987 3 4.21875C3 4.47763 3.22386 4.6875 3.5 4.6875H7.5C7.77614 4.6875 8 4.47763 8 4.21875C8 3.95987 7.77614 3.75 7.5 3.75H3.5ZM3 7.03125C3 6.77237 3.22386 6.5625 3.5 6.5625H4.5C4.77614 6.5625 5 6.77237 5 7.03125C5 7.29013 4.77614 7.5 4.5 7.5H3.5C3.22386 7.5 3 7.29013 3 7.03125ZM3.5 9.375C3.22386 9.375 3 9.58487 3 9.84375C3 10.1026 3.22386 10.3125 3.5 10.3125C3.77614 10.3125 4 10.1026 4 9.84375C4 9.58487 3.77614 9.375 3.5 9.375Z",
          fill: ""
        }))
      }
    };
  });
  var DownloadIcon = /*#__PURE__*/createIconComponent("DownloadIcon", "oxygen-icon oxygen-icon-download", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8 0C8.25773 0 8.46667 0.209867 8.46667 0.46875V10.1183L12.3367 6.23104C12.5189 6.04799 12.8144 6.04799 12.9966 6.23104C13.1789 6.4141 13.1789 6.7109 12.9966 6.89396L8 11.9129L3.00335 6.89396C2.82111 6.7109 2.82111 6.4141 3.00335 6.23104C3.1856 6.04799 3.48107 6.04799 3.66332 6.23104L7.53333 10.1183V0.46875C7.53333 0.209867 7.74227 0 8 0ZM1.46667 12.6562C1.7244 12.6562 1.93333 12.8661 1.93333 13.125C1.93333 13.6428 2.3512 14.0625 2.86667 14.0625H13.1333C13.6488 14.0625 14.0667 13.6428 14.0667 13.125C14.0667 12.8661 14.2756 12.6562 14.5333 12.6562C14.7911 12.6562 15 12.8661 15 13.125C15 14.1605 14.1643 15 13.1333 15H2.86667C1.83574 15 1 14.1605 1 13.125C1 12.8661 1.20893 12.6562 1.46667 12.6562Z",
          fill: ""
        })
      }
    };
  });
  var DrawingPencilIcon = /*#__PURE__*/createIconComponent("DrawingPencilIcon", "oxygen-icon oxygen-icon-drawing-pencil", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M9.89732 9.65168C9.87768 9.67132 9.85723 9.68996 9.83604 9.70758C9.81536 9.72477 9.79399 9.74097 9.77199 9.75617C9.64464 9.84414 9.49637 9.89821 9.34136 9.91248C9.31393 9.915 9.28628 9.91628 9.2585 9.91628H6.78639C6.76154 9.91628 6.737 9.91499 6.71282 9.91248C6.38351 9.87821 6.1218 9.61651 6.08753 9.2872C6.08502 9.26301 6.08373 9.23847 6.08373 9.21362V6.74151C6.08373 6.71373 6.085 6.68608 6.08753 6.65864C6.1018 6.50364 6.15587 6.35537 6.24384 6.22802C6.25903 6.20603 6.27524 6.18466 6.29242 6.16398C6.31004 6.14279 6.32869 6.12234 6.34833 6.10269L11.716 0.735018C12.696 -0.245006 14.285 -0.245006 15.265 0.735018C16.245 1.71504 16.245 3.30398 15.265 4.28401L9.89732 9.65168ZM7.08753 7.07709L8.92292 8.91248H7.08753L7.08753 7.07709ZM9.77972 8.34968L14.5552 3.57421C15.1432 2.98619 15.1432 2.03283 14.5552 1.44482C13.9672 0.856801 13.0138 0.856801 12.4258 1.44482L7.65033 6.22029L9.77972 8.34968ZM4.11082 10.981C4.11082 10.7038 3.88611 10.4791 3.60892 10.4791H1.75666C0.786483 10.4791 0 11.2655 0 12.2357C0 13.2059 0.786483 13.9924 1.75666 13.9924H11.5438C11.821 13.9924 12.0457 14.2171 12.0457 14.4943C12.0457 14.7715 11.821 14.9962 11.5438 14.9962H7.02664C6.74945 14.9962 6.52474 15.2209 6.52474 15.4981C6.52474 15.7753 6.74945 16 7.02664 16H11.5438C12.3753 16 13.0495 15.3259 13.0495 14.4943C13.0495 13.6627 12.3753 12.9886 11.5438 12.9886H1.75666C1.34087 12.9886 1.00381 12.6515 1.00381 12.2357C1.00381 11.8199 1.34087 11.4829 1.75666 11.4829H3.60892C3.88611 11.4829 4.11082 11.2582 4.11082 10.981Z",
          fill: ""
        })
      }
    };
  });
  var EclipseIcon = /*#__PURE__*/createIconComponent("EclipseIcon", "oxygen-icon oxygen-icon-eclipse", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8.5 0.5C8.5 0.223858 8.27614 0 8 0C7.72386 0 7.5 0.223858 7.5 0.5V1.5C7.5 1.77614 7.72386 2 8 2C8.27614 2 8.5 1.77614 8.5 1.5V0.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8.5 14.5C8.5 14.2239 8.27614 14 8 14C7.72386 14 7.5 14.2239 7.5 14.5V15.5C7.5 15.7761 7.72386 16 8 16C8.27614 16 8.5 15.7761 8.5 15.5V14.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2 8C2 8.27614 1.77614 8.5 1.5 8.5H0.5C0.223858 8.5 0 8.27614 0 8C0 7.72386 0.223858 7.5 0.5 7.5H1.5C1.77614 7.5 2 7.72386 2 8Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M15.5 8.5C15.7761 8.5 16 8.27614 16 8C16 7.72386 15.7761 7.5 15.5 7.5H14.5C14.2239 7.5 14 7.72386 14 8C14 8.27614 14.2239 8.5 14.5 8.5H15.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.4464 3.54647C12.2512 3.35121 12.2512 3.03463 12.4464 2.83936L13.1535 2.13226C13.3488 1.937 13.6654 1.937 13.8606 2.13226C14.0559 2.32752 14.0559 2.6441 13.8606 2.83936L13.1535 3.54647C12.9583 3.74173 12.6417 3.74173 12.4464 3.54647Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.14645 2.86065C1.95118 2.66539 1.95118 2.3488 2.14645 2.15354C2.34171 1.95828 2.65829 1.95828 2.85355 2.15354L3.56066 2.86065C3.75592 3.05591 3.75592 3.37249 3.56066 3.56775C3.3654 3.76302 3.04882 3.76302 2.85355 3.56775L2.14645 2.86065Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.14645 13.8465C1.95118 13.6512 1.95118 13.3346 2.14645 13.1394L2.85355 12.4322C3.04882 12.237 3.3654 12.237 3.56066 12.4322C3.75592 12.6275 3.75592 12.9441 3.56066 13.1394L2.85355 13.8465C2.65829 14.0417 2.34171 14.0417 2.14645 13.8465Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.4464 13.1606C12.2512 12.9654 12.2512 12.6488 12.4464 12.4535C12.6417 12.2583 12.9583 12.2583 13.1535 12.4535L13.8606 13.1606C14.0559 13.3559 14.0559 13.6725 13.8606 13.8677C13.6654 14.063 13.3488 14.063 13.1535 13.8677L12.4464 13.1606Z",
          fill: ""
        }))
      }
    };
  });
  var EllipsisIcon = /*#__PURE__*/createIconComponent("EllipsisIcon", "oxygen-icon oxygen-icon-ellipsis", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M13 9C13.8284 9 14.5 8.32843 14.5 7.5C14.5 6.67157 13.8284 6 13 6C12.1716 6 11.5 6.67157 11.5 7.5C11.5 8.32843 12.1716 9 13 9Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8 9C8.82843 9 9.5 8.32843 9.5 7.5C9.5 6.67157 8.82843 6 8 6C7.17157 6 6.5 6.67157 6.5 7.5C6.5 8.32843 7.17157 9 8 9Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M3 9C3.82843 9 4.5 8.32843 4.5 7.5C4.5 6.67157 3.82843 6 3 6C2.17157 6 1.5 6.67157 1.5 7.5C1.5 8.32843 2.17157 9 3 9Z",
          fill: ""
        }))
      }
    };
  });
  var EllipsisVerticalIcon = /*#__PURE__*/createIconComponent("EllipsisVerticalIcon", "oxygen-icon oxygen-icon-ellipsis-vertical", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.5 13C6.5 13.8284 7.17157 14.5 8 14.5C8.82843 14.5 9.5 13.8284 9.5 13C9.5 12.1716 8.82843 11.5 8 11.5C7.17157 11.5 6.5 12.1716 6.5 13Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.5 8C6.5 8.82843 7.17157 9.5 8 9.5C8.82843 9.5 9.5 8.82843 9.5 8C9.5 7.17157 8.82843 6.5 8 6.5C7.17157 6.5 6.5 7.17157 6.5 8Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.5 3C6.5 3.82843 7.17157 4.5 8 4.5C8.82843 4.5 9.5 3.82843 9.5 3C9.5 2.17157 8.82843 1.5 8 1.5C7.17157 1.5 6.5 2.17157 6.5 3Z",
          fill: ""
        }))
      }
    };
  });
  var EnvelopeIcon = /*#__PURE__*/createIconComponent("EnvelopeIcon", "oxygen-icon oxygen-icon-envelope", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 2C0.895431 2 0 2.89543 0 4V12C0 13.1046 0.895431 14 2 14H14C15.1046 14 16 13.1046 16 12V6.5V6.49418V6.48837V6.48257V6.47677V6.47098V6.4652V6.45942V6.45365V6.44788V6.44212V6.43637V6.43062V6.42488V6.41915V6.41342V6.4077V6.40198V6.39627V6.39057V6.38487V6.37918V6.37349V6.36781V6.36214V6.35647V6.35081V6.34515V6.3395V6.33385V6.32822V6.32258V6.31696V6.31133V6.30572V6.30011V6.29451V6.28891V6.28332V6.27773V6.27215V6.26658V6.26101V6.25544V6.24989V6.24433V6.23879V6.23325V6.22771V6.22218V6.21666V6.21114V6.20563V6.20012V6.19462V6.18912V6.18363V6.17814V6.17266V6.16719V6.16172V6.15626V6.1508V6.14534V6.1399V6.13445V6.12902V6.12359V6.11816V6.11274V6.10732V6.10191V6.09651V6.09111V6.08571V6.08032V6.07494V6.06956V6.06418V6.05881V6.05345V6.04809V6.04274V6.03739V6.03204V6.0267V6.02137V6.01604V6.01072V6.0054V6.00009V5.99478V5.98947V5.98417V5.97888V5.97359V5.96831V5.96303V5.95775V5.95248V5.94721V5.94195V5.9367V5.93145V5.9262V5.92096V5.91572V5.91049V5.90526V5.90004V5.89482V5.88961V5.8844V5.87919V5.87399V5.8688V5.86361V5.85842V5.85324V5.84806V5.84289V5.83772V5.83256V5.8274V5.82224V5.81709V5.81194V5.8068V5.80167V5.79653V5.7914V5.78628V5.78116V5.77604V5.77093V5.76582V5.76072V5.75562V5.75052V5.74543V5.74035V5.73526V5.73019V5.72511V5.72004V5.71497V5.70991V5.70485V5.6998V5.69475V5.6897V5.68466V5.67962V5.67459V5.66956V5.66453V5.65951V5.65449V5.64948V5.64447V5.63946V5.63446V5.62946V5.62446V5.61947V5.61448V5.6095V5.60452V5.59954V5.59457V5.5896V5.58463V5.57967V5.57471V5.56976V5.56481V5.55986V5.55491V5.54997V5.54504V5.5401V5.53517V5.53025V5.52532V5.52041V5.51549V5.51058V5.50567V5.50076V5.49586V5.49096V5.48606V5.48117V5.47628V5.4714V5.46652V5.46164V5.45676V5.45189V5.44702V5.44215V5.43729V5.43243V5.42757V5.42272V5.41787V5.41302V5.40818V5.40334V5.3985V5.39366V5.38883V5.384V5.37918V5.37435V5.36953V5.36472V5.3599V5.35509V5.35028V5.34548V5.34068V5.33588V5.33108V5.32629V5.3215V5.31671V5.31192V5.30714V5.30236V5.29758V5.29281V5.28804V5.28327V5.2785V5.27374V5.26898V5.26422V5.25946V5.25471V5.24996V5.24521V5.24046V5.23572V5.23098V5.22624V5.22151V5.21677V5.21204V5.20731V5.20259V5.19787V5.19315V5.18843V5.18371V5.179V5.17428V5.16958V5.16487V5.16016V5.15546V5.15076V5.14606V5.14137V5.13667V5.13198V5.12729V5.12261V5.11792V5.11324V5.10856V5.10388V5.0992V5.09453V5.08986V5.08519V5.08052V5.07585V5.07119V5.06653V5.06187V5.05721V5.05255V5.0479V5.04324V5.03859V5.03394V5.0293V5.02465V5.02001V5.01537V5.01073V5.00609V5.00145V4.99682V4.99218V4.98755V4.98292V4.9783V4.97367V4.96904V4.96442V4.9598V4.95518V4.95056V4.94595V4.94133V4.93672V4.9321V4.92749V4.92288V4.91828V4.91367V4.90907V4.90446V4.89986V4.89526V4.89066V4.88606V4.88147V4.87687V4.87228V4.86768V4.86309V4.8585V4.85391V4.84933V4.84474V4.84015V4.83557V4.83099V4.8264V4.82182V4.81724V4.81267V4.80809V4.80351V4.79894V4.79436V4.78979V4.78522V4.78065V4.77608V4.77151V4.76694V4.76237V4.7578V4.75324V4.74867V4.74411V4.73955V4.73498V4.73042V4.72586V4.7213V4.71674V4.71219V4.70763V4.70307V4.69851V4.69396V4.6894V4.68485V4.6803V4.67574V4.67119V4.66664V4.66209V4.65754V4.65299V4.64844V4.64389V4.63934V4.63479V4.63025V4.6257V4.62115V4.61661V4.61206V4.60752V4.60297V4.59843V4.59388V4.58934V4.58479V4.58025V4.57571V4.57116V4.56662V4.56208V4.55754V4.553V4.54845V4.54391V4.53937V4.53483V4.53029V4.52575V4.52121V4.51667V4.51212V4.50758V4.50304V4.4985V4.49396V4.48942V4.48488V4.48034V4.4758V4.47126V4.46672V4.46217V4.45763V4.45309V4.44855V4.44401V4.43947V4.43492V4.43038V4.42584V4.4213V4.41675V4.41221V4.40767V4.40312V4.39858V4.39403V4.38949V4.38494V4.38039V4.37585V4.3713V4.36675V4.36221V4.35766V4.35311V4.34856V4.34401V4.33946V4.33491V4.33036V4.32581V4.32125V4.3167V4.31215V4.30759V4.30304V4.29848V4.29392V4.28937V4.28481V4.28025V4.27569V4.27113V4.26657V4.26201V4.25744V4.25288V4.24832V4.24375V4.23918V4.23462V4.23005V4.22548V4.22091V4.21634V4.21177V4.20719V4.20262V4.19805V4.19347V4.18889V4.18431V4.17974V4.17516V4.17057V4.16599V4.16141V4.15682V4.15224V4.14765V4.14306V4.13847V4.13388V4.12929V4.12469V4.1201V4.1155V4.11091V4.10631V4.10171V4.09711V4.0925V4.0879V4.08329V4.07868V4.07408V4.06947V4.06485V4.06024V4.05563V4.05101V4.04639V4.04177V4.03715V4.03253V4.02791V4.02328V4.01865V4.01402V4.00939V4.00476V4.00013C16 2.89561 15.1046 2 14 2H2ZM1.41982 3.18542C1.58343 3.06868 1.78369 3 2 3H14C14.2163 3 14.4165 3.06869 14.5802 3.18544L8 7.88555L1.41982 3.18542ZM1 4.11445V12C1 12.5523 1.44772 13 2 13H14C14.5523 13 15 12.5523 15 12V6.5V6.49418V6.48837V6.48257V6.47677V6.47098V6.4652V6.45942V6.45365V6.44788V6.44212V6.43637V6.43062V6.42488V6.41915V6.41342V6.4077V6.40198V6.39627V6.39057V6.38487V6.37918V6.37349V6.36781V6.36214V6.35647V6.35081V6.34515V6.3395V6.33385V6.32822V6.32258V6.31696V6.31133V6.30572V6.30011V6.29451V6.28891V6.28332V6.27773V6.27215V6.26658V6.26101V6.25544V6.24989V6.24433V6.23879V6.23325V6.22771V6.22218V6.21666V6.21114V6.20563V6.20012V6.19462V6.18912V6.18363V6.17814V6.17266V6.16719V6.16172V6.15626V6.1508V6.14534V6.1399V6.13445V6.12902V6.12359V6.11816V6.11274V6.10732V6.10191V6.09651V6.09111V6.08571V6.08032V6.07494V6.06956V6.06418V6.05881V6.05345V6.04809V6.04274V6.03739V6.03204V6.0267V6.02137V6.01604V6.01072V6.0054V6.00009V5.99478V5.98947V5.98417V5.97888V5.97359V5.96831V5.96303V5.95775V5.95248V5.94721V5.94195V5.9367V5.93145V5.9262V5.92096V5.91572V5.91049V5.90526V5.90004V5.89482V5.88961V5.8844V5.87919V5.87399V5.8688V5.86361V5.85842V5.85324V5.84806V5.84289V5.83772V5.83256V5.8274V5.82224V5.81709V5.81194V5.8068V5.80167V5.79653V5.7914V5.78628V5.78116V5.77604V5.77093V5.76582V5.76072V5.75562V5.75052V5.74543V5.74035V5.73526V5.73019V5.72511V5.72004V5.71497V5.70991V5.70485V5.6998V5.69475V5.6897V5.68466V5.67962V5.67459V5.66956V5.66453V5.65951V5.65449V5.64948V5.64447V5.63946V5.63446V5.62946V5.62446V5.61947V5.61448V5.6095V5.60452V5.59954V5.59457V5.5896V5.58463V5.57967V5.57471V5.56976V5.56481V5.55986V5.55491V5.54997V5.54504V5.5401V5.53517V5.53025V5.52532V5.52041V5.51549V5.51058V5.50567V5.50076V5.49586V5.49096V5.48606V5.48117V5.47628V5.4714V5.46652V5.46164V5.45676V5.45189V5.44702V5.44215V5.43729V5.43243V5.42757V5.42272V5.41787V5.41302V5.40818V5.40334V5.3985V5.39366V5.38883V5.384V5.37918V5.37435V5.36953V5.36472V5.3599V5.35509V5.35028V5.34548V5.34068V5.33588V5.33108V5.32629V5.3215V5.31671V5.31192V5.30714V5.30236V5.29758V5.29281V5.28804V5.28327V5.2785V5.27374V5.26898V5.26422V5.25946V5.25471V5.24996V5.24521V5.24046V5.23572V5.23098V5.22624V5.22151V5.21677V5.21204V5.20731V5.20259V5.19787V5.19315V5.18843V5.18371V5.179V5.17428V5.16958V5.16487V5.16016V5.15546V5.15076V5.14606V5.14137V5.13667V5.13198V5.12729V5.12261V5.11792V5.11324V5.10856V5.10388V5.0992V5.09453V5.08986V5.08519V5.08052V5.07585V5.07119V5.06653V5.06187V5.05721V5.05255V5.0479V5.04324V5.03859V5.03394V5.0293V5.02465V5.02001V5.01537V5.01073V5.00609V5.00145V4.99682V4.99218V4.98755V4.98292V4.9783V4.97367V4.96904V4.96442V4.9598V4.95518V4.95056V4.94595V4.94133V4.93672V4.9321V4.92749V4.92288V4.91828V4.91367V4.90907V4.90446V4.89986V4.89526V4.89066V4.88606V4.88147V4.87687V4.87228V4.86768V4.86309V4.8585V4.85391V4.84933V4.84474V4.84015V4.83557V4.83099V4.8264V4.82182V4.81724V4.81267V4.80809V4.80351V4.79894V4.79436V4.78979V4.78522V4.78065V4.77608V4.77151V4.76694V4.76237V4.7578V4.75324V4.74867V4.74411V4.73955V4.73498V4.73042V4.72586V4.7213V4.71674V4.71219V4.70763V4.70307V4.69851V4.69396V4.6894V4.68485V4.6803V4.67574V4.67119V4.66664V4.66209V4.65754V4.65299V4.64844V4.64389V4.63934V4.63479V4.63025V4.6257V4.62115V4.61661V4.61206V4.60752V4.60297V4.59843V4.59388V4.58934V4.58479V4.58025V4.57571V4.57116V4.56662V4.56208V4.55754V4.553V4.54845V4.54391V4.53937V4.53483V4.53029V4.52575V4.52121V4.51667V4.51212V4.50758V4.50304V4.4985V4.49396V4.48942V4.48488V4.48034V4.4758V4.47126V4.46672V4.46217V4.45763V4.45309V4.44855V4.44401V4.43947V4.43492V4.43038V4.42584V4.4213V4.41675V4.41221V4.40767V4.40312V4.39858V4.39403V4.38949V4.38494V4.38039V4.37585V4.3713V4.36675V4.36221V4.35766V4.35311V4.34856V4.34401V4.33946V4.33491V4.33036V4.32581V4.32125V4.3167V4.31215V4.30759V4.30304V4.29848V4.29392V4.28937V4.28481V4.28025V4.27569V4.27113V4.26657V4.26201V4.25744V4.25288V4.24832V4.24375V4.23918V4.23462V4.23005V4.22548V4.22091V4.21634V4.21177V4.20719V4.20262V4.19805V4.19347V4.18889V4.18431V4.17974V4.17516V4.17057V4.16599V4.16141V4.15682V4.15224V4.14765V4.14306V4.13847V4.13388V4.12929V4.12469V4.1201V4.1155V4.11445L8.58124 8.69928C8.23354 8.94764 7.76646 8.94764 7.41876 8.69928L1 4.11445Z",
          fill: ""
        })
      }
    };
  });
  var EnvelopeAsteriskIcon = /*#__PURE__*/createIconComponent("EnvelopeAsteriskIcon", "oxygen-icon oxygen-icon-envelope-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 4C0 2.89543 0.895431 2 2 2H14C15.1046 2 16 2.89561 16 4.00013V4.00476V4.00939V4.01402V4.01865V4.02328V4.02791V4.03253V4.03715V4.04177V4.04639V4.05101V4.05563V4.06024V4.06485V4.06947V4.07408V4.07868V4.08329V4.0879V4.0925V4.09711V4.10171V4.10631V4.11091V4.1155V4.1201V4.12469V4.12929V4.13388V4.13847V4.14306V4.14765V4.15224V4.15682V4.16141V4.16599V4.17057V4.17516V4.17974V4.18431V4.18889V4.19347V4.19805V4.20262V4.20719V4.21177V4.21634V4.22091V4.22548V4.23005V4.23462V4.23918V4.24375V4.24832V4.25288V4.25744V4.26201V4.26657V4.27113V4.27569V4.28025V4.28481V4.28937V4.29392V4.29848V4.30304V4.30759V4.31215V4.3167V4.32125V4.32581V4.33036V4.33491V4.33946V4.34401V4.34856V4.35311V4.35766V4.36221V4.36675V4.3713V4.37585V4.38039V4.38494V4.38949V4.39403V4.39858V4.40312V4.40767V4.41221V4.41675V4.4213V4.42584V4.43038V4.43492V4.43947V4.44401V4.44855V4.45309V4.45763V4.46217V4.46672V4.47126V4.4758V4.48034V4.48488V4.48942V4.49396V4.4985V4.50304V4.50758V4.51212V4.51667V4.52121V4.52575V4.53029V4.53483V4.53937V4.54391V4.54845V4.553V4.55754V4.56208V4.56662V4.57116V4.57571V4.58025V4.58479V4.58934V4.59388V4.59843V4.60297V4.60752V4.61206V4.61661V4.62115V4.6257V4.63025V4.63479V4.63934V4.64389V4.64844V4.65299V4.65754V4.66209V4.66664V4.67119V4.67574V4.6803V4.68485V4.6894V4.69396V4.69851V4.70307V4.70763V4.71219V4.71674V4.7213V4.72586V4.73042V4.73498V4.73955V4.74411V4.74867V4.75324V4.7578V4.76237V4.76694V4.77151V4.77608V4.78065V4.78522V4.78979V4.79436V4.79894V4.80351V4.80809V4.81267V4.81724V4.82182V4.8264V4.83099V4.83557V4.84015V4.84474V4.84933V4.85391V4.8585V4.86309V4.86768V4.87228V4.87687V4.88147V4.88606V4.89066V4.89526V4.89986V4.90446V4.90907V4.91367V4.91828V4.92288V4.92749V4.9321V4.93672V4.94133V4.94595V4.95056V4.95518V4.9598V4.96442V4.96904V4.97367V4.9783V4.98292V4.98755V4.99218V4.99682V5.00145V5.00609V5.01073V5.01537V5.02001V5.02465V5.0293V5.03394V5.03859V5.04324V5.0479V5.05255V5.05721V5.06187V5.06653V5.07119V5.07585V5.08052V5.08519V5.08986V5.09453V5.0992V5.10388V5.10856V5.11324V5.11792V5.12261V5.12729V5.13198V5.13667V5.14137V5.14606V5.15076V5.15546V5.16016V5.16487V5.16958V5.17428V5.179V5.18371V5.18843V5.19315V5.19787V5.20259V5.20731V5.21204V5.21677V5.22151V5.22624V5.23098V5.23572V5.24046V5.24521V5.24996V5.25471V5.25946V5.26422V5.26898V5.27374V5.2785V5.28327V5.28804V5.29281V5.29758V5.30236V5.30714V5.31192V5.31671V5.3215V5.32629V5.33108V5.33588V5.34068V5.34548V5.35028V5.35509V5.3599V5.36472V5.36953V5.37435V5.37918V5.384V5.38883V5.39366V5.3985V5.40334V5.40818V5.41302V5.41787V5.42272V5.42757V5.43243V5.43729V5.44215V5.44702V5.45189V5.45676V5.46164V5.46652V5.4714V5.47628V5.48117V5.48606V5.49096V5.49586V5.50076V5.50567V5.51058V5.51549V5.52041V5.52532V5.53025V5.53517V5.5401V5.54504V5.54997V5.55491V5.55986V5.56481V5.56976V5.57471V5.57967V5.58463V5.5896V5.59457V5.59954V5.60452V5.6095V5.61448V5.61947V5.62446V5.62946V5.63446V5.63946V5.64447V5.64948V5.65449V5.65951V5.66453V5.66956V5.67459V5.67962V5.68466V5.6897V5.69475V5.6998V5.70485V5.70991V5.71497V5.72004V5.72511V5.73019V5.73526V5.74035V5.74543V5.75052V5.75562V5.76072V5.76582V5.77093V5.77604V5.78116V5.78628V5.7914V5.79653V5.80167V5.8068V5.81194V5.81709V5.82224V5.8274V5.83256V5.83772V5.84289V5.84806V5.85324V5.85842V5.86361V5.8688V5.87399V5.87919V5.8844V5.88961V5.89482V5.90004V5.90526V5.91049V5.91572V5.92096V5.9262V5.93145V5.9367V5.94195V5.94721V5.95248V5.95775V5.96303V5.96831V5.97359V5.97888V5.98417V5.98947V5.99478V6.00009V6.0054V6.01072V6.01604V6.02137V6.0267V6.03204V6.03739V6.04274V6.04809V6.05345V6.05881V6.06418V6.06956V6.07494V6.08032V6.08571V6.09111V6.09651V6.10191V6.10732V6.11274V6.11816V6.12359V6.12902V6.13445V6.1399V6.14534V6.1508V6.15626V6.16172V6.16719V6.17266V6.17814V6.18363V6.18912V6.19462V6.20012V6.20563V6.21114V6.21666V6.22218V6.22771V6.23325V6.23879V6.24433V6.24989V6.25544V6.26101V6.26658V6.27215V6.27773V6.28332V6.28891V6.29451V6.30011V6.30572V6.31133V6.31696V6.32258V6.32822V6.33385V6.3395V6.34515V6.35081V6.35647V6.36214V6.36781V6.37349V6.37918V6.38487V6.39057V6.39627V6.40198V6.4077V6.41342V6.41915V6.42488V6.43062V6.43637V6.44212V6.44788V6.45365V6.45942V6.4652V6.47098V6.47677V6.48257V6.48837V6.49418V6.5V9C16 9.27614 15.7761 9.5 15.5 9.5C15.2239 9.5 15 9.27614 15 9V6.5V6.49418V6.48837V6.48257V6.47677V6.47098V6.4652V6.45942V6.45365V6.44788V6.44212V6.43637V6.43062V6.42488V6.41915V6.41342V6.4077V6.40198V6.39627V6.39057V6.38487V6.37918V6.37349V6.36781V6.36214V6.35647V6.35081V6.34515V6.3395V6.33385V6.32822V6.32258V6.31696V6.31133V6.30572V6.30011V6.29451V6.28891V6.28332V6.27773V6.27215V6.26658V6.26101V6.25544V6.24989V6.24433V6.23879V6.23325V6.22771V6.22218V6.21666V6.21114V6.20563V6.20012V6.19462V6.18912V6.18363V6.17814V6.17266V6.16719V6.16172V6.15626V6.1508V6.14534V6.1399V6.13445V6.12902V6.12359V6.11816V6.11274V6.10732V6.10191V6.09651V6.09111V6.08571V6.08032V6.07494V6.06956V6.06418V6.05881V6.05345V6.04809V6.04274V6.03739V6.03204V6.0267V6.02137V6.01604V6.01072V6.0054V6.00009V5.99478V5.98947V5.98417V5.97888V5.97359V5.96831V5.96303V5.95775V5.95248V5.94721V5.94195V5.9367V5.93145V5.9262V5.92096V5.91572V5.91049V5.90526V5.90004V5.89482V5.88961V5.8844V5.87919V5.87399V5.8688V5.86361V5.85842V5.85324V5.84806V5.84289V5.83772V5.83256V5.8274V5.82224V5.81709V5.81194V5.8068V5.80167V5.79653V5.7914V5.78628V5.78116V5.77604V5.77093V5.76582V5.76072V5.75562V5.75052V5.74543V5.74035V5.73526V5.73019V5.72511V5.72004V5.71497V5.70991V5.70485V5.6998V5.69475V5.6897V5.68466V5.67962V5.67459V5.66956V5.66453V5.65951V5.65449V5.64948V5.64447V5.63946V5.63446V5.62946V5.62446V5.61947V5.61448V5.6095V5.60452V5.59954V5.59457V5.5896V5.58463V5.57967V5.57471V5.56976V5.56481V5.55986V5.55491V5.54997V5.54504V5.5401V5.53517V5.53025V5.52532V5.52041V5.51549V5.51058V5.50567V5.50076V5.49586V5.49096V5.48606V5.48117V5.47628V5.4714V5.46652V5.46164V5.45676V5.45189V5.44702V5.44215V5.43729V5.43243V5.42757V5.42272V5.41787V5.41302V5.40818V5.40334V5.3985V5.39366V5.38883V5.384V5.37918V5.37435V5.36953V5.36472V5.3599V5.35509V5.35028V5.34548V5.34068V5.33588V5.33108V5.32629V5.3215V5.31671V5.31192V5.30714V5.30236V5.29758V5.29281V5.28804V5.28327V5.2785V5.27374V5.26898V5.26422V5.25946V5.25471V5.24996V5.24521V5.24046V5.23572V5.23098V5.22624V5.22151V5.21677V5.21204V5.20731V5.20259V5.19787V5.19315V5.18843V5.18371V5.179V5.17428V5.16958V5.16487V5.16016V5.15546V5.15076V5.14606V5.14137V5.13667V5.13198V5.12729V5.12261V5.11792V5.11324V5.10856V5.10388V5.0992V5.09453V5.08986V5.08519V5.08052V5.07585V5.07119V5.06653V5.06187V5.05721V5.05255V5.0479V5.04324V5.03859V5.03394V5.0293V5.02465V5.02001V5.01537V5.01073V5.00609V5.00145V4.99682V4.99218V4.98755V4.98292V4.9783V4.97367V4.96904V4.96442V4.9598V4.95518V4.95056V4.94595V4.94133V4.93672V4.9321V4.92749V4.92288V4.91828V4.91367V4.90907V4.90446V4.89986V4.89526V4.89066V4.88606V4.88147V4.87687V4.87228V4.86768V4.86309V4.8585V4.85391V4.84933V4.84474V4.84015V4.83557V4.83099V4.8264V4.82182V4.81724V4.81267V4.80809V4.80351V4.79894V4.79436V4.78979V4.78522V4.78065V4.77608V4.77151V4.76694V4.76237V4.7578V4.75324V4.74867V4.74411V4.73955V4.73498V4.73042V4.72586V4.7213V4.71674V4.71219V4.70763V4.70307V4.69851V4.69396V4.6894V4.68485V4.6803V4.67574V4.67119V4.66664V4.66209V4.65754V4.65299V4.64844V4.64389V4.63934V4.63479V4.63025V4.6257V4.62115V4.61661V4.61206V4.60752V4.60297V4.59843V4.59388V4.58934V4.58479V4.58025V4.57571V4.57116V4.56662V4.56208V4.55754V4.553V4.54845V4.54391V4.53937V4.53483V4.53029V4.52575V4.52121V4.51667V4.51212V4.50758V4.50304V4.4985V4.49396V4.48942V4.48488V4.48034V4.4758V4.47126V4.46672V4.46217V4.45763V4.45309V4.44855V4.44401V4.43947V4.43492V4.43038V4.42584V4.4213V4.41675V4.41221V4.40767V4.40312V4.39858V4.39403V4.38949V4.38494V4.38039V4.37585V4.3713V4.36675V4.36221V4.35766V4.35311V4.34856V4.34401V4.33946V4.33491V4.33036V4.32581V4.32125V4.3167V4.31215V4.30759V4.30304V4.29848V4.29392V4.28937V4.28481V4.28025V4.27569V4.27113V4.26657V4.26201V4.25744V4.25288V4.24832V4.24375V4.23918V4.23462V4.23005V4.22548V4.22091V4.21634V4.21177V4.20719V4.20262V4.19805V4.19347V4.18889V4.18431V4.17974V4.17516V4.17057V4.16599V4.16141V4.15682V4.15224V4.14765V4.14306V4.13847V4.13388V4.12929V4.12469V4.1201V4.1155V4.11445L8.58124 8.69928C8.23354 8.94764 7.76646 8.94764 7.41876 8.69928L1 4.11445V12C1 12.5523 1.44772 13 2 13H4C4.27614 13 4.5 13.2239 4.5 13.5C4.5 13.7761 4.27614 14 4 14H2C0.89543 14 0 13.1046 0 12V4ZM14 3C14.2163 3 14.4165 3.06869 14.5802 3.18544L8 7.88555L1.41982 3.18542C1.58343 3.06868 1.78369 3 2 3H14ZM8.62718 11.3369C8.58208 10.8877 7.91792 10.8877 7.87282 11.3369L7.74264 12.6336L6.53863 12.0964C6.12154 11.9103 5.78945 12.4774 6.16145 12.7405L7.23528 13.5L6.16145 14.2595C5.78945 14.5226 6.12154 15.0897 6.53863 14.9036L7.74264 14.3664L7.87282 15.6631C7.91792 16.1123 8.58208 16.1123 8.62718 15.6631L8.75736 14.3664L9.96137 14.9036C10.3785 15.0897 10.7105 14.5226 10.3385 14.2595L9.26472 13.5L10.3385 12.7405C10.7105 12.4774 10.3785 11.9103 9.96137 12.0964L8.75736 12.6336L8.62718 11.3369ZM14.1272 11.3369C14.0821 10.8877 13.4179 10.8877 13.3728 11.3369L13.2426 12.6336L12.0386 12.0964C11.6215 11.9103 11.2895 12.4774 11.6615 12.7405L12.7353 13.5L11.6615 14.2595C11.2895 14.5226 11.6215 15.0897 12.0386 14.9036L13.2426 14.3664L13.3728 15.6631C13.4179 16.1123 14.0821 16.1123 14.1272 15.6631L14.2574 14.3664L15.4614 14.9036C15.8785 15.0897 16.2105 14.5226 15.8385 14.2595L14.7647 13.5L15.8385 12.7405C16.2105 12.4774 15.8785 11.9103 15.4614 12.0964L14.2574 12.6336L14.1272 11.3369Z",
          fill: ""
        })
      }
    };
  });
  var EnvelopeAtIcon = /*#__PURE__*/createIconComponent("EnvelopeAtIcon", "oxygen-icon oxygen-icon-envelope-at", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 2.5C0 1.39543 0.89543 0.5 2 0.5H11C12.1046 0.5 13 1.39561 13 2.50013V2.50476V2.50939V2.51402V2.51865V2.52328V2.52791V2.53253V2.53715V2.54177V2.54639V2.55101V2.55563V2.56024V2.56485V2.56947V2.57408V2.57868V2.58329V2.5879V2.5925V2.59711V2.60171V2.60631V2.61091V2.6155V2.6201V2.62469V2.62929V2.63388V2.63847V2.64306V2.64765V2.65224V2.65682V2.66141V2.66599V2.67057V2.67516V2.67974V2.68431V2.68889V2.69347V2.69805V2.70262V2.70719V2.71177V2.71634V2.72091V2.72548V2.73005V2.73462V2.73918V2.74375V2.74832V2.75288V2.75744V2.76201V2.76657V2.77113V2.77569V2.78025V2.78481V2.78937V2.79392V2.79848V2.80304V2.80759V2.81215V2.8167V2.82125V2.82581V2.83036V2.83491V2.83946V2.84401V2.84856V2.85311V2.85766V2.86221V2.86675V2.8713V2.87585V2.88039V2.88494V2.88949V2.89403V2.89858V2.90312V2.90767V2.91221V2.91675V2.9213V2.92584V2.93038V2.93492V2.93947V2.94401V2.94855V2.95309V2.95763V2.96217V2.96672V2.97126V2.9758V2.98034V2.98488V2.98942V2.99396V2.9985V3.00304V3.00758V3.01212V3.01667V3.02121V3.02575V3.03029V3.03483V3.03937V3.04391V3.04845V3.053V3.05754V3.06208V3.06662V3.07116V3.07571V3.08025V3.08479V3.08934V3.09388V3.09843V3.10297V3.10752V3.11206V3.11661V3.12115V3.1257V3.13025V3.13479V3.13934V3.14389V3.14844V3.15299V3.15754V3.16209V3.16664V3.17119V3.17574V3.1803V3.18485V3.1894V3.19396V3.19851V3.20307V3.20763V3.21219V3.21674V3.2213V3.22586V3.23042V3.23498V3.23955V3.24411V3.24867V3.25324V3.2578V3.26237V3.26694V3.27151V3.27608V3.28065V3.28522V3.28979V3.29436V3.29894V3.30351V3.30809V3.31267V3.31724V3.32182V3.3264V3.33099V3.33557V3.34015V3.34474V3.34933V3.35391V3.3585V3.36309V3.36768V3.37228V3.37687V3.38147V3.38606V3.39066V3.39526V3.39986V3.40446V3.40907V3.41367V3.41828V3.42288V3.42749V3.4321V3.43672V3.44133V3.44595V3.45056V3.45518V3.4598V3.46442V3.46904V3.47367V3.4783V3.48292V3.48755V3.49218V3.49682V3.50145V3.50609V3.51073V3.51537V3.52001V3.52465V3.5293V3.53394V3.53859V3.54324V3.5479V3.55255V3.55721V3.56187V3.56653V3.57119V3.57585V3.58052V3.58519V3.58986V3.59453V3.5992V3.60388V3.60856V3.61324V3.61792V3.62261V3.62729V3.63198V3.63667V3.64137V3.64606V3.65076V3.65546V3.66016V3.66487V3.66958V3.67428V3.679V3.68371V3.68843V3.69315V3.69787V3.70259V3.70731V3.71204V3.71677V3.72151V3.72624V3.73098V3.73572V3.74046V3.74521V3.74996V3.75471V3.75946V3.76422V3.76898V3.77374V3.7785V3.78327V3.78804V3.79281V3.79758V3.80236V3.80714V3.81192V3.81671V3.8215V3.82629V3.83108V3.83588V3.84068V3.84548V3.85028V3.85509V3.8599V3.86472V3.86953V3.87435V3.87918V3.884V3.88883V3.89366V3.8985V3.90334V3.90818V3.91302V3.91787V3.92272V3.92757V3.93243V3.93729V3.94215V3.94702V3.95189V3.95676V3.96164V3.96652V3.9714V3.97628V3.98117V3.98606V3.99096V3.99586V4.00076V4.00567V4.01058V4.01549V4.02041V4.02532V4.03025V4.03517V4.0401V4.04504V4.04997V4.05491V4.05986V4.06481V4.06976V4.07471V4.07967V4.08463V4.0896V4.09457V4.09954V4.10452V4.1095V4.11448V4.11947V4.12446V4.12946V4.13446V4.13946V4.14447V4.14948V4.15449V4.15951V4.16453V4.16956V4.17459V4.17962V4.18466V4.1897V4.19475V4.1998V4.20485V4.20991V4.21497V4.22004V4.22511V4.23019V4.23526V4.24035V4.24543V4.25052V4.25562V4.26072V4.26582V4.27093V4.27604V4.28116V4.28628V4.2914V4.29653V4.30167V4.3068V4.31194V4.31709V4.32224V4.3274V4.33256V4.33772V4.34289V4.34806V4.35324V4.35842V4.36361V4.3688V4.37399V4.37919V4.3844V4.38961V4.39482V4.40004V4.40526V4.41049V4.41572V4.42096V4.4262V4.43145V4.4367V4.44195V4.44721V4.45248V4.45775V4.46303V4.46831V4.47359V4.47888V4.48417V4.48947V4.49478V4.50009V4.5054V4.51072V4.51604V4.52137V4.5267V4.53204V4.53739V4.54274V4.54809V4.55345V4.55881V4.56418V4.56956V4.57494V4.58032V4.58571V4.59111V4.59651V4.60191V4.60732V4.61274V4.61816V4.62359V4.62902V4.63445V4.6399V4.64534V4.6508V4.65626V4.66172V4.66719V4.67266V4.67814V4.68363V4.68912V4.69462V4.70012V4.70563V4.71114V4.71666V4.72218V4.72771V4.73325V4.73879V4.74433V4.74989V4.75544V4.76101V4.76658V4.77215V4.77773V4.78332V4.78891V4.79451V4.80011V4.80572V4.81133V4.81696V4.82258V4.82822V4.83385V4.8395V4.84515V4.85081V4.85647V4.86214V4.86781V4.87349V4.87918V4.88487V4.89057V4.89627V4.90198V4.9077V4.91342V4.91915V4.92488V4.93062V4.93637V4.94212V4.94788V4.95365V4.95942V4.9652V4.97098V4.97677V4.98257V4.98837V4.99418V5C13 5.27614 12.7761 5.5 12.5 5.5C12.2239 5.5 12 5.27614 12 5V4.99418V4.98837V4.98257V4.97677V4.97098V4.9652V4.95942V4.95365V4.94788V4.94212V4.93637V4.93062V4.92488V4.91915V4.91342V4.9077V4.90198V4.89627V4.89057V4.88487V4.87918V4.87349V4.86781V4.86214V4.85647V4.85081V4.84515V4.8395V4.83385V4.82822V4.82258V4.81696V4.81133V4.80572V4.80011V4.79451V4.78891V4.78332V4.77773V4.77215V4.76658V4.76101V4.75544V4.74989V4.74433V4.73879V4.73325V4.72771V4.72218V4.71666V4.71114V4.70563V4.70012V4.69462V4.68912V4.68363V4.67814V4.67266V4.66719V4.66172V4.65626V4.6508V4.64534V4.6399V4.63445V4.62902V4.62359V4.61816V4.61274V4.60732V4.60191V4.59651V4.59111V4.58571V4.58032V4.57494V4.56956V4.56418V4.55881V4.55345V4.54809V4.54274V4.53739V4.53204V4.5267V4.52137V4.51604V4.51072V4.5054V4.50009V4.49478V4.48947V4.48417V4.47888V4.47359V4.46831V4.46303V4.45775V4.45248V4.44721V4.44195V4.4367V4.43145V4.4262V4.42096V4.41572V4.41049V4.40526V4.40004V4.39482V4.38961V4.3844V4.37919V4.37399V4.3688V4.36361V4.35842V4.35324V4.34806V4.34289V4.33772V4.33256V4.3274V4.32224V4.31709V4.31194V4.3068V4.30167V4.29653V4.2914V4.28628V4.28116V4.27604V4.27093V4.26582V4.26072V4.25562V4.25052V4.24543V4.24035V4.23526V4.23019V4.22511V4.22004V4.21497V4.20991V4.20485V4.1998V4.19475V4.1897V4.18466V4.17962V4.17459V4.16956V4.16453V4.15951V4.15449V4.14948V4.14447V4.13946V4.13446V4.12946V4.12446V4.11947V4.11448V4.1095V4.10452V4.09954V4.09457V4.0896V4.08463V4.07967V4.07471V4.06976V4.06481V4.05986V4.05491V4.04997V4.04504V4.0401V4.03517V4.03025V4.02532V4.02041V4.01549V4.01058V4.00567V4.00076V3.99586V3.99096V3.98606V3.98117V3.97628V3.9714V3.96652V3.96164V3.95676V3.95189V3.94702V3.94215V3.93729V3.93243V3.92757V3.92272V3.91787V3.91302V3.90818V3.90334V3.8985V3.89366V3.88883V3.884V3.87918V3.87435V3.86953V3.86472V3.8599V3.85509V3.85028V3.84548V3.84068V3.83588V3.83108V3.82629V3.8215V3.81671V3.81192V3.80714V3.80236V3.79758V3.79281V3.78804V3.78327V3.7785V3.77374V3.76898V3.76422V3.75946V3.75471V3.74996V3.74521V3.74046V3.73572V3.73098V3.72624V3.72151V3.71677V3.71204V3.70731V3.70259V3.69787V3.69315V3.68843V3.68371V3.679V3.67428V3.66958V3.66487V3.66016V3.65546V3.65076V3.64606V3.64137V3.63667V3.63198V3.62729V3.62261V3.61792V3.61324V3.60856V3.60388V3.5992V3.59453V3.58986V3.58519V3.58052V3.57585V3.57119V3.56653V3.56187V3.55721V3.55255V3.5479V3.54324V3.53859V3.53394V3.5293V3.52465V3.52001V3.51537V3.51073V3.50609V3.50145V3.49682V3.49218V3.48755V3.48292V3.4783V3.47367V3.46904V3.46442V3.4598V3.45518V3.45056V3.44595V3.44133V3.43672V3.4321V3.42749V3.42288V3.41828V3.41367V3.40907V3.40446V3.39986V3.39526V3.39066V3.38606V3.38147V3.37687V3.37228V3.36768V3.36309V3.3585V3.35391V3.34933V3.34474V3.34015V3.33557V3.33099V3.3264V3.32182V3.31724V3.31267V3.30809V3.30351V3.29894V3.29436V3.28979V3.28522V3.28065V3.27608V3.27151V3.26694V3.26237V3.2578V3.25324V3.24867V3.24411V3.23955V3.23498V3.23042V3.22586V3.2213V3.21674V3.21219V3.20763V3.20307V3.19851V3.19396V3.1894V3.18485V3.1803V3.17574V3.17119V3.16664V3.16209V3.15754V3.15299V3.14844V3.14389V3.13934V3.13479V3.13025V3.1257V3.12115V3.11661V3.11206V3.10752V3.10297V3.09843V3.09388V3.08934V3.08479V3.08025V3.07571V3.07116V3.06662V3.06208V3.05754V3.053V3.04845V3.04391V3.03937V3.03483V3.03029V3.02575V3.02121V3.01667V3.01212V3.00758V3.00304V2.9985V2.99396V2.98942V2.98488V2.98034V2.9758V2.97126V2.96672V2.96217V2.95763V2.95309V2.94855V2.94401V2.93947V2.93492V2.93038V2.92584V2.9213V2.91675V2.91221V2.90767V2.90312V2.89858V2.89403V2.88949V2.88494V2.88039V2.87585V2.8713V2.86675V2.86221V2.85766V2.85311V2.84856V2.84401V2.83946V2.83491V2.83036V2.82581V2.82125V2.8167V2.81215V2.80759V2.80304V2.79848V2.79392V2.78937V2.78481V2.78025V2.77569V2.77113V2.76657V2.76201V2.75744V2.75288V2.74832V2.74375V2.73918V2.73462V2.73005V2.72548V2.72091V2.71634V2.71177V2.70719V2.70262V2.69805V2.69347V2.68889V2.68431V2.67974V2.67516V2.67057V2.66599V2.66141V2.65682V2.65224V2.64765V2.64306V2.63847V2.63388V2.62929V2.62469V2.6201V2.6155V2.61091V2.60631V2.60171V2.59711V2.5925V2.5879V2.58329V2.57868V2.57408V2.56947V2.56485V2.56024V2.55563V2.55101V2.54639V2.54177V2.53715V2.53253V2.52791V2.52328V2.51865V2.51402V2.50939V2.50476V2.50013C12 2.39075 11.9824 2.28547 11.95 2.18695L7.13324 6.12793C6.76487 6.42932 6.23513 6.42932 5.86676 6.12793L1.04999 2.18693C1.01755 2.28541 1 2.39066 1 2.5V8.5C1 9.05229 1.44772 9.5 2 9.5H5C5.27614 9.5 5.5 9.72386 5.5 10C5.5 10.2761 5.27614 10.5 5 10.5H2C0.89543 10.5 0 9.60457 0 8.5V2.5ZM11 1.5C11.0645 1.5 11.1276 1.50611 11.1887 1.51778L6.5 5.35397L1.81132 1.51777C1.87242 1.50611 1.9355 1.5 2 1.5H11ZM8 11.5C8 9.567 9.567 8 11.5 8C13.433 8 15 9.567 15 11.5C15 11.8228 14.9564 12.1346 14.8751 12.4303C14.7568 12.8606 14.3378 13.1925 13.9401 13.279C13.7455 13.3214 13.6294 13.2888 13.5827 13.2597C13.5635 13.2478 13.5 13.2082 13.5 13.0136V11.5V11.4848L13.4991 11.4696L13.4422 10.5374L13.4422 10.5373C13.4218 10.2019 13.2861 9.8034 12.9308 9.5506C11.9682 8.86567 10.6252 8.94096 9.74511 9.79203C8.75259 10.7519 8.72608 12.3345 9.6859 13.3271C10.4929 14.1616 11.7402 14.3132 12.7069 13.7698C12.795 13.9048 12.9111 14.0198 13.0548 14.1091C13.395 14.3205 13.8022 14.3325 14.1528 14.2562C14.8456 14.1054 15.6052 13.5471 15.8394 12.6954C15.9442 12.3142 16 11.9132 16 11.5C16 9.01472 13.9853 7 11.5 7C9.01472 7 7 9.01472 7 11.5C7 13.9853 9.01472 16 11.5 16C11.7761 16 12 15.7761 12 15.5C12 15.2239 11.7761 15 11.5 15C9.567 15 8 13.433 8 11.5ZM12.5 11.5152V12.6918C11.9032 13.2428 10.9724 13.2189 10.4047 12.6319C9.82886 12.0364 9.84476 11.0868 10.4403 10.5109C10.9677 10.0008 11.7739 9.9547 12.351 10.3654C12.3844 10.3891 12.4355 10.4573 12.444 10.598L12.4441 10.5982L12.5 11.5152Z",
          fill: ""
        })
      }
    };
  });
  var EnvelopeGearIcon = /*#__PURE__*/createIconComponent("EnvelopeGearIcon", "oxygen-icon oxygen-icon-envelope-gear", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 2.5C0 1.39543 0.89543 0.5 2 0.5H11C12.1046 0.5 13 1.39561 13 2.50013V2.50476V2.50939V2.51402V2.51865V2.52328V2.52791V2.53253V2.53715V2.54177V2.54639V2.55101V2.55563V2.56024V2.56485V2.56947V2.57408V2.57868V2.58329V2.5879V2.5925V2.59711V2.60171V2.60631V2.61091V2.6155V2.6201V2.62469V2.62929V2.63388V2.63847V2.64306V2.64765V2.65224V2.65682V2.66141V2.66599V2.67057V2.67516V2.67974V2.68431V2.68889V2.69347V2.69805V2.70262V2.70719V2.71177V2.71634V2.72091V2.72548V2.73005V2.73462V2.73918V2.74375V2.74832V2.75288V2.75744V2.76201V2.76657V2.77113V2.77569V2.78025V2.78481V2.78937V2.79392V2.79848V2.80304V2.80759V2.81215V2.8167V2.82125V2.82581V2.83036V2.83491V2.83946V2.84401V2.84856V2.85311V2.85766V2.86221V2.86675V2.8713V2.87585V2.88039V2.88494V2.88949V2.89403V2.89858V2.90312V2.90767V2.91221V2.91675V2.9213V2.92584V2.93038V2.93492V2.93947V2.94401V2.94855V2.95309V2.95763V2.96217V2.96672V2.97126V2.9758V2.98034V2.98488V2.98942V2.99396V2.9985V3.00304V3.00758V3.01212V3.01667V3.02121V3.02575V3.03029V3.03483V3.03937V3.04391V3.04845V3.053V3.05754V3.06208V3.06662V3.07116V3.07571V3.08025V3.08479V3.08934V3.09388V3.09843V3.10297V3.10752V3.11206V3.11661V3.12115V3.1257V3.13025V3.13479V3.13934V3.14389V3.14844V3.15299V3.15754V3.16209V3.16664V3.17119V3.17574V3.1803V3.18485V3.1894V3.19396V3.19851V3.20307V3.20763V3.21219V3.21674V3.2213V3.22586V3.23042V3.23498V3.23955V3.24411V3.24867V3.25324V3.2578V3.26237V3.26694V3.27151V3.27608V3.28065V3.28522V3.28979V3.29436V3.29894V3.30351V3.30809V3.31267V3.31724V3.32182V3.3264V3.33099V3.33557V3.34015V3.34474V3.34933V3.35391V3.3585V3.36309V3.36768V3.37228V3.37687V3.38147V3.38606V3.39066V3.39526V3.39986V3.40446V3.40907V3.41367V3.41828V3.42288V3.42749V3.4321V3.43672V3.44133V3.44595V3.45056V3.45518V3.4598V3.46442V3.46904V3.47367V3.4783V3.48292V3.48755V3.49218V3.49682V3.50145V3.50609V3.51073V3.51537V3.52001V3.52465V3.5293V3.53394V3.53859V3.54324V3.5479V3.55255V3.55721V3.56187V3.56653V3.57119V3.57585V3.58052V3.58519V3.58986V3.59453V3.5992V3.60388V3.60856V3.61324V3.61792V3.62261V3.62729V3.63198V3.63667V3.64137V3.64606V3.65076V3.65546V3.66016V3.66487V3.66958V3.67428V3.679V3.68371V3.68843V3.69315V3.69787V3.70259V3.70731V3.71204V3.71677V3.72151V3.72624V3.73098V3.73572V3.74046V3.74521V3.74996V3.75471V3.75946V3.76422V3.76898V3.77374V3.7785V3.78327V3.78804V3.79281V3.79758V3.80236V3.80714V3.81192V3.81671V3.8215V3.82629V3.83108V3.83588V3.84068V3.84548V3.85028V3.85509V3.8599V3.86472V3.86953V3.87435V3.87918V3.884V3.88883V3.89366V3.8985V3.90334V3.90818V3.91302V3.91787V3.92272V3.92757V3.93243V3.93729V3.94215V3.94702V3.95189V3.95676V3.96164V3.96652V3.9714V3.97628V3.98117V3.98606V3.99096V3.99586V4.00076V4.00567V4.01058V4.01549V4.02041V4.02532V4.03025V4.03517V4.0401V4.04504V4.04997V4.05491V4.05986V4.06481V4.06976V4.07471V4.07967V4.08463V4.0896V4.09457V4.09954V4.10452V4.1095V4.11448V4.11947V4.12446V4.12946V4.13446V4.13946V4.14447V4.14948V4.15449V4.15951V4.16453V4.16956V4.17459V4.17962V4.18466V4.1897V4.19475V4.1998V4.20485V4.20991V4.21497V4.22004V4.22511V4.23019V4.23526V4.24035V4.24543V4.25052V4.25562V4.26072V4.26582V4.27093V4.27604V4.28116V4.28628V4.2914V4.29653V4.30167V4.3068V4.31194V4.31709V4.32224V4.3274V4.33256V4.33772V4.34289V4.34806V4.35324V4.35842V4.36361V4.3688V4.37399V4.37919V4.3844V4.38961V4.39482V4.40004V4.40526V4.41049V4.41572V4.42096V4.4262V4.43145V4.4367V4.44195V4.44721V4.45248V4.45775V4.46303V4.46831V4.47359V4.47888V4.48417V4.48947V4.49478V4.50009V4.5054V4.51072V4.51604V4.52137V4.5267V4.53204V4.53739V4.54274V4.54809V4.55345V4.55881V4.56418V4.56956V4.57494V4.58032V4.58571V4.59111V4.59651V4.60191V4.60732V4.61274V4.61816V4.62359V4.62902V4.63445V4.6399V4.64534V4.6508V4.65626V4.66172V4.66719V4.67266V4.67814V4.68363V4.68912V4.69462V4.70012V4.70563V4.71114V4.71666V4.72218V4.72771V4.73325V4.73879V4.74433V4.74989V4.75544V4.76101V4.76658V4.77215V4.77773V4.78332V4.78891V4.79451V4.80011V4.80572V4.81133V4.81696V4.82258V4.82822V4.83385V4.8395V4.84515V4.85081V4.85647V4.86214V4.86781V4.87349V4.87918V4.88487V4.89057V4.89627V4.90198V4.9077V4.91342V4.91915V4.92488V4.93062V4.93637V4.94212V4.94788V4.95365V4.95942V4.9652V4.97098V4.97677V4.98257V4.98837V4.99418V5C13 5.27614 12.7761 5.5 12.5 5.5C12.2239 5.5 12 5.27614 12 5V4.99418V4.98837V4.98257V4.97677V4.97098V4.9652V4.95942V4.95365V4.94788V4.94212V4.93637V4.93062V4.92488V4.91915V4.91342V4.9077V4.90198V4.89627V4.89057V4.88487V4.87918V4.87349V4.86781V4.86214V4.85647V4.85081V4.84515V4.8395V4.83385V4.82822V4.82258V4.81696V4.81133V4.80572V4.80011V4.79451V4.78891V4.78332V4.77773V4.77215V4.76658V4.76101V4.75544V4.74989V4.74433V4.73879V4.73325V4.72771V4.72218V4.71666V4.71114V4.70563V4.70012V4.69462V4.68912V4.68363V4.67814V4.67266V4.66719V4.66172V4.65626V4.6508V4.64534V4.6399V4.63445V4.62902V4.62359V4.61816V4.61274V4.60732V4.60191V4.59651V4.59111V4.58571V4.58032V4.57494V4.56956V4.56418V4.55881V4.55345V4.54809V4.54274V4.53739V4.53204V4.5267V4.52137V4.51604V4.51072V4.5054V4.50009V4.49478V4.48947V4.48417V4.47888V4.47359V4.46831V4.46303V4.45775V4.45248V4.44721V4.44195V4.4367V4.43145V4.4262V4.42096V4.41572V4.41049V4.40526V4.40004V4.39482V4.38961V4.3844V4.37919V4.37399V4.3688V4.36361V4.35842V4.35324V4.34806V4.34289V4.33772V4.33256V4.3274V4.32224V4.31709V4.31194V4.3068V4.30167V4.29653V4.2914V4.28628V4.28116V4.27604V4.27093V4.26582V4.26072V4.25562V4.25052V4.24543V4.24035V4.23526V4.23019V4.22511V4.22004V4.21497V4.20991V4.20485V4.1998V4.19475V4.1897V4.18466V4.17962V4.17459V4.16956V4.16453V4.15951V4.15449V4.14948V4.14447V4.13946V4.13446V4.12946V4.12446V4.11947V4.11448V4.1095V4.10452V4.09954V4.09457V4.0896V4.08463V4.07967V4.07471V4.06976V4.06481V4.05986V4.05491V4.04997V4.04504V4.0401V4.03517V4.03025V4.02532V4.02041V4.01549V4.01058V4.00567V4.00076V3.99586V3.99096V3.98606V3.98117V3.97628V3.9714V3.96652V3.96164V3.95676V3.95189V3.94702V3.94215V3.93729V3.93243V3.92757V3.92272V3.91787V3.91302V3.90818V3.90334V3.8985V3.89366V3.88883V3.884V3.87918V3.87435V3.86953V3.86472V3.8599V3.85509V3.85028V3.84548V3.84068V3.83588V3.83108V3.82629V3.8215V3.81671V3.81192V3.80714V3.80236V3.79758V3.79281V3.78804V3.78327V3.7785V3.77374V3.76898V3.76422V3.75946V3.75471V3.74996V3.74521V3.74046V3.73572V3.73098V3.72624V3.72151V3.71677V3.71204V3.70731V3.70259V3.69787V3.69315V3.68843V3.68371V3.679V3.67428V3.66958V3.66487V3.66016V3.65546V3.65076V3.64606V3.64137V3.63667V3.63198V3.62729V3.62261V3.61792V3.61324V3.60856V3.60388V3.5992V3.59453V3.58986V3.58519V3.58052V3.57585V3.57119V3.56653V3.56187V3.55721V3.55255V3.5479V3.54324V3.53859V3.53394V3.5293V3.52465V3.52001V3.51537V3.51073V3.50609V3.50145V3.49682V3.49218V3.48755V3.48292V3.4783V3.47367V3.46904V3.46442V3.4598V3.45518V3.45056V3.44595V3.44133V3.43672V3.4321V3.42749V3.42288V3.41828V3.41367V3.40907V3.40446V3.39986V3.39526V3.39066V3.38606V3.38147V3.37687V3.37228V3.36768V3.36309V3.3585V3.35391V3.34933V3.34474V3.34015V3.33557V3.33099V3.3264V3.32182V3.31724V3.31267V3.30809V3.30351V3.29894V3.29436V3.28979V3.28522V3.28065V3.27608V3.27151V3.26694V3.26237V3.2578V3.25324V3.24867V3.24411V3.23955V3.23498V3.23042V3.22586V3.2213V3.21674V3.21219V3.20763V3.20307V3.19851V3.19396V3.1894V3.18485V3.1803V3.17574V3.17119V3.16664V3.16209V3.15754V3.15299V3.14844V3.14389V3.13934V3.13479V3.13025V3.1257V3.12115V3.11661V3.11206V3.10752V3.10297V3.09843V3.09388V3.08934V3.08479V3.08025V3.07571V3.07116V3.06662V3.06208V3.05754V3.053V3.04845V3.04391V3.03937V3.03483V3.03029V3.02575V3.02121V3.01667V3.01212V3.00758V3.00304V2.9985V2.99396V2.98942V2.98488V2.98034V2.9758V2.97126V2.96672V2.96217V2.95763V2.95309V2.94855V2.94401V2.93947V2.93492V2.93038V2.92584V2.9213V2.91675V2.91221V2.90767V2.90312V2.89858V2.89403V2.88949V2.88494V2.88039V2.87585V2.8713V2.86675V2.86221V2.85766V2.85311V2.84856V2.84401V2.83946V2.83491V2.83036V2.82581V2.82125V2.8167V2.81215V2.80759V2.80304V2.79848V2.79392V2.78937V2.78481V2.78025V2.77569V2.77113V2.76657V2.76201V2.75744V2.75288V2.74832V2.74375V2.73918V2.73462V2.73005V2.72548V2.72091V2.71634V2.71177V2.70719V2.70262V2.69805V2.69347V2.68889V2.68431V2.67974V2.67516V2.67057V2.66599V2.66141V2.65682V2.65224V2.64765V2.64306V2.63847V2.63388V2.62929V2.62469V2.6201V2.6155V2.61091V2.60631V2.60171V2.59711V2.5925V2.5879V2.58329V2.57868V2.57408V2.56947V2.56485V2.56024V2.55563V2.55101V2.54639V2.54177V2.53715V2.53253V2.52791V2.52328V2.51865V2.51402V2.50939V2.50476V2.50013C12 2.39075 11.9824 2.28547 11.95 2.18695L7.13324 6.12793C6.76487 6.42932 6.23513 6.42932 5.86676 6.12793L1.04999 2.18693C1.01755 2.28541 1 2.39066 1 2.5V8.5C1 9.05228 1.44772 9.5 2 9.5H4.5C4.77614 9.5 5 9.72386 5 10C5 10.2761 4.77614 10.5 4.5 10.5H2C0.895431 10.5 0 9.60457 0 8.5V2.5ZM1.81132 1.51777L6.5 5.35397L11.1887 1.51778C11.1276 1.50611 11.0645 1.5 11 1.5H2C1.9355 1.5 1.87242 1.50611 1.81132 1.51777ZM12.5532 7.91723V7.67L12.5501 7.60901C12.5096 7.25598 12.2241 7 11.883 7H11.117L11.0558 7.00305L10.9979 7.01204C10.6751 7.07547 10.4468 7.34805 10.4468 7.67021V7.91723L10.3657 7.94145C10.1653 8.00526 9.97118 8.08586 9.78502 8.18227L9.71187 8.22208L9.53657 8.04713L9.48759 8.00315C9.20825 7.78525 8.82847 7.80757 8.58883 8.04721L8.04721 8.58883L8.00315 8.63789L7.96719 8.68818C7.78862 8.96142 7.82166 9.3111 8.04721 9.53665L8.22208 9.71149L8.18232 9.78493C8.08594 9.97102 8.00535 10.1651 7.94155 10.3654L7.91723 10.4464L7.67 10.4468C7.30006 10.4468 7 10.7469 7 11.117V11.883L7.00222 11.9379C7.03018 12.2824 7.31857 12.5532 7.67021 12.5532L7.91723 12.5528L7.94145 12.6343C8.00526 12.8347 8.08586 13.0288 8.18227 13.215L8.22208 13.2877L8.04713 13.4634C7.78548 13.7251 7.78548 14.1494 8.04721 14.4112L8.58883 14.9528L8.63664 14.9963C8.89992 15.2136 9.29031 15.1991 9.53665 14.9528L9.71149 14.7775L9.78493 14.8177C9.97102 14.9141 10.1651 14.9947 10.3654 15.0584L10.4464 15.0824L10.4468 15.33C10.4468 15.6999 10.7469 16 11.117 16H11.883L11.9379 15.9978C12.2824 15.9698 12.5532 15.6814 12.5532 15.3298L12.5528 15.0824L12.6343 15.0585C12.8347 14.9947 13.0288 14.9141 13.215 14.8177L13.2877 14.7775L13.4634 14.9529C13.7251 15.2145 14.1494 15.2145 14.4112 14.9528L14.9528 14.4112L14.9963 14.3634C15.2136 14.1001 15.1991 13.7097 14.9528 13.4634L14.7775 13.2877L14.8177 13.215C14.9141 13.0288 14.9947 12.8347 15.0585 12.6343L15.0824 12.5528L15.3298 12.5532L15.391 12.5501C15.744 12.5096 16 12.2241 16 11.883V11.117L15.9969 11.0558L15.988 10.9979C15.9245 10.6751 15.6519 10.4468 15.3298 10.4468L15.0824 10.4464L15.0584 10.3654C14.9947 10.1651 14.9141 9.97102 14.8177 9.78493L14.7775 9.71149L14.9529 9.53657L14.9968 9.48759C15.2148 9.20825 15.1924 8.82847 14.9528 8.58883L14.4112 8.04721L14.3621 8.00315L14.3118 7.96719C14.0386 7.78862 13.6889 7.82166 13.4634 8.04721L13.2881 8.22208L13.2151 8.18232C13.029 8.08594 12.8349 8.00535 12.6346 7.94155L12.5532 7.91723ZM12.393 8.72326L11.735 8.52685V7.81818H11.265V8.52689L10.6073 8.72319C10.4561 8.77176 10.3093 8.83265 10.1683 8.90519L9.56635 9.23278L9.06284 8.73028L8.73039 9.06273L9.23214 9.56438L8.90561 10.1675C8.83285 10.3088 8.77179 10.4559 8.72312 10.6075L8.52631 11.2637L7.81818 11.2648V11.7348L8.52743 11.7337L8.72334 12.3932C8.7718 12.544 8.83251 12.6903 8.9048 12.831L9.23344 13.4317L8.73017 13.937L9.06261 14.2695L9.56557 13.7653L10.1688 14.0951C10.3092 14.1673 10.4554 14.2279 10.6059 14.2764L11.2637 14.4706L11.2648 15.1818H11.7348L11.7337 14.4694L12.3948 14.2761C12.5445 14.2279 12.6899 14.1676 12.8296 14.0959L13.4304 13.764L13.9372 14.2697L14.2697 13.9372L13.764 13.4304L14.0959 12.8296C14.1676 12.6899 14.2279 12.5445 14.2761 12.3948L14.4694 11.7337L15.1818 11.7348V11.2648L14.4706 11.2637L14.2764 10.6059C14.2279 10.4554 14.1673 10.3092 14.0951 10.1688L13.7653 9.56557L14.2695 9.06261L13.9372 8.73028L13.4336 9.23279L12.8318 8.90523C12.6908 8.83271 12.5441 8.77183 12.393 8.72326ZM11.5 13.1875C12.432 13.1875 13.1875 12.432 13.1875 11.5C13.1875 10.568 12.432 9.8125 11.5 9.8125C10.568 9.8125 9.8125 10.568 9.8125 11.5C9.8125 12.432 10.568 13.1875 11.5 13.1875ZM11.5 12.3693C11.9801 12.3693 12.3693 11.9801 12.3693 11.5C12.3693 11.0199 11.9801 10.6307 11.5 10.6307C11.0199 10.6307 10.6307 11.0199 10.6307 11.5C10.6307 11.9801 11.0199 12.3693 11.5 12.3693Z",
          fill: ""
        })
      }
    };
  });
  var EnvelopeLinkIcon = /*#__PURE__*/createIconComponent("EnvelopeLinkIcon", "oxygen-icon oxygen-icon-envelope-link", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          opacity: "0.9",
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 3C0 1.89543 0.895431 1 2 1H14C15.1046 1 16 1.89561 16 3.00013V3.00476V3.00939V3.01402V3.01865V3.02328V3.02791V3.03253V3.03715V3.04177V3.04639V3.05101V3.05563V3.06024V3.06485V3.06947V3.07408V3.07868V3.08329V3.0879V3.0925V3.09711V3.10171V3.10631V3.11091V3.1155V3.1201V3.12469V3.12929V3.13388V3.13847V3.14306V3.14765V3.15224V3.15682V3.16141V3.16599V3.17057V3.17516V3.17974V3.18431V3.18889V3.19347V3.19805V3.20262V3.20719V3.21177V3.21634V3.22091V3.22548V3.23005V3.23462V3.23918V3.24375V3.24832V3.25288V3.25744V3.26201V3.26657V3.27113V3.27569V3.28025V3.28481V3.28937V3.29392V3.29848V3.30304V3.30759V3.31215V3.3167V3.32125V3.32581V3.33036V3.33491V3.33946V3.34401V3.34856V3.35311V3.35766V3.36221V3.36675V3.3713V3.37585V3.38039V3.38494V3.38949V3.39403V3.39858V3.40312V3.40767V3.41221V3.41675V3.4213V3.42584V3.43038V3.43492V3.43947V3.44401V3.44855V3.45309V3.45763V3.46217V3.46672V3.47126V3.4758V3.48034V3.48488V3.48942V3.49396V3.4985V3.50304V3.50758V3.51212V3.51667V3.52121V3.52575V3.53029V3.53483V3.53937V3.54391V3.54845V3.553V3.55754V3.56208V3.56662V3.57116V3.57571V3.58025V3.58479V3.58934V3.59388V3.59843V3.60297V3.60752V3.61206V3.61661V3.62115V3.6257V3.63025V3.63479V3.63934V3.64389V3.64844V3.65299V3.65754V3.66209V3.66664V3.67119V3.67574V3.6803V3.68485V3.6894V3.69396V3.69851V3.70307V3.70763V3.71219V3.71674V3.7213V3.72586V3.73042V3.73498V3.73955V3.74411V3.74867V3.75324V3.7578V3.76237V3.76694V3.77151V3.77608V3.78065V3.78522V3.78979V3.79436V3.79894V3.80351V3.80809V3.81267V3.81724V3.82182V3.8264V3.83099V3.83557V3.84015V3.84474V3.84933V3.85391V3.8585V3.86309V3.86768V3.87228V3.87687V3.88147V3.88606V3.89066V3.89526V3.89986V3.90446V3.90907V3.91367V3.91828V3.92288V3.92749V3.9321V3.93672V3.94133V3.94595V3.95056V3.95518V3.9598V3.96442V3.96904V3.97367V3.9783V3.98292V3.98755V3.99218V3.99682V4.00145V4.00609V4.01073V4.01537V4.02001V4.02465V4.0293V4.03394V4.03859V4.04324V4.0479V4.05255V4.05721V4.06187V4.06653V4.07119V4.07585V4.08052V4.08519V4.08986V4.09453V4.0992V4.10388V4.10856V4.11324V4.11792V4.12261V4.12729V4.13198V4.13667V4.14137V4.14606V4.15076V4.15546V4.16016V4.16487V4.16958V4.17428V4.179V4.18371V4.18843V4.19315V4.19787V4.20259V4.20731V4.21204V4.21677V4.22151V4.22624V4.23098V4.23572V4.24046V4.24521V4.24996V4.25471V4.25946V4.26422V4.26898V4.27374V4.2785V4.28327V4.28804V4.29281V4.29758V4.30236V4.30714V4.31192V4.31671V4.3215V4.32629V4.33108V4.33588V4.34068V4.34548V4.35028V4.35509V4.3599V4.36472V4.36953V4.37435V4.37918V4.384V4.38883V4.39366V4.3985V4.40334V4.40818V4.41302V4.41787V4.42272V4.42757V4.43243V4.43729V4.44215V4.44702V4.45189V4.45676V4.46164V4.46652V4.4714V4.47628V4.48117V4.48606V4.49096V4.49586V4.50076V4.50567V4.51058V4.51549V4.52041V4.52532V4.53025V4.53517V4.5401V4.54504V4.54997V4.55491V4.55986V4.56481V4.56976V4.57471V4.57967V4.58463V4.5896V4.59457V4.59954V4.60452V4.6095V4.61448V4.61947V4.62446V4.62946V4.63446V4.63946V4.64447V4.64948V4.65449V4.65951V4.66453V4.66956V4.67459V4.67962V4.68466V4.6897V4.69475V4.6998V4.70485V4.70991V4.71497V4.72004V4.72511V4.73019V4.73526V4.74035V4.74543V4.75052V4.75562V4.76072V4.76582V4.77093V4.77604V4.78116V4.78628V4.7914V4.79653V4.80167V4.8068V4.81194V4.81709V4.82224V4.8274V4.83256V4.83772V4.84289V4.84806V4.85324V4.85842V4.86361V4.8688V4.87399V4.87919V4.8844V4.88961V4.89482V4.90004V4.90526V4.91049V4.91572V4.92096V4.9262V4.93145V4.9367V4.94195V4.94721V4.95248V4.95775V4.96303V4.96831V4.97359V4.97888V4.98417V4.98947V4.99478V5.00009V5.0054V5.01072V5.01604V5.02137V5.0267V5.03204V5.03739V5.04274V5.04809V5.05345V5.05881V5.06418V5.06956V5.07494V5.08032V5.08571V5.09111V5.09651V5.10191V5.10732V5.11274V5.11816V5.12359V5.12902V5.13445V5.1399V5.14534V5.1508V5.15626V5.16172V5.16719V5.17266V5.17814V5.18363V5.18912V5.19462V5.20012V5.20563V5.21114V5.21666V5.22218V5.22771V5.23325V5.23879V5.24433V5.24989V5.25544V5.26101V5.26658V5.27215V5.27773V5.28332V5.28891V5.29451V5.30011V5.30572V5.31133V5.31696V5.32258V5.32822V5.33385V5.3395V5.34515V5.35081V5.35647V5.36214V5.36781V5.37349V5.37918V5.38487V5.39057V5.39627V5.40198V5.4077V5.41342V5.41915V5.42488V5.43062V5.43637V5.44212V5.44788V5.45365V5.45942V5.4652V5.47098V5.47677V5.48257V5.48837V5.49418V5.5C16 5.77614 15.7761 6 15.5 6C15.2239 6 15 5.77614 15 5.5V5.49418V5.48837V5.48257V5.47677V5.47098V5.4652V5.45942V5.45365V5.44788V5.44212V5.43637V5.43062V5.42488V5.41915V5.41342V5.4077V5.40198V5.39627V5.39057V5.38487V5.37918V5.37349V5.36781V5.36214V5.35647V5.35081V5.34515V5.3395V5.33385V5.32822V5.32258V5.31696V5.31133V5.30572V5.30011V5.29451V5.28891V5.28332V5.27773V5.27215V5.26658V5.26101V5.25544V5.24989V5.24433V5.23879V5.23325V5.22771V5.22218V5.21666V5.21114V5.20563V5.20012V5.19462V5.18912V5.18363V5.17814V5.17266V5.16719V5.16172V5.15626V5.1508V5.14534V5.1399V5.13445V5.12902V5.12359V5.11816V5.11274V5.10732V5.10191V5.09651V5.09111V5.08571V5.08032V5.07494V5.06956V5.06418V5.05881V5.05345V5.04809V5.04274V5.03739V5.03204V5.0267V5.02137V5.01604V5.01072V5.0054V5.00009V4.99478V4.98947V4.98417V4.97888V4.97359V4.96831V4.96303V4.95775V4.95248V4.94721V4.94195V4.9367V4.93145V4.9262V4.92096V4.91572V4.91049V4.90526V4.90004V4.89482V4.88961V4.8844V4.87919V4.87399V4.8688V4.86361V4.85842V4.85324V4.84806V4.84289V4.83772V4.83256V4.8274V4.82224V4.81709V4.81194V4.8068V4.80167V4.79653V4.7914V4.78628V4.78116V4.77604V4.77093V4.76582V4.76072V4.75562V4.75052V4.74543V4.74035V4.73526V4.73019V4.72511V4.72004V4.71497V4.70991V4.70485V4.6998V4.69475V4.6897V4.68466V4.67962V4.67459V4.66956V4.66453V4.65951V4.65449V4.64948V4.64447V4.63946V4.63446V4.62946V4.62446V4.61947V4.61448V4.6095V4.60452V4.59954V4.59457V4.5896V4.58463V4.57967V4.57471V4.56976V4.56481V4.55986V4.55491V4.54997V4.54504V4.5401V4.53517V4.53025V4.52532V4.52041V4.51549V4.51058V4.50567V4.50076V4.49586V4.49096V4.48606V4.48117V4.47628V4.4714V4.46652V4.46164V4.45676V4.45189V4.44702V4.44215V4.43729V4.43243V4.42757V4.42272V4.41787V4.41302V4.40818V4.40334V4.3985V4.39366V4.38883V4.384V4.37918V4.37435V4.36953V4.36472V4.3599V4.35509V4.35028V4.34548V4.34068V4.33588V4.33108V4.32629V4.3215V4.31671V4.31192V4.30714V4.30236V4.29758V4.29281V4.28804V4.28327V4.2785V4.27374V4.26898V4.26422V4.25946V4.25471V4.24996V4.24521V4.24046V4.23572V4.23098V4.22624V4.22151V4.21677V4.21204V4.20731V4.20259V4.19787V4.19315V4.18843V4.18371V4.179V4.17428V4.16958V4.16487V4.16016V4.15546V4.15076V4.14606V4.14137V4.13667V4.13198V4.12729V4.12261V4.11792V4.11324V4.10856V4.10388V4.0992V4.09453V4.08986V4.08519V4.08052V4.07585V4.07119V4.06653V4.06187V4.05721V4.05255V4.0479V4.04324V4.03859V4.03394V4.0293V4.02465V4.02001V4.01537V4.01073V4.00609V4.00145V3.99682V3.99218V3.98755V3.98292V3.9783V3.97367V3.96904V3.96442V3.9598V3.95518V3.95056V3.94595V3.94133V3.93672V3.9321V3.92749V3.92288V3.91828V3.91367V3.90907V3.90446V3.89986V3.89526V3.89066V3.88606V3.88147V3.87687V3.87228V3.86768V3.86309V3.8585V3.85391V3.84933V3.84474V3.84015V3.83557V3.83099V3.8264V3.82182V3.81724V3.81267V3.80809V3.80351V3.79894V3.79436V3.78979V3.78522V3.78065V3.77608V3.77151V3.76694V3.76237V3.7578V3.75324V3.74867V3.74411V3.73955V3.73498V3.73042V3.72586V3.7213V3.71674V3.71219V3.70763V3.70307V3.69851V3.69396V3.6894V3.68485V3.6803V3.67574V3.67119V3.66664V3.66209V3.65754V3.65299V3.64844V3.64389V3.63934V3.63479V3.63025V3.6257V3.62115V3.61661V3.61206V3.60752V3.60297V3.59843V3.59388V3.58934V3.58479V3.58025V3.57571V3.57116V3.56662V3.56208V3.55754V3.553V3.54845V3.54391V3.53937V3.53483V3.53029V3.52575V3.52121V3.51667V3.51212V3.50758V3.50304V3.4985V3.49396V3.48942V3.48488V3.48034V3.4758V3.47126V3.46672V3.46217V3.45763V3.45309V3.44855V3.44401V3.43947V3.43492V3.43038V3.42584V3.4213V3.41675V3.41221V3.40767V3.40312V3.39858V3.39403V3.38949V3.38494V3.38039V3.37585V3.3713V3.36675V3.36221V3.35766V3.35311V3.34856V3.34401V3.33946V3.33491V3.33036V3.32581V3.32125V3.3167V3.31215V3.30759V3.30304V3.29848V3.29392V3.28937V3.28481V3.28025V3.27569V3.27113V3.26657V3.26201V3.25744V3.25288V3.24832V3.24375V3.23918V3.23462V3.23005V3.22548V3.22091V3.21634V3.21177V3.20719V3.20262V3.19805V3.19347V3.18889V3.18431V3.17974V3.17516V3.17057V3.16599V3.16141V3.15682V3.15224V3.14765V3.14306V3.13847V3.13388V3.12929V3.12469V3.1201V3.1155V3.11445L8.58124 7.69928C8.23354 7.94764 7.76646 7.94764 7.41876 7.69928L1 3.11445V11C1 11.5523 1.44772 12 2 12H5C5.27614 12 5.5 12.2239 5.5 12.5C5.5 12.7761 5.27614 13 5 13H2C0.89543 13 0 12.1046 0 11V3ZM14 2C14.2163 2 14.4165 2.06869 14.5802 2.18544L8 6.88555L1.41982 2.18542C1.58343 2.06868 1.78369 2 2 2H14ZM7.49738 14.7021C6.83421 14.0389 6.83421 12.9637 7.49738 12.3005L9.89895 9.89895C10.5621 9.23578 11.6373 9.23578 12.3005 9.89895L12.7008 10.2992C12.9218 10.5203 12.9218 10.8787 12.7008 11.0997C12.4797 11.3208 12.1213 11.3208 11.9003 11.0997L11.5 10.6995C11.2789 10.4784 10.9205 10.4784 10.6995 10.6995L8.2979 13.101C8.07685 13.3221 8.07685 13.6805 8.2979 13.9016L9.09843 14.7021C9.31949 14.9232 9.67789 14.9232 9.89895 14.7021L10.2992 14.3018C10.5203 14.0808 10.8787 14.0808 11.0997 14.3018C11.3208 14.5229 11.3208 14.8813 11.0997 15.1024L10.6995 15.5026C10.0363 16.1658 8.96108 16.1658 8.2979 15.5026L7.49738 14.7021ZM15.5026 8.2979C16.1658 8.96108 16.1658 10.0363 15.5026 10.6995L13.101 13.101C12.4379 13.7642 11.3627 13.7642 10.6995 13.101L10.2992 12.7008C10.0782 12.4797 10.0782 12.1213 10.2992 11.9003C10.5203 11.6792 10.8787 11.6792 11.0997 11.9003L11.5 12.3005C11.7211 12.5216 12.0795 12.5216 12.3005 12.3005L14.7021 9.89895C14.9232 9.67789 14.9232 9.31949 14.7021 9.09843L13.9016 8.2979C13.6805 8.07685 13.3221 8.07685 13.101 8.2979L12.7008 8.69817C12.4797 8.91923 12.1213 8.91923 11.9003 8.69817C11.6792 8.47711 11.6792 8.1187 11.9003 7.89764L12.3005 7.49738C12.9637 6.83421 14.0389 6.83421 14.7021 7.49738L15.5026 8.2979Z",
          fill: ""
        })
      }
    };
  });
  var EnvelopeMagnifyingGlassIcon = /*#__PURE__*/createIconComponent("EnvelopeMagnifyingGlassIcon", "oxygen-icon oxygen-icon-envelope-magnifying-glass", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2 0.5C0.89543 0.5 0 1.39543 0 2.5V8.5C0 9.60457 0.895431 10.5 2 10.5H4.5C4.77614 10.5 5 10.2761 5 10C5 9.72386 4.77614 9.5 4.5 9.5H2C1.44772 9.5 1 9.05228 1 8.5V2.5C1 2.39066 1.01755 2.28541 1.04999 2.18693L5.86676 6.12793C6.23513 6.42932 6.76487 6.42932 7.13324 6.12793L11.95 2.18695C11.9824 2.28547 12 2.39075 12 2.50013V5C12 5.27614 12.2239 5.5 12.5 5.5C12.7761 5.5 13 5.27614 13 5V2.50013C13 1.39561 12.1046 0.5 11 0.5H2ZM11.1887 1.51778C11.1276 1.50611 11.0645 1.5 11 1.5H2C1.9355 1.5 1.87242 1.50611 1.81132 1.51777L6.5 5.35397L11.1887 1.51778Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6.5 10.5C6.5 8.29086 8.29086 6.5 10.5 6.5C12.7091 6.5 14.5 8.29086 14.5 10.5C14.5 11.4244 14.1865 12.2755 13.6599 12.9528L15.8536 15.1464C16.0488 15.3417 16.0488 15.6583 15.8536 15.8536C15.6583 16.0488 15.3417 16.0488 15.1464 15.8536L12.9528 13.6599C12.2755 14.1865 11.4244 14.5 10.5 14.5C8.29086 14.5 6.5 12.7091 6.5 10.5ZM10.5 7.5C8.84315 7.5 7.5 8.84315 7.5 10.5C7.5 12.1569 8.84315 13.5 10.5 13.5C12.1569 13.5 13.5 12.1569 13.5 10.5C13.5 8.84315 12.1569 7.5 10.5 7.5Z",
          fill: ""
        }))
      }
    };
  });
  var EnvelopesIcon = /*#__PURE__*/createIconComponent("EnvelopesIcon", "oxygen-icon oxygen-icon-envelopes", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 3.5C0 2.39543 0.89543 1.5 2 1.5H11C12.1046 1.5 13 2.39561 13 3.50013V3.50476V3.50939V3.51402V3.51865V3.52328V3.52791V3.53253V3.53715V3.54177V3.54639V3.55101V3.55563V3.56024V3.56485V3.56947V3.57408V3.57868V3.58329V3.5879V3.5925V3.59711V3.60171V3.60631V3.61091V3.6155V3.6201V3.62469V3.62929V3.63388V3.63847V3.64306V3.64765V3.65224V3.65682V3.66141V3.66599V3.67057V3.67516V3.67974V3.68431V3.68889V3.69347V3.69805V3.70262V3.70719V3.71177V3.71634V3.72091V3.72548V3.73005V3.73462V3.73918V3.74375V3.74832V3.75288V3.75744V3.76201V3.76657V3.77113V3.77569V3.78025V3.78481V3.78937V3.79392V3.79848V3.80304V3.80759V3.81215V3.8167V3.82125V3.82581V3.83036V3.83491V3.83946V3.84401V3.84856V3.85311V3.85766V3.86221V3.86675V3.8713V3.87585V3.88039V3.88494V3.88949V3.89403V3.89858V3.90312V3.90767V3.91221V3.91675V3.9213V3.92584V3.93038V3.93492V3.93947V3.94401V3.94855V3.95309V3.95763V3.96217V3.96672V3.97126V3.9758V3.98034V3.98488V3.98942V3.99396V3.9985V4.00304V4.00758V4.01212V4.01667V4.02121V4.02575V4.03029V4.03483V4.03937V4.04391V4.04845V4.053V4.05754V4.06208V4.06662V4.07116V4.07571V4.08025V4.08479V4.08934V4.09388V4.09843V4.10297V4.10752V4.11206V4.11661V4.12115V4.1257V4.13025V4.13479V4.13934V4.14389V4.14844V4.15299V4.15754V4.16209V4.16664V4.17119V4.17574V4.1803V4.18485V4.1894V4.19396V4.19851V4.20307V4.20763V4.21219V4.21674V4.2213V4.22586V4.23042V4.23498V4.23955V4.24411V4.24867V4.25324V4.2578V4.26237V4.26694V4.27151V4.27608V4.28065V4.28522V4.28979V4.29436V4.29894V4.30351V4.30809V4.31267V4.31724V4.32182V4.3264V4.33099V4.33557V4.34015V4.34474V4.34933V4.35391V4.3585V4.36309V4.36768V4.37228V4.37687V4.38147V4.38606V4.39066V4.39526V4.39986V4.40446V4.40907V4.41367V4.41828V4.42288V4.42749V4.4321V4.43672V4.44133V4.44595V4.45056V4.45518V4.4598V4.46442V4.46904V4.47367V4.4783V4.48292V4.48755V4.49218V4.49682V4.5H14C15.1046 4.5 16 5.39561 16 6.50013V6.50476V6.50939V6.51402V6.51865V6.52328V6.52791V6.53253V6.53715V6.54177V6.54639V6.55101V6.55563V6.56024V6.56485V6.56947V6.57408V6.57868V6.58329V6.5879V6.5925V6.59711V6.60171V6.60631V6.61091V6.6155V6.6201V6.62469V6.62929V6.63388V6.63847V6.64306V6.64765V6.65224V6.65682V6.66141V6.66599V6.67057V6.67516V6.67974V6.68431V6.68889V6.69347V6.69805V6.70262V6.70719V6.71177V6.71634V6.72091V6.72548V6.73005V6.73462V6.73918V6.74375V6.74832V6.75288V6.75744V6.76201V6.76657V6.77113V6.77569V6.78025V6.78481V6.78937V6.79392V6.79848V6.80304V6.80759V6.81215V6.8167V6.82125V6.82581V6.83036V6.83491V6.83946V6.84401V6.84856V6.85311V6.85766V6.86221V6.86675V6.8713V6.87585V6.88039V6.88494V6.88949V6.89403V6.89858V6.90312V6.90767V6.91221V6.91675V6.9213V6.92584V6.93038V6.93492V6.93947V6.94401V6.94855V6.95309V6.95763V6.96217V6.96672V6.97126V6.9758V6.98034V6.98488V6.98942V6.99396V6.9985V7.00304V7.00758V7.01213V7.01667V7.02121V7.02575V7.03029V7.03483V7.03937V7.04391V7.04845V7.053V7.05754V7.06208V7.06662V7.07117V7.07571V7.08025V7.08479V7.08934V7.09388V7.09843V7.10297V7.10752V7.11206V7.11661V7.12115V7.1257V7.13025V7.13479V7.13934V7.14389V7.14844V7.15299V7.15754V7.16209V7.16664V7.17119V7.17574V7.1803V7.18485V7.1894V7.19396V7.19851V7.20307V7.20763V7.21218V7.21674V7.2213V7.22586V7.23042V7.23498V7.23955V7.24411V7.24867V7.25324V7.2578V7.26237V7.26694V7.27151V7.27608V7.28065V7.28522V7.28979V7.29436V7.29894V7.30351V7.30809V7.31267V7.31724V7.32182V7.3264V7.33099V7.33557V7.34015V7.34474V7.34933V7.35391V7.3585V7.36309V7.36768V7.37228V7.37687V7.38146V7.38606V7.39066V7.39526V7.39986V7.40446V7.40907V7.41367V7.41828V7.42288V7.42749V7.4321V7.43672V7.44133V7.44594V7.45056V7.45518V7.4598V7.46442V7.46904V7.47367V7.4783V7.48292V7.48755V7.49218V7.49682V7.50145V7.50609V7.51073V7.51537V7.52001V7.52465V7.5293V7.53394V7.53859V7.54324V7.5479V7.55255V7.55721V7.56187V7.56653V7.57119V7.57585V7.58052V7.58519V7.58986V7.59453V7.59921V7.60388V7.60856V7.61324V7.61792V7.62261V7.62729V7.63198V7.63667V7.64137V7.64606V7.65076V7.65546V7.66016V7.66487V7.66958V7.67428V7.679V7.68371V7.68843V7.69314V7.69787V7.70259V7.70731V7.71204V7.71677V7.72151V7.72624V7.73098V7.73572V7.74046V7.74521V7.74996V7.75471V7.75946V7.76422V7.76898V7.77374V7.7785V7.78327V7.78804V7.79281V7.79758V7.80236V7.80714V7.81192V7.81671V7.8215V7.82629V7.83108V7.83588V7.84068V7.84548V7.85028V7.85509V7.8599V7.86472V7.86953V7.87435V7.87918V7.884V7.88883V7.89366V7.8985V7.90334V7.90818V7.91302V7.91787V7.92272V7.92757V7.93243V7.93729V7.94215V7.94702V7.95189V7.95676V7.96164V7.96652V7.9714V7.97628V7.98117V7.98606V7.99096V7.99586V8.00076V8.00567V8.01058V8.01549V8.0204V8.02532V8.03025V8.03517V8.0401V8.04504V8.04997V8.05491V8.05986V8.06481V8.06976V8.07471V8.07967V8.08463V8.0896V8.09457V8.09954V8.10452V8.1095V8.11448V8.11947V8.12446V8.12946V8.13446V8.13946V8.14447V8.14948V8.15449V8.15951V8.16453V8.16956V8.17459V8.17962V8.18466V8.1897V8.19475V8.1998V8.20485V8.20991V8.21497V8.22004V8.22511V8.23019V8.23526V8.24035V8.24543V8.25052V8.25562V8.26072V8.26582V8.27093V8.27604V8.28116V8.28628V8.2914V8.29653V8.30167V8.3068V8.31194V8.31709V8.32224V8.3274V8.33256V8.33772V8.34289V8.34806V8.35324V8.35842V8.36361V8.3688V8.37399V8.37919V8.3844V8.38961V8.39482V8.40004V8.40526V8.41049V8.41572V8.42096V8.4262V8.43145V8.4367V8.44195V8.44722V8.45248V8.45775V8.46303V8.46831V8.47359V8.47888V8.48417V8.48947V8.49478V8.50009V8.5054V8.51072V8.51604V8.52137V8.5267V8.53204V8.53739V8.54274V8.54809V8.55345V8.55881V8.56418V8.56956V8.57494V8.58032V8.58571V8.59111V8.59651V8.60191V8.60732V8.61274V8.61816V8.62359V8.62902V8.63445V8.6399V8.64534V8.6508V8.65626V8.66172V8.66719V8.67266V8.67814V8.68363V8.68912V8.69462V8.70012V8.70563V8.71114V8.71666V8.72218V8.72771V8.73325V8.73879V8.74433V8.74989V8.75544V8.76101V8.76658V8.77215V8.77773V8.78332V8.78891V8.79451V8.80011V8.80572V8.81133V8.81696V8.82258V8.82822V8.83385V8.8395V8.84515V8.85081V8.85647V8.86214V8.86781V8.87349V8.87918V8.88487V8.89057V8.89627V8.90198V8.9077V8.91342V8.91915V8.92488V8.93062V8.93637V8.94212V8.94788V8.95365V8.95942V8.9652V8.97098V8.97677V8.98257V8.98837V8.99418V9V12.5C16 13.6046 15.1046 14.5 14 14.5H5C3.89543 14.5 3 13.6046 3 12.5V11.5H2C0.895431 11.5 0 10.6046 0 9.5V3.5ZM13 5.50009V5.5H14C14.5522 5.5 15 5.94779 15 6.50013V6.50476V6.50939V6.51402V6.51865V6.52328V6.52791V6.53253V6.53715V6.54177V6.54639V6.55101V6.55563V6.56024V6.56485V6.56947V6.57408V6.57868V6.58329V6.5879V6.5925V6.59711V6.60171V6.60631V6.61091V6.6155V6.6201V6.62469V6.62929V6.63388V6.63847V6.64306V6.64765V6.65224V6.65682V6.66141V6.66599V6.67057V6.67516V6.67974V6.68431V6.68889V6.69347V6.69805V6.70262V6.70719V6.71177V6.71634V6.72091V6.72548V6.73005V6.73462V6.73918V6.74375V6.74832V6.75288V6.75744V6.76201V6.76657V6.77113V6.77569V6.78025V6.78481V6.78937V6.79392V6.79848V6.80304V6.80759V6.81215V6.8167V6.82125V6.82581V6.83036V6.83491V6.83946V6.84401V6.84856V6.85311V6.85766V6.86221V6.86675V6.8713V6.87585V6.88039V6.88494V6.88949V6.89403V6.89858V6.90312V6.90767V6.91221V6.91675V6.9213V6.92584V6.93038V6.93492V6.93947V6.94401V6.94855V6.95309V6.95763V6.96217V6.96672V6.97126V6.9758V6.98034V6.98488V6.98942V6.99396V6.9985V7.00304V7.00758V7.01213V7.01667V7.02121V7.02575V7.03029V7.03483V7.03937V7.04391V7.04845V7.053V7.05754V7.06208V7.06662V7.07117V7.07571V7.08025V7.08479V7.08934V7.09388V7.09843V7.10297V7.10752V7.11206V7.11661V7.12115V7.1257V7.13025V7.13479V7.13934V7.14389V7.14844V7.15299V7.15754V7.16209V7.16664V7.17119V7.17574V7.1803V7.18485V7.1894V7.19396V7.19851V7.20307V7.20763V7.21218V7.21674V7.2213V7.22586V7.23042V7.23498V7.23955V7.24411V7.24867V7.25324V7.2578V7.26237V7.26694V7.27151V7.27608V7.28065V7.28522V7.28979V7.29436V7.29894V7.30351V7.30809V7.31267V7.31724V7.32182V7.3264V7.33099V7.33557V7.34015V7.34474V7.34933V7.35391V7.3585V7.36309V7.36768V7.37228V7.37687V7.38146V7.38606V7.39066V7.39526V7.39986V7.40446V7.40907V7.41367V7.41828V7.42288V7.42749V7.4321V7.43672V7.44133V7.44594V7.45056V7.45518V7.4598V7.46442V7.46904V7.47367V7.4783V7.48292V7.48755V7.49218V7.49682V7.50145V7.50609V7.51073V7.51537V7.52001V7.52465V7.5293V7.53394V7.53859V7.54324V7.5479V7.55255V7.55721V7.56187V7.56653V7.57119V7.57585V7.58052V7.58519V7.58986V7.59453V7.59921V7.60388V7.60856V7.61324V7.61792V7.62261V7.62729V7.63198V7.63667V7.64137V7.64606V7.65076V7.65546V7.66016V7.66487V7.66958V7.67428V7.679V7.68371V7.68843V7.69314V7.69787V7.70259V7.70731V7.71204V7.71677V7.72151V7.72624V7.73098V7.73572V7.74046V7.74521V7.74996V7.75471V7.75946V7.76422V7.76898V7.77374V7.7785V7.78327V7.78804V7.79281V7.79758V7.80236V7.80714V7.81192V7.81671V7.8215V7.82629V7.83108V7.83588V7.84068V7.84548V7.85028V7.85509V7.8599V7.86472V7.86953V7.87435V7.87918V7.884V7.88883V7.89366V7.8985V7.90334V7.90818V7.91302V7.91787V7.92272V7.92757V7.93243V7.93729V7.94215V7.94702V7.95189V7.95676V7.96164V7.96652V7.9714V7.97628V7.98117V7.98606V7.99096V7.99586V8.00076V8.00567V8.01058V8.01549V8.0204V8.02532V8.03025V8.03517V8.0401V8.04504V8.04997V8.05491V8.05986V8.06481V8.06976V8.07471V8.07967V8.08463V8.0896V8.09457V8.09954V8.10452V8.1095V8.11448V8.11947V8.12446V8.12946V8.13446V8.13946V8.14447V8.14948V8.15449V8.15951V8.16453V8.16956V8.17459V8.17962V8.18466V8.1897V8.19475V8.1998V8.20485V8.20991V8.21497V8.22004V8.22511V8.23019V8.23526V8.24035V8.24543V8.25052V8.25562V8.26072V8.26582V8.27093V8.27604V8.28116V8.28628V8.2914V8.29653V8.30167V8.3068V8.31194V8.31709V8.32224V8.3274V8.33256V8.33772V8.34289V8.34806V8.35324V8.35842V8.36361V8.3688V8.37399V8.37919V8.3844V8.38961V8.39482V8.40004V8.40526V8.41049V8.41572V8.42096V8.4262V8.43145V8.4367V8.44195V8.44722V8.45248V8.45775V8.46303V8.46831V8.47359V8.47888V8.48417V8.48947V8.49478V8.50009V8.5054V8.51072V8.51604V8.52137V8.5267V8.53204V8.53739V8.54274V8.54809V8.55345V8.55881V8.56418V8.56956V8.57494V8.58032V8.58571V8.59111V8.59651V8.60191V8.60732V8.61274V8.61816V8.62359V8.62902V8.63445V8.6399V8.64534V8.6508V8.65626V8.66172V8.66719V8.67266V8.67814V8.68363V8.68912V8.69462V8.70012V8.70563V8.71114V8.71666V8.72218V8.72771V8.73325V8.73879V8.74433V8.74989V8.75544V8.76101V8.76658V8.77215V8.77773V8.78332V8.78891V8.79451V8.80011V8.80572V8.81133V8.81696V8.82258V8.82822V8.83385V8.8395V8.84515V8.85081V8.85647V8.86214V8.86781V8.87349V8.87918V8.88487V8.89057V8.89627V8.90198V8.9077V8.91342V8.91915V8.92488V8.93062V8.93637V8.94212V8.94788V8.95365V8.95942V8.9652V8.97098V8.97677V8.98257V8.98837V8.99418V9V12.5C15 13.0523 14.5523 13.5 14 13.5H5C4.44772 13.5 4 13.0523 4 12.5V11.5H11C12.1046 11.5 13 10.6046 13 9.5V6V5.99418V5.98837V5.98257V5.97677V5.97098V5.9652V5.95942V5.95365V5.94788V5.94212V5.93637V5.93062V5.92488V5.91915V5.91342V5.9077V5.90198V5.89627V5.89057V5.88487V5.87918V5.87349V5.86781V5.86214V5.85647V5.85081V5.84515V5.8395V5.83385V5.82822V5.82258V5.81696V5.81133V5.80572V5.80011V5.79451V5.78891V5.78332V5.77773V5.77215V5.76658V5.76101V5.75544V5.74989V5.74433V5.73879V5.73325V5.72771V5.72218V5.71666V5.71114V5.70563V5.70012V5.69462V5.68912V5.68363V5.67814V5.67266V5.66719V5.66172V5.65626V5.6508V5.64534V5.6399V5.63445V5.62902V5.62359V5.61816V5.61274V5.60732V5.60191V5.59651V5.59111V5.58571V5.58032V5.57494V5.56956V5.56418V5.55881V5.55345V5.54809V5.54274V5.53739V5.53204V5.5267V5.52137V5.51604V5.51072V5.5054V5.50009ZM1.04999 3.18693C1.01755 3.28541 1 3.39066 1 3.5V9.5C1 10.0523 1.44772 10.5 2 10.5H11C11.5523 10.5 12 10.0523 12 9.5V6V5.99418V5.98837V5.98257V5.97677V5.97098V5.9652V5.95942V5.95365V5.94788V5.94212V5.93637V5.93062V5.92488V5.91915V5.91342V5.9077V5.90198V5.89627V5.89057V5.88487V5.87918V5.87349V5.86781V5.86214V5.85647V5.85081V5.84515V5.8395V5.83385V5.82822V5.82258V5.81696V5.81133V5.80572V5.80011V5.79451V5.78891V5.78332V5.77773V5.77215V5.76658V5.76101V5.75544V5.74989V5.74433V5.73879V5.73325V5.72771V5.72218V5.71666V5.71114V5.70563V5.70012V5.69462V5.68912V5.68363V5.67814V5.67266V5.66719V5.66172V5.65626V5.6508V5.64534V5.6399V5.63445V5.62902V5.62359V5.61816V5.61274V5.60732V5.60191V5.59651V5.59111V5.58571V5.58032V5.57494V5.56956V5.56418V5.55881V5.55345V5.54809V5.54274V5.53739V5.53204V5.5267V5.52137V5.51604V5.51072V5.5054V5.50009V5.49478V5.48947V5.48417V5.47888V5.47359V5.46831V5.46303V5.45775V5.45248V5.44721V5.44195V5.4367V5.43145V5.4262V5.42096V5.41572V5.41049V5.40526V5.40004V5.39482V5.38961V5.3844V5.37919V5.37399V5.3688V5.36361V5.35842V5.35324V5.34806V5.34289V5.33772V5.33256V5.3274V5.32224V5.31709V5.31194V5.3068V5.30167V5.29653V5.2914V5.28628V5.28116V5.27604V5.27093V5.26582V5.26072V5.25562V5.25052V5.24543V5.24035V5.23526V5.23019V5.22511V5.22004V5.21497V5.20991V5.20485V5.1998V5.19475V5.1897V5.18466V5.17962V5.17459V5.16956V5.16453V5.15951V5.15449V5.14948V5.14447V5.13946V5.13446V5.12946V5.12446V5.11947V5.11448V5.1095V5.10452V5.09954V5.09457V5.0896V5.08463V5.07967V5.07471V5.06976V5.06481V5.05986V5.05491V5.04997V5.04504V5.0401V5.03517V5.03025V5.02532V5.02041V5.01549V5.01058V5.00567V5.00076V4.99586V4.99096V4.98606V4.98117V4.97628V4.9714V4.96652V4.96164V4.95676V4.95189V4.94702V4.94215V4.93729V4.93243V4.92757V4.92272V4.91787V4.91302V4.90818V4.90334V4.8985V4.89366V4.88883V4.884V4.87918V4.87435V4.86953V4.86472V4.8599V4.85509V4.85028V4.84548V4.84068V4.83588V4.83108V4.82629V4.8215V4.81671V4.81192V4.80714V4.80236V4.79758V4.79281V4.78804V4.78327V4.7785V4.77374V4.76898V4.76422V4.75946V4.75471V4.74996V4.74521V4.74046V4.73572V4.73098V4.72624V4.72151V4.71677V4.71204V4.70731V4.70259V4.69787V4.69315V4.68843V4.68371V4.679V4.67428V4.66958V4.66487V4.66016V4.65546V4.65076V4.64606V4.64137V4.63667V4.63198V4.62729V4.62261V4.61792V4.61324V4.60856V4.60388V4.5992V4.59453V4.58986V4.58519V4.58052V4.57585V4.57119V4.56653V4.56187V4.55721V4.55255V4.5479V4.54324V4.53859V4.53394V4.5293V4.52465V4.52001V4.51537V4.51073V4.50609V4.50145V4.49682V4.49218V4.48755V4.48292V4.4783V4.47367V4.46904V4.46442V4.4598V4.45518V4.45056V4.44595V4.44133V4.43672V4.4321V4.42749V4.42288V4.41828V4.41367V4.40907V4.40446V4.39986V4.39526V4.39066V4.38606V4.38147V4.37687V4.37228V4.36768V4.36309V4.3585V4.35391V4.34933V4.34474V4.34015V4.33557V4.33099V4.3264V4.32182V4.31724V4.31267V4.30809V4.30351V4.29894V4.29436V4.28979V4.28522V4.28065V4.27608V4.27151V4.26694V4.26237V4.2578V4.25324V4.24867V4.24411V4.23955V4.23498V4.23042V4.22586V4.2213V4.21674V4.21219V4.20763V4.20307V4.19851V4.19396V4.1894V4.18485V4.1803V4.17574V4.17119V4.16664V4.16209V4.15754V4.15299V4.14844V4.14389V4.13934V4.13479V4.13025V4.1257V4.12115V4.11661V4.11206V4.10752V4.10297V4.09843V4.09388V4.08934V4.08479V4.08025V4.07571V4.07116V4.06662V4.06208V4.05754V4.053V4.04845V4.04391V4.03937V4.03483V4.03029V4.02575V4.02121V4.01667V4.01212V4.00758V4.00304V3.9985V3.99396V3.98942V3.98488V3.98034V3.9758V3.97126V3.96672V3.96217V3.95763V3.95309V3.94855V3.94401V3.93947V3.93492V3.93038V3.92584V3.9213V3.91675V3.91221V3.90767V3.90312V3.89858V3.89403V3.88949V3.88494V3.88039V3.87585V3.8713V3.86675V3.86221V3.85766V3.85311V3.84856V3.84401V3.83946V3.83491V3.83036V3.82581V3.82125V3.8167V3.81215V3.80759V3.80304V3.79848V3.79392V3.78937V3.78481V3.78025V3.77569V3.77113V3.76657V3.76201V3.75744V3.75288V3.74832V3.74375V3.73918V3.73462V3.73005V3.72548V3.72091V3.71634V3.71177V3.70719V3.70262V3.69805V3.69347V3.68889V3.68431V3.67974V3.67516V3.67057V3.66599V3.66141V3.65682V3.65224V3.64765V3.64306V3.63847V3.63388V3.62929V3.62469V3.6201V3.6155V3.61091V3.60631V3.60171V3.59711V3.5925V3.5879V3.58329V3.57868V3.57408V3.56947V3.56485V3.56024V3.55563V3.55101V3.54639V3.54177V3.53715V3.53253V3.52791V3.52328V3.51865V3.51402V3.50939V3.50476V3.50013C12 3.39075 11.9824 3.28547 11.95 3.18695L7.13324 7.12793C6.76487 7.42932 6.23513 7.42932 5.86676 7.12793L1.04999 3.18693ZM1.81132 2.51777L6.5 6.35397L11.1887 2.51778C11.1276 2.50611 11.0645 2.5 11 2.5H2C1.9355 2.5 1.87242 2.50611 1.81132 2.51777Z",
          fill: ""
        })
      }
    };
  });
  var EyeIcon = /*#__PURE__*/createIconComponent("EyeIcon", "oxygen-icon oxygen-icon-eye", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M16 8C16 8 12.4183 13.5 8 13.5C3.58172 13.5 0 8 0 8C0 8 3.58172 2.5 8 2.5C12.4183 2.5 16 8 16 8ZM10.0003 8.00019C10.0003 8.27633 10.2242 8.50019 10.5003 8.50019C10.7765 8.50019 11.0003 8.27633 11.0003 8.00019C11.0003 6.34333 9.65719 5.00019 8.00034 5.00019C6.34348 5.00019 5.00034 6.34333 5.00034 8.00019C5.00034 9.65704 6.34349 11.0002 8.00034 11.0002C8.27648 11.0002 8.50034 10.7763 8.50034 10.5002C8.50034 10.224 8.27648 10.0002 8.00034 10.0002C6.89577 10.0002 6.00034 9.10476 6.00034 8.00019C6.00034 6.89562 6.89577 6.00019 8.00034 6.00019C9.10491 6.00019 10.0003 6.89562 10.0003 8.00019ZM1.41523 7.75815C1.34757 7.84433 1.2854 7.92526 1.22895 8C1.2854 8.07475 1.34757 8.15567 1.41523 8.24185C1.79878 8.73038 2.35207 9.37932 3.03181 10.0249C4.42946 11.3524 6.18747 12.5 8 12.5C9.81253 12.5 11.5705 11.3524 12.9682 10.0249C13.6479 9.37932 14.2012 8.73038 14.5848 8.24185C14.6524 8.15567 14.7146 8.07475 14.7711 8C14.7146 7.92526 14.6524 7.84433 14.5848 7.75815C14.2012 7.26962 13.6479 6.62068 12.9682 5.97508C11.5705 4.64763 9.81253 3.5 8 3.5C6.18747 3.5 4.42946 4.64763 3.03181 5.97508C2.35207 6.62068 1.79878 7.26962 1.41523 7.75815Z",
          fill: ""
        })
      }
    };
  });
  var EyeSlashIcon = /*#__PURE__*/createIconComponent("EyeSlashIcon", "oxygen-icon oxygen-icon-eye-slash", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M10.0003 8.00019C10.0003 8.27633 10.2242 8.50019 10.5003 8.50019C10.7765 8.50019 11.0003 8.27633 11.0003 8.00019C11.0003 6.34333 9.65719 5.00019 8.00034 5.00019C6.34348 5.00019 5.00034 6.34333 5.00034 8.00019C5.00034 9.65704 6.34349 11.0002 8.00034 11.0002C8.27648 11.0002 8.50034 10.7763 8.50034 10.5002C8.50034 10.224 8.27648 10.0002 8.00034 10.0002C6.89577 10.0002 6.00034 9.10476 6.00034 8.00019C6.00034 6.89562 6.89577 6.00019 8.00034 6.00019C9.10491 6.00019 10.0003 6.89562 10.0003 8.00019Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M16 8C16 8 12.4183 13.5 8 13.5C3.58172 13.5 0 8 0 8C0 8 3.58172 2.5 8 2.5C12.4183 2.5 16 8 16 8ZM1.41523 7.75815C1.34757 7.84433 1.2854 7.92526 1.22895 8C1.2854 8.07475 1.34757 8.15567 1.41523 8.24185C1.79878 8.73038 2.35207 9.37932 3.03181 10.0249C4.42946 11.3524 6.18747 12.5 8 12.5C9.81253 12.5 11.5705 11.3524 12.9682 10.0249C13.6479 9.37932 14.2012 8.73038 14.5848 8.24185C14.6524 8.15567 14.7146 8.07475 14.7711 8C14.7146 7.92526 14.6524 7.84433 14.5848 7.75815C14.2012 7.26962 13.6479 6.62068 12.9682 5.97508C11.5705 4.64763 9.81253 3.5 8 3.5C6.18747 3.5 4.42946 4.64763 3.03181 5.97508C2.35207 6.62068 1.79878 7.26962 1.41523 7.75815Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M13.8536 2.85355C14.0489 2.65829 14.0489 2.34171 13.8536 2.14645C13.6584 1.95118 13.3418 1.95118 13.1465 2.14645L2.14652 13.1464C1.95126 13.3417 1.95126 13.6583 2.14652 13.8536C2.34178 14.0488 2.65837 14.0488 2.85363 13.8536L13.8536 2.85355Z",
          fill: ""
        }))
      }
    };
  });
  var GearIcon = /*#__PURE__*/createIconComponent("GearIcon", "oxygen-icon oxygen-icon-gear", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M14.1384 4.50945L13.8267 4.82043L13.8981 4.95099C14.0694 5.28182 14.2127 5.62687 14.3261 5.98285L14.3687 6.12698L14.8085 6.12766C15.3812 6.12766 15.8658 6.53358 15.9786 7.10739L15.9946 7.21034L16 7.31915V8.68085C16 9.28727 15.5449 9.79488 14.9173 9.86691L14.8085 9.87234L14.3687 9.87166L14.3263 10.0166C14.2129 10.3727 14.0696 10.7179 13.8982 11.0488L13.8267 11.1782L14.1383 11.4904C14.5762 11.9283 14.602 12.6224 14.2156 13.0904L14.1383 13.1754L13.1754 14.1383C12.7101 14.6036 11.9557 14.6036 11.4906 14.1384L11.1782 13.8267L11.0488 13.8982C10.7179 14.0696 10.3727 14.2129 10.0166 14.3263L9.87166 14.3687L9.87234 14.8085C9.87234 15.4337 9.3909 15.9463 8.77857 15.9961L8.68085 16H7.31915C6.66111 16 6.12766 15.4666 6.12766 14.8089L6.12698 14.3687L5.98285 14.3261C5.62687 14.2127 5.28182 14.0694 4.95099 13.8981L4.82043 13.8267L4.5096 14.1383C4.07167 14.5762 3.37764 14.602 2.90958 14.2156L2.82458 14.1383L1.86171 13.1754C1.39641 12.7101 1.39641 11.9557 1.86156 11.4906L2.1726 11.1782L2.10182 11.0488C1.93043 10.7179 1.78712 10.3727 1.6737 10.0166L1.63064 9.87166L1.19149 9.87234C0.56635 9.87234 0.0536559 9.3909 0.00394971 8.77857L0 8.68085V7.31915C0 6.66111 0.533448 6.12766 1.19111 6.12766L1.63064 6.12698L1.67387 5.98285C1.78728 5.62687 1.93056 5.28182 2.10191 4.95099L2.1726 4.82043L1.86171 4.5096C1.46073 4.10863 1.402 3.48697 1.71944 3.0012L1.78338 2.9118L1.86171 2.82458L2.82458 1.86171C3.25062 1.43567 3.92578 1.39599 4.42238 1.78338L4.50945 1.86156L4.82111 2.1726L4.95116 2.10182C5.2821 1.93043 5.62727 1.78712 5.98339 1.6737L6.12766 1.63064V1.19149C6.12766 0.618759 6.53358 0.134164 7.10739 0.0214085L7.21034 0.00542797L7.31915 0H8.68085C9.28727 0 9.79488 0.455083 9.86691 1.08268L9.87234 1.19111V1.63064L10.0172 1.67387C10.3731 1.78728 10.7182 1.93056 11.049 2.10191L11.1789 2.1726L11.4904 1.86171C11.8914 1.46073 12.513 1.402 12.9988 1.71944L13.0882 1.78338L13.1754 1.86171L14.1383 2.82458C14.5643 3.25062 14.604 3.92578 14.2166 4.42238L14.1384 4.50945ZM12.9493 5.30008L13.015 5.42042C13.1568 5.6953 13.2756 5.98157 13.3702 6.27665L13.4096 6.41012L13.6209 7.12582L14.3671 7.12698L14.807 7.12766H14.8085C14.8854 7.12766 14.9677 7.17673 14.9946 7.28754L14.9984 7.31222L15 7.34407V8.68085C15 8.72892 14.9833 8.76944 14.9536 8.80207C14.9271 8.83135 14.8853 8.85901 14.8242 8.87031L14.7843 8.8723L14.3702 8.87166L13.6195 8.8705L13.4089 9.59105L13.37 9.72404C13.2756 10.0182 13.1572 10.3035 13.0161 10.5776L12.9514 10.6947L12.588 11.3526L13.1189 11.8846L13.4305 12.1968L13.4312 12.1975C13.4979 12.2642 13.5052 12.3689 13.4527 12.443L13.4144 12.4851L12.4683 13.4312C12.3935 13.506 12.2722 13.5059 12.1977 13.4313L12.197 13.4306L11.8846 13.1189L11.3526 12.588L10.6947 12.9514L10.5776 13.0161C10.3035 13.1572 10.0182 13.2756 9.72404 13.37L9.59105 13.4089L8.8705 13.6195L8.87166 14.3702L8.87234 14.8085L8.87234 14.809C8.87209 14.9048 8.80088 14.9848 8.70915 14.998L8.66065 15H7.31915C7.21319 15 7.12766 14.9141 7.12766 14.8089L7.12766 14.8073L7.12698 14.3671L7.12582 13.6209L6.41012 13.4096L6.27665 13.3702C5.98157 13.2756 5.6953 13.1568 5.42042 13.015L5.30008 12.9493L4.64209 12.5896L4.11248 13.1205L3.80249 13.4312L3.80239 13.4313C3.73571 13.4979 3.63104 13.5052 3.55699 13.4527L3.51489 13.4144L2.56882 12.4683C2.49396 12.3935 2.49412 12.2722 2.56867 12.1977L2.57015 12.1962L2.88118 11.8838L3.4087 11.3541L3.04989 10.6983L2.98479 10.5793C2.84295 10.3041 2.72403 10.0175 2.62939 9.72208L2.58924 9.58691L2.37643 8.8705L1.62909 8.87166L1.19149 8.87234L1.19098 8.87234C1.09519 8.87209 1.01515 8.80088 1.00196 8.70913L1 8.66065V7.31915C1 7.21319 1.08594 7.12766 1.19111 7.12766L1.19266 7.12766L1.63219 7.12698L2.37506 7.12582L2.58848 6.41427L2.62916 6.27863C2.72407 5.98224 2.84342 5.69473 2.98583 5.41872L3.05198 5.29654L3.40711 4.64062L2.87963 4.11325L2.56882 3.80249L2.56875 3.80243C2.5368 3.77045 2.52053 3.73331 2.51675 3.69325C2.51319 3.65558 2.52039 3.60903 2.5494 3.55975L2.56448 3.53867L2.58779 3.51271L3.53169 2.56882C3.5654 2.53511 3.60535 2.51843 3.64887 2.51617C3.68765 2.51415 3.73673 2.52356 3.78878 2.55843L3.82173 2.58801L4.11471 2.88041L4.64324 3.40789L5.29912 3.05095L5.41979 2.98528C5.69544 2.84314 5.98254 2.72399 6.2785 2.62921L6.41364 2.58887L7.12766 2.37578V1.63064V1.19149C7.12766 1.11462 7.17673 1.03232 7.28754 1.00542L7.31222 1.00159L7.34408 1H8.68085C8.72892 1 8.76943 1.01672 8.80207 1.04635C8.83136 1.07294 8.85903 1.1147 8.87033 1.17583L8.87234 1.21611V1.63064V2.37573L9.5863 2.58885L9.72196 2.62935C10.0178 2.72413 10.3048 2.84325 10.5804 2.98535L10.7009 3.05093L11.3567 3.4079L11.8853 2.88041L12.1968 2.56953L12.1975 2.56882C12.2295 2.53682 12.2667 2.52053 12.3068 2.51675C12.3444 2.51319 12.391 2.52039 12.4402 2.5494L12.4613 2.56448L12.4873 2.5878L13.4312 3.53169C13.4649 3.5654 13.4816 3.60535 13.4838 3.64887C13.4858 3.68765 13.4764 3.73673 13.4416 3.78878L13.4127 3.82092L13.1205 4.11248L12.5896 4.64209L12.9493 5.30008ZM11 8C11 9.65685 9.65685 11 8 11C6.34315 11 5 9.65685 5 8C5 6.34315 6.34315 5 8 5C9.65685 5 11 6.34315 11 8ZM12 8C12 10.2091 10.2091 12 8 12C5.79086 12 4 10.2091 4 8C4 5.79086 5.79086 4 8 4C10.2091 4 12 5.79086 12 8Z",
          fill: ""
        })
      }
    };
  });
  var GithubIcon = /*#__PURE__*/createIconComponent("GithubIcon", "oxygen-icon oxygen-icon-github", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.99926 0C3.58218 0 0 3.67234 0 8.20271C0 11.8267 2.29203 14.9008 5.47101 15.9855C5.87127 16.061 6.01713 15.8077 6.01713 15.5902C6.01713 15.3958 6.01025 14.8797 6.00632 14.1954C3.78109 14.6909 3.31158 13.0956 3.31158 13.0956C2.94767 12.148 2.42316 11.8957 2.42316 11.8957C1.6968 11.3871 2.47816 11.3972 2.47816 11.3972C3.28113 11.4551 3.70349 12.2426 3.70349 12.2426C4.41708 13.4959 5.57611 13.1339 6.03186 12.9239C6.10455 12.3942 6.3113 12.0327 6.53967 11.8277C4.76331 11.6208 2.89561 10.9168 2.89561 7.77369C2.89561 6.87839 3.20746 6.14574 3.71921 5.57271C3.6367 5.36525 3.36217 4.53088 3.79778 3.40193C3.79778 3.40193 4.46914 3.18138 5.99748 4.24285C6.63544 4.06057 7.32005 3.96993 8.00025 3.96641C8.67995 3.96993 9.36407 4.06057 10.003 4.24285C11.5304 3.18138 12.2007 3.40193 12.2007 3.40193C12.6373 4.53088 12.3628 5.36525 12.2808 5.57271C12.7935 6.14574 13.1029 6.87839 13.1029 7.77369C13.1029 10.9249 11.2323 11.6182 9.4505 11.8212C9.73732 12.0744 9.99319 12.575 9.99319 13.3404C9.99319 14.4366 9.98336 15.3213 9.98336 15.5902C9.98336 15.8097 10.1278 16.065 10.5334 15.985C13.7099 14.8978 16 11.8257 16 8.20271C16 3.67234 12.4178 0 7.99926 0Z",
          fill: ""
        })
      }
    };
  });
  var GlobeIcon = /*#__PURE__*/createIconComponent("GlobeIcon", "oxygen-icon oxygen-icon-globe", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M10.3875 1.16672C9.99112 1.05039 9.584 0.97453 9.17235 0.940303C8.26155 0.833182 7.3386 0.904968 6.45531 1.15163L6.40248 1.16672C4.8189 1.60156 3.42202 2.5446 2.42669 3.85079C1.43136 5.15698 0.892698 6.75398 0.893556 8.39618C0.894413 10.0384 1.43474 11.6348 2.43144 12.94C3.42813 14.2451 4.82599 15.1867 6.41003 15.6199C6.98991 15.7832 7.58878 15.8695 8.1912 15.8765C8.25839 15.8887 8.32671 15.8938 8.39498 15.8916C9.06598 15.8929 9.73395 15.8015 10.3799 15.6199C11.9626 15.1852 13.3588 14.243 14.3543 12.9381C15.3497 11.6331 15.8893 10.0375 15.8901 8.39618C15.891 6.75489 15.3531 5.1587 14.359 3.85269C13.365 2.54668 11.9697 1.60306 10.3875 1.16672ZM10.1837 1.89127C11.1609 2.16177 12.0646 2.64896 12.8276 3.31664C13.5907 3.98431 14.1935 4.81533 14.5913 5.74796H11.3762C10.9924 4.26622 10.2863 2.88747 9.3082 1.71013C9.604 1.74946 9.89658 1.81 10.1837 1.89127ZM8.39498 1.82334C9.42609 2.94021 10.1786 4.28497 10.5913 5.74796H6.18361C6.59448 4.28143 7.35306 2.93567 8.39498 1.82485V1.82334ZM10.7799 6.50269C11.0214 7.75153 11.0214 9.03507 10.7799 10.2839H6.01002C5.88228 9.66315 5.81904 9.03084 5.82133 8.39707C5.81942 7.76083 5.88265 7.12606 6.01002 6.50269H10.7799ZM6.55342 1.90636L6.60626 1.89127C6.89404 1.81459 7.18648 1.75661 7.48175 1.71768C6.49837 2.89032 5.78927 4.26777 5.40623 5.74947H2.20238C2.59861 4.82719 3.19433 4.00419 3.94667 3.33968C4.69901 2.67517 5.58927 2.18566 6.55342 1.90636ZM1.64766 8.39707C1.64778 7.75537 1.74186 7.11714 1.92691 6.50269H5.24019C5.12528 7.12762 5.06718 7.76167 5.0666 8.39707C5.06683 9.03 5.12494 9.66157 5.24019 10.2839H1.92691C1.74132 9.67217 1.64722 9.03635 1.64766 8.39707ZM6.60626 14.8953C5.62806 14.627 4.72333 14.1406 3.95997 13.4727C3.1966 12.8047 2.59442 11.9726 2.19861 11.0386H5.39868C5.7857 12.5237 6.50001 13.9033 7.4893 15.0765C7.19089 15.0379 6.89574 14.9774 6.60626 14.8953ZM6.18361 11.0386H10.5913C10.1836 12.5059 9.43047 13.8542 8.39498 14.9708C7.35952 13.8518 6.60197 12.5047 6.18361 11.0386ZM10.1837 14.8953C9.89267 14.9709 9.59793 15.0314 9.30066 15.0765C10.281 13.8995 10.9897 12.5208 11.3762 11.0386H14.5913C14.1944 11.9718 13.5919 12.8034 12.8287 13.4712C12.0655 14.1389 11.1613 14.6258 10.1837 14.8953ZM11.5422 10.2839C11.7762 9.03436 11.7762 7.75224 11.5422 6.50269H14.8555C15.0442 7.11632 15.1384 7.7551 15.1347 8.39707C15.1366 9.0359 15.0451 9.67156 14.863 10.2839H11.5422Z",
          fill: ""
        })
      }
    };
  });
  var GridDotsVerticalIcon = /*#__PURE__*/createIconComponent("GridDotsVerticalIcon", "oxygen-icon oxygen-icon-grid-dots-vertical", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_3144_31)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M5.71805 1.14286V1.14172L6.28949 1.14286H5.71805ZM5.71805 13.7143C6.34777 13.7143 6.86091 14.2274 6.86091 14.8571C6.86091 15.4869 6.34777 16 5.71805 16C5.0872 16 4.5752 15.4869 4.5752 14.8571C4.5752 14.2274 5.0872 13.7143 5.71805 13.7143ZM10.2895 13.7143C10.9192 13.7143 11.4323 14.2274 11.4323 14.8571C11.4323 15.4869 10.9192 16 10.2895 16C9.65863 16 9.14663 15.4869 9.14663 14.8571C9.14663 14.2274 9.65863 13.7143 10.2895 13.7143ZM5.71805 9.14286C6.34776 9.14286 6.8609 9.656 6.8609 10.2857C6.8609 10.9154 6.34776 11.4286 5.71805 11.4286C5.0872 11.4286 4.5752 10.9154 4.5752 10.2857C4.5752 9.656 5.0872 9.14286 5.71805 9.14286ZM10.2895 9.14286C10.9192 9.14286 11.4323 9.656 11.4323 10.2857C11.4323 10.9154 10.9192 11.4286 10.2895 11.4286C9.65862 11.4286 9.14662 10.9154 9.14662 10.2857C9.14662 9.656 9.65862 9.14286 10.2895 9.14286ZM5.71805 4.57142C6.34776 4.57142 6.8609 5.08457 6.8609 5.71428C6.8609 6.34399 6.34776 6.85713 5.71805 6.85713C5.0872 6.85713 4.5752 6.34399 4.5752 5.71428C4.5752 5.08457 5.0872 4.57142 5.71805 4.57142ZM10.2895 4.57142C10.9192 4.57142 11.4323 5.08457 11.4323 5.71428C11.4323 6.34399 10.9192 6.85713 10.2895 6.85713C9.65862 6.85713 9.14662 6.34399 9.14662 5.71428C9.14662 5.08457 9.65862 4.57142 10.2895 4.57142ZM5.71805 0C6.34776 0 6.8609 0.513142 6.8609 1.14286C6.8609 1.77258 6.34776 2.28572 5.71805 2.28572C5.0872 2.28572 4.5752 1.77258 4.5752 1.14286C4.5752 0.513142 5.0872 0 5.71805 0ZM10.2889 0C10.9186 0 11.4318 0.513142 11.4318 1.14286C11.4318 1.77258 10.9186 2.28572 10.2889 2.28572C9.6592 2.28572 9.14605 1.77258 9.14605 1.14286C9.14605 0.513142 9.6592 0 10.2889 0Z",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_3144_31"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "16",
          height: "16",
          fill: "white"
        }))))
      }
    };
  });
  var HexagonTwoIcon = /*#__PURE__*/createIconComponent("HexagonTwoIcon", "oxygen-icon oxygen-icon-hexagon-two", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.5974 1.15317L13.9323 4.11294C14.2966 4.31501 14.5 4.67398 14.5 5.04023V10.9598C14.5 11.326 14.2966 11.685 13.9323 11.8871L8.5974 14.8468C8.22928 15.0511 7.77072 15.0511 7.4026 14.8468L2.06766 11.8871C1.70343 11.685 1.5 11.326 1.5 10.9598V5.04023C1.5 4.67398 1.70343 4.31501 2.06766 4.11294L7.4026 1.15317C7.77072 0.948943 8.22928 0.948943 8.5974 1.15317ZM6.91747 0.278729C7.58734 -0.0929097 8.41266 -0.0929096 9.08253 0.278729L14.4175 3.2385C15.0873 3.61014 15.5 4.29695 15.5 5.04023V10.9598C15.5 11.703 15.0873 12.3899 14.4175 12.7615L9.08253 15.7213C8.41266 16.0929 7.58734 16.0929 6.91747 15.7213L1.58253 12.7615C0.912659 12.3899 0.5 11.703 0.5 10.9598V5.04023C0.5 4.29695 0.912659 3.61014 1.58253 3.2385L6.91747 0.278729ZM5.69948 10.7046V11.5001H10.4864V10.559H7.21227V10.5058L8.65758 8.99299C9.10029 8.54318 9.44593 8.16084 9.69451 7.84597C9.94309 7.52873 10.1171 7.24109 10.2165 6.98304C10.3183 6.72499 10.3692 6.46103 10.3692 6.19114C10.3692 5.80052 10.271 5.45014 10.0745 5.14C9.87799 4.8275 9.60455 4.58129 9.25417 4.40137C8.90616 4.21908 8.5037 4.12793 8.04679 4.12793C7.59461 4.12793 7.19096 4.22026 6.83585 4.40492C6.48073 4.58721 6.20138 4.84408 5.99778 5.17552C5.79418 5.50695 5.69238 5.89403 5.69238 6.33674H6.73997C6.73997 6.07632 6.79205 5.84905 6.89622 5.65492C7.00038 5.46079 7.14953 5.31046 7.34366 5.20392C7.53779 5.09739 7.76506 5.04412 8.02548 5.04412C8.27169 5.04412 8.49305 5.09266 8.68954 5.18972C8.88604 5.28442 9.0411 5.42054 9.15474 5.5981C9.26838 5.77329 9.3252 5.98162 9.3252 6.2231C9.3252 6.43617 9.28258 6.6374 9.19736 6.82679C9.11213 7.01619 8.9831 7.21624 8.81028 7.42694C8.63983 7.63527 8.42321 7.87793 8.16042 8.15492L5.69948 10.7046Z",
          fill: ""
        })
      }
    };
  });
  var HierarchyIcon = /*#__PURE__*/createIconComponent("HierarchyIcon", "oxygen-icon oxygen-icon-hierarchy", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.33333 0C4.59695 0 4 0.596954 4 1.33333V3.66667C4 4.40305 4.59695 5 5.33333 5H10.6667C11.403 5 12 4.40305 12 3.66667V1.33333C12 0.596954 11.403 0 10.6667 0H5.33333ZM10.6667 1H5.33333C5.14924 1 5 1.14924 5 1.33333V3.66667C5 3.85076 5.14924 4 5.33333 4H10.6667C10.8508 4 11 3.85076 11 3.66667V1.33333C11 1.14924 10.8508 1 10.6667 1Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 11.3C0 10.582 0.582025 10 1.3 10H2.7C3.41798 10 4 10.582 4 11.3V14.7C4 15.418 3.41797 16 2.7 16H1.3C0.582033 16 0 15.418 0 14.7V11.3ZM1.3 11C1.13431 11 1 11.1343 1 11.3V14.7C1 14.8657 1.13431 15 1.3 15H2.7C2.86569 15 3 14.8657 3 14.7V11.3C3 11.1343 2.86569 11 2.7 11H1.3Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6 11.3C6 10.582 6.58203 10 7.3 10H8.7C9.41797 10 10 10.582 10 11.3V14.7C10 15.418 9.41797 16 8.7 16H7.3C6.58203 16 6 15.418 6 14.7V11.3ZM9 11.3C9 11.1343 8.86569 11 8.7 11H7.3C7.13431 11 7 11.1343 7 11.3V14.7C7 14.8657 7.13431 15 7.3 15H8.7C8.86569 15 9 14.8657 9 14.7V11.3Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M12 11.3C12 10.582 12.582 10 13.3 10H14.7C15.418 10 16 10.582 16 11.3V14.7C16 15.418 15.418 16 14.7 16H13.3C12.582 16 12 15.418 12 14.7V11.3ZM13.3 11C13.1343 11 13 11.1343 13 11.3V14.7C13 14.8657 13.1343 15 13.3 15H14.7C14.8657 15 15 14.8657 15 14.7V11.3C15 11.1343 14.8657 11 14.7 11H13.3Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M7.5 5.66667H8.5V7H13.8333C14.2015 7 14.5 7.29848 14.5 7.66667V9H13.5V8H2.5V9H1.5V7.66667C1.5 7.29848 1.79848 7 2.16667 7H7.5V5.66667Z",
          fill: ""
        }))
      }
    };
  });
  var HomeIcon = /*#__PURE__*/createIconComponent("HomeIcon", "oxygen-icon oxygen-icon-home", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5 15.993H2C0.895431 15.993 0 15.0976 0 13.993V6.37428C0 5.73526 0.305378 5.13471 0.821753 4.75824L6.82175 0.383904C7.52386 -0.127968 8.47614 -0.127968 9.17825 0.383904L15.1782 4.75824C15.6946 5.1347 16 5.73526 16 6.37428V13.993C16 15.0976 15.1046 15.993 14 15.993H11V16H5V15.993ZM1.41088 5.56626L7.41088 1.19193C7.76193 0.93599 8.23807 0.935991 8.58912 1.19193L14.5891 5.56626C14.8473 5.75449 15 6.05477 15 6.37428V13.993C15 14.5453 14.5523 14.993 14 14.993H11V10.335C11 9.41459 10.2538 8.66842 9.33333 8.66842H6.66667C5.74619 8.66842 5 9.41459 5 10.335V14.993H2C1.44772 14.993 1 14.5453 1 13.993V6.37428C1 6.05477 1.15269 5.75449 1.41088 5.56626ZM10 14.993H6V10.335C6 9.96686 6.29848 9.66839 6.66667 9.66839H9.33333C9.70152 9.66839 10 9.96686 10 10.335V14.993Z",
          fill: ""
        })
      }
    };
  });
  var HomeContainedIcon = /*#__PURE__*/createIconComponent("HomeContainedIcon", "oxygen-icon oxygen-icon-home-contained", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7 1H9C12.3137 1 15 3.68629 15 7V9C15 12.3137 12.3137 15 9 15H7C3.68629 15 1 12.3137 1 9V7C1 3.68629 3.68629 1 7 1ZM0 7C0 3.13401 3.13401 0 7 0H9C12.866 0 16 3.13401 16 7V9C16 12.866 12.866 16 9 16H7C3.13401 16 0 12.866 0 9V7ZM8.25725 3.57125L8 3.4169L7.74275 3.57125L2.74275 6.57125C2.50596 6.71333 2.42918 7.02046 2.57125 7.25725C2.71333 7.49404 3.02046 7.57082 3.25725 7.42875L4 6.9831V10.5C4 11.3284 4.67157 12 5.5 12H10.5C11.3284 12 12 11.3284 12 10.5V6.9831L12.7428 7.42875C12.9795 7.57082 13.2867 7.49404 13.4287 7.25725C13.5708 7.02046 13.494 6.71333 13.2572 6.57125L8.25725 3.57125ZM11 6.38309L8 4.5831L5 6.38309V10.5C5 10.7761 5.22386 11 5.5 11H6.75V9.5C6.75 8.94772 7.19772 8.5 7.75 8.5H8.25C8.80228 8.5 9.25 8.94771 9.25 9.5V11H10.5C10.7761 11 11 10.7761 11 10.5V6.38309ZM8.25 9.5V11H7.75V9.5H8.25Z",
          fill: ""
        })
      }
    };
  });
  var HomeFilledIcon = /*#__PURE__*/createIconComponent("HomeFilledIcon", "oxygen-icon oxygen-icon-home-filled", function () {
    return {
      "18": {
        "width": 18,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_358_2197)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M9.00001 0.092453L17.6723 5.00147C18.0146 5.2347 18.103 5.70127 17.8698 6.04358C17.6578 6.35477 17.2529 6.45613 16.9239 6.29676L16.8277 6.24107L16.2499 5.92145L16.25 15.25C16.25 16.7125 15.1083 17.9084 13.6675 17.995L13.5 18H4.50001C3.03748 18 1.84161 16.8583 1.75503 15.4175L1.75001 15.25L1.74994 5.92045L1.17232 6.24107C0.861135 6.4531 0.447251 6.39931 0.199337 6.13059L0.130211 6.04358C-0.081822 5.73239 -0.028024 5.31851 0.24069 5.0706L0.327701 5.00147L9.00001 0.092453Z",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_358_2197"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "18",
          height: "18",
          fill: "white"
        }))))
      }
    };
  });
  var HorizontalBarsFilterIcon = /*#__PURE__*/createIconComponent("HorizontalBarsFilterIcon", "oxygen-icon oxygen-icon-horizontal-bars-filter", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M7.08588 13.3529C6.88588 13.3529 6.71827 13.2853 6.58306 13.1499C6.44769 13.0145 6.38 12.8468 6.38 12.6468C6.38 12.4467 6.44769 12.2791 6.58306 12.144C6.71827 12.0088 6.88588 11.9412 7.08588 11.9412H8.90494C9.10494 11.9412 9.27263 12.0089 9.408 12.1442C9.54322 12.2796 9.61082 12.4473 9.61082 12.6473C9.61082 12.8475 9.54322 13.0151 9.408 13.1501C9.27263 13.2853 9.10494 13.3529 8.90494 13.3529H7.08588ZM3.43882 8.88235C3.23882 8.88235 3.07122 8.81467 2.936 8.67929C2.80078 8.54392 2.73318 8.37624 2.73318 8.17624C2.73318 7.97608 2.80078 7.80847 2.936 7.67341C3.07122 7.5382 3.23882 7.47059 3.43882 7.47059H12.552C12.752 7.47059 12.9197 7.53827 13.0551 7.67365C13.1903 7.80902 13.2579 7.97671 13.2579 8.17671C13.2579 8.37686 13.1903 8.54447 13.0551 8.67953C12.9197 8.81475 12.752 8.88235 12.552 8.88235H3.43882ZM0.705882 4.41176C0.505882 4.41176 0.338275 4.34408 0.203059 4.20871C0.0676864 4.07333 0 3.90565 0 3.70565C0 3.50549 0.0676864 3.33788 0.203059 3.20282C0.338275 3.06761 0.505882 3 0.705882 3H15.2941C15.4941 3 15.6617 3.06769 15.7969 3.20306C15.9323 3.33843 16 3.50612 16 3.70612C16 3.90627 15.9323 4.07388 15.7969 4.20894C15.6617 4.34416 15.4941 4.41176 15.2941 4.41176H0.705882Z",
          fill: ""
        })
      }
    };
  });
  var KeyFlowIcon = /*#__PURE__*/createIconComponent("KeyFlowIcon", "oxygen-icon oxygen-icon-key-flow", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.31933 4.62284L3.29508 4.34901C3.56095 4.27439 3.83697 4.42944 3.91158 4.69531C3.9862 4.96118 3.83115 5.2372 3.56528 5.31181L1.52287 5.885L1.04146 6.0201L0.906363 5.53869L0.333179 3.49628C0.258565 3.23041 0.413609 2.95439 0.67948 2.87978C0.945351 2.80516 1.22137 2.96021 1.29598 3.22608L1.51793 4.01693C3.48703 0.865274 7.53794 -0.408348 11.0046 1.18389C11.8994 1.5949 12.6757 2.16058 13.3155 2.83501C13.5055 3.03536 13.4972 3.35183 13.2968 3.54187C13.0965 3.73191 12.78 3.72355 12.59 3.52321C12.0365 2.93971 11.3643 2.44954 10.5872 2.09262C7.55546 0.700133 4.0081 1.83677 2.31933 4.62284ZM3.1585 12.4755C2.96846 12.2752 2.65199 12.2668 2.45164 12.4569C2.25129 12.6469 2.24294 12.9634 2.43298 13.1637C3.07271 13.8382 3.84902 14.4039 4.74386 14.8149C8.4472 16.5158 12.8173 14.9462 14.6039 11.3103L15.0671 12.1126C15.2052 12.3518 15.511 12.4337 15.7501 12.2957C15.9893 12.1576 16.0712 11.8518 15.9331 11.6126L14.8725 9.77553L14.6225 9.34251L14.1895 9.59251L12.3524 10.6532C12.1132 10.7912 12.0313 11.097 12.1693 11.3362C12.3074 11.5753 12.6132 11.6573 12.8524 11.5192L13.5913 11.0925C11.9768 14.0836 8.29381 15.3449 5.16124 13.9061C4.38415 13.5492 3.71198 13.059 3.1585 12.4755ZM9.12513 8.18735C10.2815 8.18735 11.2189 7.24995 11.2189 6.0936C11.2189 4.93725 10.2815 3.99985 9.12513 3.99985C7.96878 3.99985 7.03138 4.93725 7.03138 6.0936C7.03138 7.24995 7.96878 8.18735 9.12513 8.18735ZM9.12513 9.18735C10.8338 9.18735 12.2189 7.80223 12.2189 6.0936C12.2189 4.38497 10.8338 2.99985 9.12513 2.99985C7.4165 2.99985 6.03138 4.38497 6.03138 6.0936C6.03138 6.396 6.07476 6.68827 6.15565 6.96451C6.12738 6.98304 6.10056 7.00472 6.07572 7.02957L3.17586 9.92942C3.06334 10.0419 3.00013 10.1946 3.00013 10.3537V11.6186C3.00013 11.95 3.26876 12.2186 3.60013 12.2186H5.42746C5.58659 12.2186 5.7392 12.1554 5.85172 12.0429L6.35564 11.5389C6.46816 11.4264 6.53138 11.2738 6.53138 11.1147V10.8123H7.11496C7.27409 10.8123 7.4267 10.7491 7.53922 10.6365L8.91618 9.25957C8.93977 9.23598 8.9605 9.21063 8.97839 9.18393C9.02702 9.1862 9.07594 9.18735 9.12513 9.18735ZM4.00013 10.5194L6.61586 7.90364C6.9302 8.33865 7.35488 8.68867 7.84887 8.91267L6.94927 9.81226H6.13138C5.80001 9.81226 5.53138 10.0809 5.53138 10.4123V10.949L5.26177 11.2186H4.00013V10.5194Z",
          fill: ""
        })
      }
    };
  });
  var LanguageIcon = /*#__PURE__*/createIconComponent("LanguageIcon", "oxygen-icon oxygen-icon-language", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.00013 0C5.27627 0 5.50013 0.223858 5.50013 0.5V1H7.49497H7.50425H9.50013C9.77627 1 10.0001 1.22386 10.0001 1.5C10.0001 1.77614 9.77627 2 9.50013 2H7.95538C7.78802 3.45848 7.25446 5.67729 5.84346 7.75992C6.08727 7.87233 6.33942 7.95796 6.59818 8.00971C6.86896 8.06387 7.04457 8.32728 6.99042 8.59806C6.93626 8.86884 6.67285 9.04445 6.40207 8.99029C5.98941 8.90776 5.60002 8.7629 5.23676 8.57659C4.16654 9.8924 2.69966 11.1013 0.697086 11.9596C0.443271 12.0684 0.149332 11.9508 0.040554 11.697C-0.0682238 11.4431 0.049352 11.1492 0.303167 11.0404C2.08777 10.2756 3.40928 9.20581 4.38402 8.03603C4.09136 7.81409 3.82291 7.57176 3.5809 7.32535C2.85391 6.58514 2.32435 5.76648 2.05291 5.22361C1.92942 4.97662 2.02953 4.67628 2.27652 4.55279C2.52351 4.42929 2.82385 4.5294 2.94734 4.77639C3.17591 5.23352 3.64635 5.96486 4.29435 6.62465C4.51082 6.84505 4.74258 7.0529 4.98725 7.23852C6.27043 5.36652 6.77852 3.36369 6.9485 2H5.00013H0.500127C0.223984 2 0.000126539 1.77614 0.000126539 1.5C0.000126539 1.22386 0.223984 1 0.500127 1H4.50013V0.5C4.50013 0.223858 4.72398 0 5.00013 0ZM7.09126 15.2811C6.96968 15.5291 7.07216 15.8286 7.32014 15.9502C7.56807 16.0718 7.86763 15.9693 7.98915 15.7214L9.44795 12.7458C9.47188 12.7493 9.49629 12.7511 9.52119 12.7511H13.5212C13.546 12.7511 13.5704 12.7493 13.5943 12.7458L15.0531 15.7214C15.1746 15.9693 15.4741 16.0718 15.7221 15.9502C15.97 15.8286 16.0725 15.5291 15.9509 15.2811L11.9892 7.2C11.8994 7.01684 11.7127 6.91308 11.5213 6.92034C11.3298 6.91308 11.1428 7.01684 11.053 7.2L7.09126 15.2811ZM13.1066 11.7511H9.93556L11.5211 8.51696L13.1066 11.7511Z",
          fill: ""
        })
      }
    };
  });
  var LightbulbOnIcon = /*#__PURE__*/createIconComponent("LightbulbOnIcon", "oxygen-icon oxygen-icon-lightbulb-on", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.5 0.5C8.5 0.223858 8.27614 0 8 0C7.72386 0 7.5 0.223858 7.5 0.5V1.5C7.5 1.77614 7.72386 2 8 2C8.27614 2 8.5 1.77614 8.5 1.5V0.5ZM4.68301 1.25488C4.54494 1.01574 4.23915 0.933799 4 1.07187C3.76085 1.20994 3.67892 1.51574 3.81699 1.75488L4.31699 2.62091C4.45506 2.86005 4.76085 2.94199 5 2.80392C5.23915 2.66585 5.32108 2.36005 5.18301 2.12091L4.68301 1.25488ZM12 8C12 10.2091 10.2091 12 8 12C5.79086 12 4 10.2091 4 8C4 5.79086 5.79086 4 8 4C10.2091 4 12 5.79086 12 8ZM9.5 12.7711C9.02648 12.9198 8.5226 13 8 13C7.4774 13 6.97352 12.9198 6.5 12.7711V14C6.5 14.2761 6.72386 14.5 7 14.5H8H9C9.27614 14.5 9.5 14.2761 9.5 14V12.7711ZM8 16C7.72386 16 7.5 15.7761 7.5 15.5H7C6.17157 15.5 5.5 14.8284 5.5 14V12.3311C4.0055 11.4666 3 9.85071 3 8C3 5.23858 5.23858 3 8 3C10.7614 3 13 5.23858 13 8C13 9.85071 11.9945 11.4666 10.5 12.3311V14C10.5 14.8284 9.82843 15.5 9 15.5H8.5C8.5 15.7761 8.27614 16 8 16ZM0.5 7.5C0.223858 7.5 0 7.72386 0 8C0 8.27614 0.223858 8.5 0.5 8.5H1.5C1.77614 8.5 2 8.27614 2 8C2 7.72386 1.77614 7.5 1.5 7.5H0.5ZM14 8C14 7.72386 14.2239 7.5 14.5 7.5H15.5C15.7761 7.5 16 7.72386 16 8C16 8.27614 15.7761 8.5 15.5 8.5H14.5C14.2239 8.5 14 8.27614 14 8ZM12 1.07187C12.2391 1.20994 12.3211 1.51574 12.183 1.75488L11.683 2.62091C11.5449 2.86005 11.2391 2.94199 11 2.80392C10.7609 2.66585 10.6789 2.36005 10.817 2.12091L11.317 1.25488C11.4551 1.01574 11.7609 0.933799 12 1.07187ZM1.07187 12C0.933799 11.7609 1.01574 11.4551 1.25488 11.317L2.12091 10.817C2.36005 10.6789 2.66585 10.7609 2.80392 11C2.94199 11.2391 2.86005 11.5449 2.62091 11.683L1.75488 12.183C1.51574 12.3211 1.20994 12.2391 1.07187 12ZM13.3789 4.31699C13.1398 4.45506 13.0578 4.76085 13.1959 5C13.334 5.23915 13.6398 5.32108 13.8789 5.18301L14.7449 4.68301C14.9841 4.54494 15.066 4.23915 14.9279 4C14.7899 3.76085 14.4841 3.67892 14.2449 3.81699L13.3789 4.31699ZM1.07187 4C1.20994 3.76085 1.51574 3.67892 1.75488 3.81699L2.62091 4.31699C2.86005 4.45506 2.94199 4.76085 2.80392 5C2.66585 5.23915 2.36005 5.32108 2.12091 5.18301L1.25488 4.68301C1.01574 4.54494 0.933799 4.23915 1.07187 4ZM13.8789 10.817C13.6398 10.6789 13.334 10.7609 13.1959 11C13.0578 11.2391 13.1398 11.5449 13.3789 11.683L14.2449 12.183C14.4841 12.3211 14.7899 12.2391 14.9279 12C15.066 11.7609 14.9841 11.4551 14.7449 11.317L13.8789 10.817Z",
          fill: ""
        })
      }
    };
  });
  var LinearNodesIcon = /*#__PURE__*/createIconComponent("LinearNodesIcon", "oxygen-icon oxygen-icon-linear-nodes", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M15 2C15 2.55228 14.5523 3 14 3C13.4477 3 13 2.55228 13 2C13 1.44772 13.4477 1 14 1C14.5523 1 15 1.44772 15 2ZM16 2C16 3.10457 15.1046 4 14 4C13.9371 4 13.8748 3.99709 13.8133 3.9914L12.4811 6.65593C12.8035 7.01102 13 7.48256 13 8C13 9.10457 12.1046 10 11 10C10.0681 10 9.28503 9.36261 9.06301 8.5H6.93699C6.71497 9.36261 5.93192 10 5 10C4.77659 10 4.56174 9.96337 4.36112 9.89579L3.13314 12.3517C3.65675 12.7124 4 13.3161 4 14C4 15.1046 3.10457 16 2 16C0.895431 16 0 15.1046 0 14C0 12.8954 0.895431 12 2 12C2.06295 12 2.12522 12.0029 2.18668 12.0086L3.51895 9.34407C3.1965 8.98898 3 8.51744 3 8C3 6.89543 3.89543 6 5 6C5.93192 6 6.71497 6.63739 6.93699 7.5H9.06301C9.28503 6.63739 10.0681 6 11 6C11.2234 6 11.4383 6.03663 11.6389 6.10421L12.8669 3.64825C12.3432 3.28759 12 2.68388 12 2C12 0.895431 12.8954 0 14 0C15.1046 0 16 0.895431 16 2ZM5 9C5.55228 9 6 8.55228 6 8C6 7.44772 5.55228 7 5 7C4.44772 7 4 7.44772 4 8C4 8.55228 4.44772 9 5 9ZM10 8C10 8.55228 10.4477 9 11 9C11.5523 9 12 8.55228 12 8C12 7.44772 11.5523 7 11 7C10.4477 7 10 7.44772 10 8ZM2 15C2.55228 15 3 14.5523 3 14C3 13.4477 2.55228 13 2 13C1.44772 13 1 13.4477 1 14C1 14.5523 1.44772 15 2 15Z",
          fill: ""
        })
      }
    };
  });
  var LinkIcon = /*#__PURE__*/createIconComponent("LinkIcon", "oxygen-icon oxygen-icon-link", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_1_3243)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.2962 6.19085C3.49603 5.99102 3.82003 5.99102 4.01986 6.19085C4.19749 6.36848 4.21722 6.64421 4.07907 6.84364L4.01986 6.91451L2.57254 8.36183C1.1737 9.76067 1.1737 12.0286 2.57254 13.4275C3.92474 14.7797 6.0891 14.8247 7.49545 13.5627L7.63816 13.4275L9.08548 11.9801C9.28532 11.7803 9.60931 11.7803 9.80914 11.9801C9.98677 12.1578 10.0065 12.4335 9.86835 12.6329L9.80914 12.7038L8.36182 14.1511C6.56332 15.9496 3.64738 15.9496 1.84888 14.1511C0.101761 12.404 0.0518429 9.60239 1.69912 7.79501L1.84888 7.63817L3.2962 6.19085ZM7.63817 1.84888C9.43667 0.0503749 12.3526 0.0503749 14.1511 1.84888C15.8982 3.59599 15.9482 6.39761 14.3009 8.20498L14.1511 8.36182L12.7038 9.80914C12.504 10.009 12.18 10.009 11.9801 9.80914C11.8025 9.63151 11.7828 9.35578 11.9209 9.15635L11.9801 9.08548L13.4275 7.63816C14.8263 6.23933 14.8263 3.97137 13.4275 2.57254C12.0753 1.22033 9.9109 1.17526 8.50455 2.43732L8.36183 2.57254L6.91451 4.01986C6.71468 4.21969 6.39068 4.21969 6.19085 4.01986C6.01322 3.84223 5.99348 3.5665 6.13164 3.36707L6.19085 3.2962L7.63817 1.84888ZM11.4322 4.56808C11.2324 4.36817 10.9084 4.36805 10.7085 4.5678L4.56343 10.7083L4.50419 10.7791C4.36596 10.9785 4.38559 11.2542 4.56316 11.4319C4.76292 11.6318 5.08691 11.632 5.28682 11.4322L11.4319 5.29174L11.4911 5.22089C11.6294 5.02151 11.6097 4.74577 11.4322 4.56808Z",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_1_3243"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "16",
          height: "16",
          fill: "white"
        }))))
      }
    };
  });
  var LogsDocumentIcon = /*#__PURE__*/createIconComponent("LogsDocumentIcon", "oxygen-icon oxygen-icon-logs-document", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3 0C2.17157 0 1.5 0.671573 1.5 1.5V5C1.5 5.27614 1.72386 5.5 2 5.5C2.27614 5.5 2.5 5.27614 2.5 5V1.5C2.5 1.22386 2.72386 1 3 1H13C13.2761 1 13.5 1.22386 13.5 1.5V5C13.5 5.27614 13.7239 5.5 14 5.5C14.2761 5.5 14.5 5.27614 14.5 5V1.5C14.5 0.671573 13.8284 0 13 0H3ZM2.5 14C2.5 13.7239 2.27614 13.5 2 13.5C1.72386 13.5 1.5 13.7239 1.5 14V14.5C1.5 15.3284 2.17157 16 3 16H13C13.8284 16 14.5 15.3284 14.5 14.5V14C14.5 13.7239 14.2761 13.5 14 13.5C13.7239 13.5 13.5 13.7239 13.5 14V14.5C13.5 14.7761 13.2761 15 13 15H3C2.72386 15 2.5 14.7761 2.5 14.5V14ZM7.15743 11.8042C6.80917 11.8042 6.48645 11.7419 6.18927 11.6172C5.89209 11.4926 5.63206 11.3194 5.40917 11.0978C5.19093 10.8716 5.02145 10.6061 4.90072 10.3014C4.77999 9.99672 4.71962 9.66431 4.71962 9.3042C4.71962 8.94409 4.77999 8.61168 4.90072 8.30697C5.02145 8.00226 5.19093 7.7391 5.40917 7.5175C5.63206 7.29127 5.89209 7.11583 6.18927 6.99118C6.48645 6.86653 6.80917 6.8042 7.15743 6.8042C7.51033 6.8042 7.83538 6.86653 8.13256 6.99118C8.42974 7.11583 8.68745 7.29127 8.90569 7.5175C9.12393 7.74372 9.29342 8.00919 9.41415 8.31389C9.53488 8.61399 9.59524 8.94409 9.59524 9.3042C9.59524 9.65969 9.53488 9.98979 9.41415 10.2945C9.29342 10.5992 9.12393 10.8647 8.90569 11.0909C8.68745 11.3171 8.42974 11.4926 8.13256 11.6172C7.83538 11.7419 7.51033 11.8042 7.15743 11.8042ZM7.15743 10.9455C7.38032 10.9455 7.58231 10.9062 7.7634 10.8277C7.94914 10.7446 8.10934 10.6292 8.244 10.4815C8.37866 10.3291 8.48314 10.1537 8.55743 9.95517C8.63637 9.75665 8.67584 9.53966 8.67584 9.3042C8.67584 9.06874 8.63637 8.85175 8.55743 8.65323C8.48314 8.45471 8.37866 8.28158 8.244 8.13384C8.10934 7.98148 7.94914 7.86606 7.7634 7.78758C7.58231 7.70448 7.38032 7.66293 7.15743 7.66293C6.93919 7.66293 6.7372 7.70448 6.55146 7.78758C6.36572 7.86606 6.20552 7.97918 6.07086 8.12691C5.9362 8.27465 5.83173 8.44778 5.75743 8.64631C5.68314 8.84483 5.64599 9.06413 5.64599 9.3042C5.64599 9.53966 5.68314 9.75895 5.75743 9.96209C5.83173 10.1606 5.9362 10.3337 6.07086 10.4815C6.20552 10.6292 6.36572 10.7446 6.55146 10.8277C6.7372 10.9062 6.93919 10.9455 7.15743 10.9455ZM1 11.7349V6.8873H1.90547V10.9039H4.15522V11.7349H1ZM11.7751 11.6172C12.0862 11.7419 12.4252 11.8042 12.792 11.8042C13.1032 11.8042 13.391 11.7534 13.6557 11.6518C13.925 11.5457 14.1595 11.3979 14.3592 11.2086C14.5635 11.0193 14.7214 10.7954 14.8328 10.5369C14.9443 10.2737 15 9.98287 15 9.66431C15 9.62276 14.9977 9.57428 14.993 9.51888C14.993 9.45886 14.9907 9.39884 14.9861 9.33883C14.9814 9.27419 14.9745 9.21648 14.9652 9.1657H12.7572V9.96902H14.0736V9.97594C14.0736 10.1144 14.0411 10.2437 13.9761 10.3638C13.9158 10.4838 13.8275 10.59 13.7114 10.6823C13.5954 10.77 13.463 10.8393 13.3144 10.8901C13.1658 10.9409 13.0056 10.9662 12.8338 10.9662C12.6063 10.9662 12.3904 10.9247 12.1861 10.8416C11.9864 10.7539 11.81 10.6338 11.6567 10.4815C11.5035 10.3291 11.3828 10.1514 11.2945 9.94824C11.2109 9.7451 11.1692 9.53042 11.1692 9.3042C11.1692 9.06874 11.2109 8.85175 11.2945 8.65323C11.3781 8.45471 11.4919 8.28158 11.6358 8.13384C11.7844 7.9861 11.9562 7.87068 12.1512 7.78758C12.3509 7.70448 12.5668 7.66293 12.799 7.66293C12.9569 7.66293 13.1101 7.68601 13.2587 7.73218C13.4073 7.77835 13.5489 7.84298 13.6836 7.92608C13.8229 8.00919 13.9575 8.11306 14.0876 8.23772L14.6587 7.64215C14.5333 7.48518 14.3755 7.34437 14.1851 7.21971C13.9947 7.09506 13.7811 6.99811 13.5443 6.92885C13.3075 6.8596 13.0614 6.82497 12.806 6.82497C12.4438 6.82497 12.1048 6.8873 11.7891 7.01196C11.4779 7.13661 11.2063 7.31205 10.9741 7.53827C10.742 7.75988 10.5609 8.02304 10.4308 8.32775C10.3055 8.62784 10.2428 8.95332 10.2428 9.3042C10.2428 9.65969 10.3055 9.98979 10.4308 10.2945C10.5562 10.5946 10.7327 10.8578 10.9602 11.084C11.1924 11.3102 11.464 11.4879 11.7751 11.6172Z",
          fill: ""
        })
      }
    };
  });
  var MagnifyingGlassIcon = /*#__PURE__*/createIconComponent("MagnifyingGlassIcon", "oxygen-icon oxygen-icon-magnifying-glass", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6.5 0C2.91015 0 0 2.91015 0 6.5C0 10.0899 2.91015 13 6.5 13C8.11495 13 9.59234 12.411 10.7291 11.4362L14.1464 14.8536L14.2157 14.9114C14.4106 15.0464 14.68 15.0271 14.8536 14.8536C15.0488 14.6583 15.0488 14.3417 14.8536 14.1464L11.4362 10.7291C12.411 9.59234 13 8.11495 13 6.5C13 2.91015 10.0899 0 6.5 0ZM6.5 1C9.53757 1 12 3.46243 12 6.5C12 9.53757 9.53757 12 6.5 12C3.46243 12 1 9.53757 1 6.5C1 3.46243 3.46243 1 6.5 1Z",
          fill: ""
        })
      }
    };
  });
  var MessageAsteriskIcon = /*#__PURE__*/createIconComponent("MessageAsteriskIcon", "oxygen-icon oxygen-icon-message-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.5 2C1.11929 2 0 3.11929 0 4.5V14.5534C0 15.5875 1.37784 15.9414 1.87622 15.0353L3.40316 12.259C3.49104 12.0993 3.65893 12 3.84127 12H5C5.27614 12 5.5 11.7761 5.5 11.5C5.5 11.2239 5.27614 11 5 11H3.84127C3.29423 11 2.79057 11.2978 2.52695 11.7771L1 14.5534V4.5C1 3.67157 1.67157 3 2.5 3H13.5C14.3284 3 15 3.67157 15 4.5V9.5C15 9.77614 15.2239 10 15.5 10C15.7761 10 16 9.77614 16 9.5V4.5C16 3.11929 14.8807 2 13.5 2H2.5ZM8.62718 11.3369C8.58208 10.8877 7.91792 10.8877 7.87282 11.3369L7.74264 12.6336L6.53863 12.0964C6.12154 11.9103 5.78945 12.4774 6.16145 12.7405L7.23528 13.5L6.16145 14.2595C5.78945 14.5226 6.12154 15.0897 6.53863 14.9036L7.74264 14.3664L7.87282 15.6631C7.91792 16.1123 8.58208 16.1123 8.62718 15.6631L8.75736 14.3664L9.96137 14.9036C10.3785 15.0897 10.7105 14.5226 10.3385 14.2595L9.26472 13.5L10.3385 12.7405C10.7105 12.4774 10.3785 11.9103 9.96137 12.0964L8.75736 12.6336L8.62718 11.3369ZM14.1272 11.3369C14.0821 10.8877 13.4179 10.8877 13.3728 11.3369L13.2426 12.6336L12.0386 12.0964C11.6215 11.9103 11.2895 12.4774 11.6615 12.7405L12.7353 13.5L11.6615 14.2595C11.2895 14.5226 11.6215 15.0897 12.0386 14.9036L13.2426 14.3664L13.3728 15.6631C13.4179 16.1123 14.0821 16.1123 14.1272 15.6631L14.2574 14.3664L15.4614 14.9036C15.8785 15.0897 16.2105 14.5226 15.8385 14.2595L14.7647 13.5L15.8385 12.7405C16.2105 12.4774 15.8785 11.9103 15.4614 12.0964L14.2574 12.6336L14.1272 11.3369ZM4 7C4 6.72386 4.22386 6.5 4.5 6.5H7C7.27614 6.5 7.5 6.72386 7.5 7C7.5 7.27614 7.27614 7.5 7 7.5H4.5C4.22386 7.5 4 7.27614 4 7ZM9 6.5C8.72386 6.5 8.5 6.72386 8.5 7C8.5 7.27614 8.72386 7.5 9 7.5H11.5C11.7761 7.5 12 7.27614 12 7C12 6.72386 11.7761 6.5 11.5 6.5H9Z",
          fill: ""
        })
      }
    };
  });
  var MinusIcon = /*#__PURE__*/createIconComponent("MinusIcon", "oxygen-icon oxygen-icon-minus", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.5 8H13.5",
          stroke: "black",
          strokeLinecap: "round",
          fill: ""
        })
      }
    };
  });
  var NodesIcon = /*#__PURE__*/createIconComponent("NodesIcon", "oxygen-icon oxygen-icon-nodes", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3 2C3 2.55228 2.55228 3 2 3C1.44772 3 1 2.55228 1 2C1 1.44772 1.44772 1 2 1C2.55228 1 3 1.44772 3 2ZM3.01568 3.72327C2.71799 3.8991 2.37078 4 2 4C0.895431 4 0 3.10457 0 2C0 0.895431 0.895431 0 2 0C3.10457 0 4 0.895431 4 2C4 2.37103 3.89897 2.71847 3.72291 3.01629L5.40364 4.69702C5.98797 4.25928 6.71371 4 7.5 4C8.28614 4 9.01174 4.25918 9.59602 4.69676L11.2769 3.01591C11.1009 2.71817 11 2.37087 11 2C11 0.895431 11.8954 0 13 0C14.1046 0 15 0.895431 15 2C15 3.10457 14.1046 4 13 4C12.6291 4 12.2817 3.89902 11.9839 3.72305L10.3031 5.40385C10.7408 5.98815 11 6.7138 11 7.5C11 8.28629 10.7407 9.01203 10.303 9.59636L12.9837 12.2771C13.2815 12.101 13.629 12 14 12C15.1046 12 16 12.8954 16 14C16 15.1046 15.1046 16 14 16C12.8954 16 12 15.1046 12 14C12 13.6292 12.1009 13.282 12.2767 12.9843L9.59581 10.3034C9.01157 10.7409 8.28604 11 7.5 11C6.8388 11 6.22043 10.8167 5.69294 10.498L4.61325 11.8177C4.85639 12.1488 5 12.5576 5 13C5 14.1046 4.10457 15 3 15C1.89543 15 1 14.1046 1 13C1 11.8954 1.89543 11 3 11C3.29981 11 3.58421 11.066 3.83949 11.1842L4.91933 9.86438C4.34842 9.24157 4 8.41148 4 7.5C4 6.71396 4.25912 5.98844 4.6966 5.40419L3.01568 3.72327ZM14 2C14 2.55228 13.5523 3 13 3C12.4477 3 12 2.55228 12 2C12 1.44772 12.4477 1 13 1C13.5523 1 14 1.44772 14 2ZM14 15C14.5523 15 15 14.5523 15 14C15 13.4477 14.5523 13 14 13C13.4477 13 13 13.4477 13 14C13 14.5523 13.4477 15 14 15ZM4 13C4 13.5523 3.55228 14 3 14C2.44772 14 2 13.5523 2 13C2 12.4477 2.44772 12 3 12C3.55228 12 4 12.4477 4 13ZM7.5 10C8.88071 10 10 8.88071 10 7.5C10 6.11929 8.88071 5 7.5 5C6.11929 5 5 6.11929 5 7.5C5 8.88071 6.11929 10 7.5 10Z",
          fill: ""
        })
      }
    };
  });
  var PadlockAsteriskIcon = /*#__PURE__*/createIconComponent("PadlockAsteriskIcon", "oxygen-icon oxygen-icon-padlock-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.5 0.5C5.84315 0.5 4.5 1.84315 4.5 3.5V5.5H3.5C2.11929 5.5 1 6.61929 1 8V12.5C1 13.8807 2.11929 15 3.5 15H4C4.27614 15 4.5 14.7761 4.5 14.5C4.5 14.2239 4.27614 14 4 14H3.5C2.67157 14 2 13.3284 2 12.5V8C2 7.17157 2.67157 6.5 3.5 6.5H11.7352C12.5637 6.5 13.2352 7.17157 13.2352 8V8.25V9.23184C13.2352 9.50799 13.4591 9.73184 13.7352 9.73184C14.0114 9.73184 14.2352 9.50799 14.2352 9.23184V8.25V8C14.2352 6.61929 13.1159 5.5 11.7352 5.5H10.5V3.5C10.5 1.84315 9.15685 0.5 7.5 0.5ZM9.5 5.5V3.5C9.5 2.39543 8.60457 1.5 7.5 1.5C6.39543 1.5 5.5 2.39543 5.5 3.5V5.5H9.5ZM14.1272 11.3369C14.0821 10.8877 13.4179 10.8877 13.3728 11.3369L13.2426 12.6336L12.0386 12.0964C11.6215 11.9103 11.2895 12.4774 11.6615 12.7405L12.7353 13.5L11.6615 14.2595C11.2895 14.5226 11.6215 15.0897 12.0386 14.9036L13.2426 14.3664L13.3728 15.6631C13.4179 16.1123 14.0821 16.1123 14.1272 15.6631L14.2574 14.3664L15.4614 14.9036C15.8785 15.0897 16.2105 14.5226 15.8385 14.2595L14.7647 13.5L15.8385 12.7405C16.2105 12.4774 15.8785 11.9103 15.4614 12.0964L14.2574 12.6336L14.1272 11.3369ZM7.87282 11.3369C7.91792 10.8877 8.58208 10.8877 8.62718 11.3369L8.75736 12.6336L9.96137 12.0964C10.3785 11.9103 10.7105 12.4774 10.3385 12.7405L9.26472 13.5L10.3385 14.2595C10.7105 14.5226 10.3785 15.0897 9.96137 14.9036L8.75736 14.3664L8.62718 15.6631C8.58208 16.1123 7.91792 16.1123 7.87282 15.6631L7.74264 14.3664L6.53863 14.9036C6.12154 15.0897 5.78945 14.5226 6.16145 14.2595L7.23528 13.5L6.16145 12.7405C5.78945 12.4774 6.12154 11.9103 6.53863 12.0964L7.74264 12.6336L7.87282 11.3369Z",
          fill: ""
        })
      }
    };
  });
  var PadlockAsteriskFlowIcon = /*#__PURE__*/createIconComponent("PadlockAsteriskFlowIcon", "oxygen-icon oxygen-icon-padlock-asterisk-flow", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.29508 4.34901L2.31933 4.62284C4.0081 1.83677 7.55546 0.700134 10.5872 2.09263C11.3643 2.44955 12.0365 2.93971 12.59 3.52321C12.78 3.72355 13.0965 3.73191 13.2968 3.54187C13.4972 3.35183 13.5055 3.03536 13.3155 2.83501C12.6757 2.16058 11.8994 1.5949 11.0046 1.18389C7.53794 -0.408348 3.48703 0.865274 1.51793 4.01693L1.29598 3.22608C1.22137 2.96021 0.945351 2.80516 0.67948 2.87978C0.413609 2.95439 0.258565 3.23041 0.333179 3.49628L0.906363 5.53869L1.04146 6.0201L1.52287 5.885L3.56528 5.31181C3.83115 5.2372 3.9862 4.96118 3.91158 4.69531C3.83697 4.42944 3.56095 4.27439 3.29508 4.34901ZM2.45164 12.4569C2.65199 12.2668 2.96846 12.2752 3.1585 12.4755C3.71198 13.059 4.38415 13.5492 5.16124 13.9061C8.29381 15.3449 11.9768 14.0836 13.5913 11.0925L12.8524 11.5192C12.6132 11.6573 12.3074 11.5753 12.1693 11.3362C12.0313 11.097 12.1132 10.7912 12.3524 10.6532L14.1895 9.59251L14.6225 9.34251L14.8725 9.77553L15.9331 11.6126C16.0712 11.8518 15.9893 12.1576 15.7501 12.2957C15.511 12.4337 15.2052 12.3518 15.0671 12.1126L14.6039 11.3103C12.8173 14.9462 8.4472 16.5158 4.74386 14.8149C3.84902 14.4039 3.07271 13.8382 2.43298 13.1637C2.24294 12.9634 2.25129 12.6469 2.45164 12.4569ZM5.31263 4.9686C5.31263 3.91581 6.16608 3.06235 7.21888 3.06235C8.27167 3.06235 9.12513 3.91581 9.12513 4.9686V5.87485H9.46057C10.4357 5.87485 11.2262 6.66535 11.2262 7.64048V8.19276C11.2262 8.4689 11.0023 8.69276 10.7262 8.69276C10.4501 8.69276 10.2262 8.4689 10.2262 8.19276V7.64048C10.2262 7.21763 9.88341 6.87485 9.46057 6.87485H5.84388C5.01545 6.87485 4.34388 7.54642 4.34388 8.37485V9.74985C4.34388 10.2504 4.74962 10.6561 5.25013 10.6561C5.52627 10.6561 5.75013 10.88 5.75013 11.1561C5.75013 11.4322 5.52627 11.6561 5.25013 11.6561C4.19733 11.6561 3.34388 10.8026 3.34388 9.74985V8.37485C3.34388 7.17644 4.18711 6.17497 5.31263 5.93141V4.9686ZM8.12513 4.9686V5.87485H6.31263V4.9686C6.31263 4.46809 6.71837 4.06235 7.21888 4.06235C7.71939 4.06235 8.12513 4.46809 8.12513 4.9686ZM10.5223 9.37685C10.5477 9.12418 10.9213 9.12418 10.9467 9.37685L11.0199 10.1062L11.6971 9.80407C11.9318 9.69939 12.1186 10.0184 11.9093 10.1664L11.3053 10.5936L11.9093 11.0208C12.1186 11.1688 11.9318 11.4878 11.6971 11.3831L11.0199 11.081L10.9467 11.8103C10.9213 12.063 10.5477 12.063 10.5223 11.8103L10.4491 11.081L9.77186 11.3831C9.53724 11.4878 9.35044 11.1688 9.55969 11.0208L10.1637 10.5936L9.55969 10.1664C9.35045 10.0184 9.53724 9.69939 9.77186 9.80407L10.4491 10.1062L10.5223 9.37685ZM7.85292 9.37685C7.82755 9.12418 7.45396 9.12418 7.42859 9.37685L7.35536 10.1062L6.67811 9.80407C6.44349 9.69939 6.2567 10.0184 6.46594 10.1664L7.06997 10.5936L6.46594 11.0208C6.25669 11.1688 6.44349 11.4878 6.67811 11.3831L7.35536 11.081L7.42859 11.8103C7.45396 12.063 7.82755 12.063 7.85292 11.8103L7.92614 11.081L8.6034 11.3831C8.83802 11.4878 9.02481 11.1688 8.81556 11.0208L8.21153 10.5936L8.81556 10.1664C9.02481 10.0184 8.83802 9.69939 8.6034 9.80407L7.92614 10.1062L7.85292 9.37685Z",
          fill: ""
        })
      }
    };
  });
  var PaletteIcon = /*#__PURE__*/createIconComponent("PaletteIcon", "oxygen-icon oxygen-icon-palette", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11.8354 0.979235C10.274 0.126294 8.47283 -0.181812 6.7167 0.103638C4.96056 0.389088 3.3497 1.2518 2.13882 2.55536C0.927944 3.85892 0.186164 5.52893 0.0307778 7.30132C-0.124609 9.0737 0.315267 10.8473 1.28085 12.3417C2.24642 13.8361 3.6826 14.9659 5.36228 15.5526C6.80348 16.056 8.42771 16.134 9.92146 15.7896C10.5948 15.6344 11 15.0208 11 14.389L11 11C11 10.7239 11.2239 10.5 11.5 10.5L14.4888 10.5C15.1603 10.5 15.8046 10.041 15.9117 9.31264C16.1327 7.81015 15.9393 6.19755 15.3381 4.8132C14.6293 3.18128 13.3968 1.83218 11.8354 0.979235ZM6.87714 1.09068C8.41375 0.840915 9.98979 1.11051 11.356 1.85683C12.7222 2.60315 13.8007 3.78362 14.4208 5.21155C14.944 6.4161 15.1176 7.83939 14.9223 9.16713C14.8966 9.34197 14.7304 9.5 14.4888 9.5L11.5 9.5C10.6716 9.50001 10 10.1716 10 11L10 14.389C10 14.6155 9.85992 14.7776 9.6968 14.8152C8.38185 15.1184 6.95006 15.0479 5.69202 14.6085C4.2223 14.0952 2.96565 13.1065 2.12077 11.799C1.27588 10.4914 0.890994 8.93949 1.02696 7.38865C1.16292 5.83782 1.81198 4.37656 2.87149 3.23594C3.93101 2.09533 5.34052 1.34045 6.87714 1.09068ZM11.5 5.5C11.5 6.05228 11.0523 6.5 10.5 6.5C9.94772 6.5 9.5 6.05228 9.5 5.5C9.5 4.94772 9.94772 4.5 10.5 4.5C11.0523 4.5 11.5 4.94772 11.5 5.5ZM12.5 5.5C12.5 6.60457 11.6046 7.5 10.5 7.5C9.39543 7.5 8.5 6.60457 8.5 5.5C8.5 4.39543 9.39543 3.5 10.5 3.5C11.6046 3.5 12.5 4.39543 12.5 5.5ZM5.5 6.5C6.05228 6.5 6.5 6.05228 6.5 5.5C6.5 4.94772 6.05228 4.5 5.5 4.5C4.94772 4.5 4.5 4.94772 4.5 5.5C4.5 6.05228 4.94772 6.5 5.5 6.5ZM5.5 7.5C6.60457 7.5 7.5 6.60457 7.5 5.5C7.5 4.39543 6.60457 3.5 5.5 3.5C4.39543 3.5 3.5 4.39543 3.5 5.5C3.5 6.60457 4.39543 7.5 5.5 7.5ZM6.5 10.5C6.5 11.0523 6.05228 11.5 5.5 11.5C4.94772 11.5 4.5 11.0523 4.5 10.5C4.5 9.94772 4.94772 9.5 5.5 9.5C6.05228 9.5 6.5 9.94772 6.5 10.5ZM7.5 10.5C7.5 11.6046 6.60457 12.5 5.5 12.5C4.39543 12.5 3.5 11.6046 3.5 10.5C3.5 9.39543 4.39543 8.5 5.5 8.5C6.60457 8.5 7.5 9.39543 7.5 10.5Z",
          fill: ""
        })
      }
    };
  });
  var PenToCircleIcon = /*#__PURE__*/createIconComponent("PenToCircleIcon", "oxygen-icon oxygen-icon-pen-to-circle", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M11.7645 1.55603L7.33957 6.36762L6.62291 9.90938L10.0375 9.06944L14.4727 4.28047C15.195 3.50051 15.1683 2.28812 14.4122 1.54077C13.6769 0.813827 12.4914 0.820659 11.7645 1.55603ZM13.7888 2.34072C14.0813 2.71052 14.0673 3.24647 13.739 3.60098L9.4947 8.18199L7.7747 8.65999L8.2447 6.85999L12.482 2.25254C12.8143 1.91645 13.3666 1.91326 13.7092 2.25194L13.7888 2.34072ZM8.5 1.5C8.5 1.22386 8.27614 1 8 1C4.13401 1 1 4.13401 1 8C1 11.866 4.13401 15 8 15C11.866 15 15 11.866 15 8C15 7.72386 14.7761 7.5 14.5 7.5C14.2239 7.5 14 7.72386 14 8C14 11.3137 11.3137 14 8 14C4.68629 14 2 11.3137 2 8C2 4.68629 4.68629 2 8 2C8.27614 2 8.5 1.77614 8.5 1.5Z",
          fill: ""
        })
      }
    };
  });
  var PenToSquareIcon = /*#__PURE__*/createIconComponent("PenToSquareIcon", "oxygen-icon oxygen-icon-pen-to-square", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M14.253 1.14645C14.0577 0.951184 13.7411 0.951185 13.5459 1.14645L13.1065 1.58579L14.3994 2.87868L14.8388 2.43934C15.034 2.24408 15.034 1.9275 14.8388 1.73223L14.253 1.14645ZM12.8388 0.439339L12.0459 1.23223L6.54586 6.73223L6.39941 6.87868V7.08579V9.08579V9.58579H6.89941H8.89941H9.10652L9.25297 9.43934L14.7527 3.93957L14.753 3.93934L14.7532 3.93911L15.5459 3.14645C16.1316 2.56066 16.1316 1.61091 15.5459 1.02513L14.9601 0.43934C14.3743 -0.146446 13.4245 -0.146448 12.8388 0.439339ZM8.69231 8.58579L13.6923 3.58579L12.3994 2.29289L7.39941 7.29289V8.58579H8.69231ZM1 11.5C1 13.433 2.567 15 4.5 15H11.5C13.433 15 15 13.433 15 11.5V8C15 7.72386 14.7761 7.5 14.5 7.5C14.2239 7.5 14 7.72386 14 8V11.5C14 12.8807 12.8807 14 11.5 14H4.5C3.11929 14 2 12.8807 2 11.5L2 4.5C2 3.11929 3.11929 2 4.5 2L8 2C8.27614 2 8.5 1.77614 8.5 1.5C8.5 1.22386 8.27614 1 8 1L4.5 1C2.567 1 1 2.567 1 4.5V11.5Z",
          fill: ""
        })
      }
    };
  });
  var PlusIcon = /*#__PURE__*/createIconComponent("PlusIcon", "oxygen-icon oxygen-icon-plus", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8.5 3.5C8.5 3.22386 8.27614 3 8 3C7.72386 3 7.5 3.22386 7.5 3.5V7.5H3.5C3.22386 7.5 3 7.72386 3 8C3 8.27614 3.22386 8.5 3.5 8.5H7.5V12.5C7.5 12.7761 7.72386 13 8 13C8.27614 13 8.5 12.7761 8.5 12.5V8.5H12.5C12.7761 8.5 13 8.27614 13 8C13 7.72386 12.7761 7.5 12.5 7.5H8.5V3.5Z",
          fill: ""
        })
      }
    };
  });
  var ProfileFlowIcon = /*#__PURE__*/createIconComponent("ProfileFlowIcon", "oxygen-icon oxygen-icon-profile-flow", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.29508 4.34901L2.31933 4.62284C4.0081 1.83677 7.55546 0.700134 10.5872 2.09263C11.3643 2.44955 12.0365 2.93971 12.59 3.52321C12.78 3.72355 13.0965 3.73191 13.2968 3.54187C13.4972 3.35183 13.5055 3.03536 13.3155 2.83501C12.6757 2.16058 11.8994 1.5949 11.0046 1.18389C7.53794 -0.408348 3.48703 0.865274 1.51793 4.01693L1.29598 3.22608C1.22137 2.96021 0.945351 2.80516 0.67948 2.87978C0.413609 2.95439 0.258565 3.23041 0.333179 3.49628L0.906363 5.53869L1.04146 6.0201L1.52287 5.885L3.56528 5.31181C3.83115 5.2372 3.9862 4.96118 3.91158 4.69531C3.83697 4.42944 3.56095 4.27439 3.29508 4.34901ZM2.45164 12.4569C2.65199 12.2668 2.96846 12.2752 3.1585 12.4755C3.71198 13.059 4.38415 13.5492 5.16124 13.9061C8.29381 15.3449 11.9768 14.0836 13.5913 11.0925L12.8524 11.5192C12.6132 11.6573 12.3074 11.5753 12.1693 11.3362C12.0313 11.097 12.1132 10.7912 12.3524 10.6532L14.1895 9.59251L14.6225 9.34251L14.8725 9.77553L15.9331 11.6126C16.0712 11.8518 15.9893 12.1576 15.7501 12.2957C15.511 12.4337 15.2052 12.3518 15.0671 12.1126L14.6039 11.3103C12.8173 14.9462 8.4472 16.5158 4.74386 14.8149C3.84902 14.4039 3.07271 13.8382 2.43298 13.1637C2.24294 12.9634 2.25129 12.6469 2.45164 12.4569ZM11.4112 5.06289C10.5274 4.39 9.48207 4.03656 8.42853 4.00256C9.26443 4.08707 9.91684 4.79288 9.91684 5.65107C9.91684 6.06949 9.76175 6.45169 9.50592 6.74332C10.301 7.02529 10.9789 7.58091 11.3269 8.36916C11.4537 7.95128 11.5205 7.51182 11.5205 7.06308V5.2836C11.5205 5.197 11.4801 5.11536 11.4112 5.06289ZM5.10948 5.06289C5.99282 4.39029 7.03768 4.03686 8.09077 4.00261C7.25507 4.08731 6.60288 4.79303 6.60288 5.65107C6.60288 6.06963 6.75808 6.45194 7.01406 6.7436C6.21935 7.02564 5.54162 7.58107 5.19371 8.36903C5.06696 7.95118 5.00013 7.51178 5.00013 7.06308V5.28361C5.00013 5.197 5.04058 5.11536 5.10948 5.06289ZM7.16658 10.9107C6.98907 10.8031 6.82067 10.6842 6.66209 10.5554L9.85868 10.5553C9.70005 10.6842 9.53161 10.8031 9.35405 10.9107L8.5196 11.4168C8.36025 11.5135 8.16038 11.5135 8.00103 11.4168L7.16658 10.9107ZM4.50367 4.26728C6.72303 2.57737 9.79761 2.57737 12.017 4.26728C12.3343 4.50888 12.5205 4.8848 12.5205 5.2836V7.06308C12.5205 8.9857 11.5165 10.7688 9.87262 11.7658L9.03816 12.2719C8.56012 12.5618 7.96051 12.5618 7.48247 12.2719L6.64801 11.7658C5.00409 10.7688 4.00013 8.98571 4.00013 7.06308V5.28361C4.00013 4.8848 4.18638 4.50888 4.50367 4.26728ZM7.60288 5.65107C7.60288 5.28823 7.89702 4.99408 8.25986 4.99408C8.6227 4.99408 8.91684 5.28823 8.91684 5.65107C8.91684 6.01391 8.6227 6.30805 8.25986 6.30805C7.89702 6.30805 7.60288 6.01391 7.60288 5.65107ZM10.5508 9.25172C10.5767 9.41801 10.4378 9.55525 10.2695 9.55526L6.25118 9.55539C6.0828 9.5554 5.94382 9.41809 5.96973 9.25172C6.13013 8.22153 7.09469 7.53069 8.26043 7.53069C9.42616 7.53069 10.3904 8.22153 10.5508 9.25172Z",
          fill: ""
        })
      }
    };
  });
  var ProgressFlowIcon = /*#__PURE__*/createIconComponent("ProgressFlowIcon", "oxygen-icon oxygen-icon-progress-flow", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M1 1H3V3H1V1ZM0 1C0 0.447715 0.447715 0 1 0H3C3.55228 0 4 0.447715 4 1V1.5L10.7929 1.5L10.6464 1.35355C10.4512 1.15829 10.4512 0.841709 10.6464 0.646447C10.8417 0.451184 11.1583 0.451184 11.3536 0.646447L12 1.29289V1C12 0.447715 12.4477 0 13 0H15C15.5523 0 16 0.447715 16 1V3C16 3.55228 15.5523 4 15 4H14.4998C14.4984 4.87931 14.4893 5.59304 14.4266 6.15678C14.3529 6.8201 14.1962 7.38589 13.7911 7.79105C13.3859 8.19622 12.8201 8.35293 12.1568 8.42663C11.874 8.45805 11.5536 8.47601 11.1934 8.48628L11.3536 8.64645C11.5488 8.84171 11.5488 9.15829 11.3536 9.35355C11.1583 9.54882 10.8417 9.54882 10.6464 9.35355L10 8.70711V9C10 9.55228 9.55228 10 9 10H7C6.44772 10 6 9.55228 6 9V8.50029C5.11945 8.50177 4.46057 8.51093 3.95365 8.56725C3.35135 8.63418 3.07339 8.75872 2.91605 8.91605C2.75872 9.07339 2.63418 9.35135 2.56725 9.95365C2.54074 10.1923 2.52467 10.4647 2.51494 10.7779L2.64645 10.6464C2.84171 10.4512 3.15829 10.4512 3.35355 10.6464C3.54882 10.8417 3.54882 11.1583 3.35355 11.3536L2.70711 12H3C3.55228 12 4 12.4477 4 13V13.5L10.7929 13.5L10.6464 13.3536C10.4512 13.1583 10.4512 12.8417 10.6464 12.6464C10.8417 12.4512 11.1583 12.4512 11.3536 12.6464L12 13.7512V13.3242L11.3536 12.6464L12 13.2929V13C12 12.4477 12.4477 12 13 12H15C15.5523 12 16 12.4477 16 13V15C16 15.5523 15.5523 16 15 16H13C12.4477 16 12 15.5523 12 15V14.7071L11.3536 15.3536C11.1583 15.5488 10.8417 15.5488 10.6464 15.3536C10.4512 15.1583 10.4512 14.8417 10.6464 14.6464L10.7929 14.5L4 14.5V15C4 15.5523 3.55228 16 3 16H1C0.447715 16 0 15.5523 0 15V13C0 12.4477 0.447715 12 1 12H1.29289L0.646447 11.3536C0.451184 11.1583 0.451184 10.8417 0.646447 10.6464C0.841709 10.4512 1.15829 10.4512 1.35355 10.6464L1.51372 10.8066C1.52399 10.4464 1.54195 10.126 1.57337 9.84322C1.64707 9.1799 1.80378 8.61411 2.20895 8.20895C2.61411 7.80378 3.1799 7.64707 3.84322 7.57337C4.40696 7.51073 5.12069 7.50156 6 7.50023V7C6 6.44772 6.44772 6 7 6H9C9.55228 6 10 6.44772 10 7V7.29289L10.6464 6.64645C10.8417 6.45118 11.1583 6.45118 11.3536 6.64645C11.5488 6.84171 11.5488 7.15829 11.3536 7.35355L11.2221 7.48506C11.5353 7.47533 11.8077 7.45926 12.0463 7.43275C12.6486 7.36582 12.9266 7.24128 13.0839 7.08395C13.2413 6.92661 13.3658 6.64865 13.4327 6.04635C13.4891 5.53943 13.4982 4.88055 13.4997 4H13C12.4477 4 12 3.55228 12 3V2.70711L11.3536 3.35355C11.1583 3.54882 10.8417 3.54882 10.6464 3.35355C10.4512 3.15829 10.4512 2.84171 10.6464 2.64645L10.7929 2.5L4 2.5V3C4 3.55228 3.55228 4 3 4H1C0.447715 4 0 3.55228 0 3V1ZM15 1H13V3H15V1ZM7 7H9V9H7V7ZM15 13H13V15H15V13ZM1 13H3V15H1V13Z",
          fill: ""
        })
      }
    };
  });
  var ReceiptIcon = /*#__PURE__*/createIconComponent("ReceiptIcon", "oxygen-icon oxygen-icon-receipt", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M4.43243 5.40265C4.16375 5.40265 3.94595 5.62651 3.94595 5.90264C3.94595 6.17878 4.16375 6.40263 4.43243 6.40263H8.32432C8.593 6.40263 8.81081 6.17878 8.81081 5.90264C8.81081 5.62651 8.593 5.40265 8.32432 5.40265H4.43243Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M4.43243 7.67482C4.16375 7.67482 3.94595 7.89867 3.94595 8.1748C3.94595 8.45094 4.16375 8.6748 4.43243 8.6748H11.5676C11.8362 8.6748 12.0541 8.45094 12.0541 8.1748C12.0541 7.89867 11.8362 7.67482 11.5676 7.67482H4.43243Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M4.43243 9.94698C4.16375 9.94698 3.94595 10.1708 3.94595 10.447C3.94595 10.7231 4.16375 10.947 4.43243 10.947H11.5676C11.8362 10.947 12.0541 10.7231 12.0541 10.447C12.0541 10.1708 11.8362 9.94698 11.5676 9.94698H4.43243Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M6.60623 0.201482C6.28451 -0.0671602 5.82359 -0.0671609 5.50187 0.201481L4.10192 1.37046L3.41423 0.819196C2.83921 0.35825 2 0.779359 2 1.52885V14.2717C2 14.9857 2.77035 15.4154 3.35289 15.0262L4.33983 14.367L5.41425 15.6589C5.74313 16.0543 6.32877 16.0817 6.6912 15.7185L8 14.4071L9.33465 15.7444C9.67474 16.0852 10.2172 16.0852 10.5572 15.7444L11.9275 14.3714L12.5858 14.8991C13.1608 15.36 14 14.9389 14 14.1894V1.52885C14 0.779359 13.1608 0.35825 12.5858 0.819196L11.8981 1.37046L10.4981 0.201482C10.1764 -0.0671602 9.71549 -0.0671609 9.39376 0.201481L8 1.3653L6.60623 0.201482ZM4.65534 2.19677L6.05405 1.02882L7.44782 2.19264C7.76954 2.46128 8.23046 2.46128 8.55218 2.19264L9.94595 1.02882L11.3447 2.19677C11.6613 2.46119 12.1137 2.46581 12.4354 2.20792L13.027 1.73366V13.9846L12.4589 13.5292C12.1137 13.2525 11.6226 13.2803 11.3091 13.5945L9.94595 14.9604L8.6113 13.623C8.27121 13.2822 7.72879 13.2822 7.3887 13.623L6.08637 14.928L5.02401 13.6506C4.73848 13.3073 4.24959 13.2346 3.88113 13.4807L2.97297 14.0874V1.73366L3.56461 2.20792C3.88632 2.46581 4.33869 2.46119 4.65534 2.19677Z",
          fill: ""
        }))
      }
    };
  });
  var RectangleLineIcon = /*#__PURE__*/createIconComponent("RectangleLineIcon", "oxygen-icon oxygen-icon-rectangle-line", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0 2C0 1.17157 0.671573 0.5 1.5 0.5H14.5C15.3284 0.5 16 1.17157 16 2V10C16 10.8284 15.3284 11.5 14.5 11.5H1.5C0.671573 11.5 0 10.8284 0 10V2ZM1.5 1.5C1.22386 1.5 1 1.72386 1 2V10C1 10.2761 1.22386 10.5 1.5 10.5H14.5C14.7761 10.5 15 10.2761 15 10V2C15 1.72386 14.7761 1.5 14.5 1.5H1.5ZM1.5 14C1.22386 14 1 14.2239 1 14.5C1 14.7761 1.22386 15 1.5 15H14.5C14.7761 15 15 14.7761 15 14.5C15 14.2239 14.7761 14 14.5 14H1.5Z",
          fill: ""
        })
      }
    };
  });
  var ShareNodesIcon = /*#__PURE__*/createIconComponent("ShareNodesIcon", "oxygen-icon oxygen-icon-share-nodes", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M14 3C14.5523 3 15 2.55228 15 2C15 1.44772 14.5523 1 14 1C13.4477 1 13 1.44772 13 2C13 2.55228 13.4477 3 14 3ZM14 4C15.1046 4 16 3.10457 16 2C16 0.895431 15.1046 0 14 0C12.8954 0 12 0.895431 12 2C12 2.1574 12.0182 2.31056 12.0526 2.45749L3.92584 7.45855C3.68974 6.61704 2.91693 6 2 6C0.895431 6 0 6.89543 0 8C0 9.10457 0.895431 10 2 10C2.91693 10 3.68974 9.38296 3.92584 8.54145L12.0526 13.5425C12.0182 13.6894 12 13.8426 12 14C12 15.1046 12.8954 16 14 16C15.1046 16 16 15.1046 16 14C16 12.8954 15.1046 12 14 12C13.4131 12 12.8852 12.2528 12.5193 12.6555L5.76652 8.5H12.063C12.285 9.36261 13.0681 10 14 10C15.1046 10 16 9.10457 16 8C16 6.89543 15.1046 6 14 6C13.0681 6 12.285 6.63739 12.063 7.5H5.76652L12.5193 3.34445C12.8852 3.74716 13.4131 4 14 4ZM2 9C2.55228 9 3 8.55229 3 8C3 7.44772 2.55228 7 2 7C1.44772 7 1 7.44772 1 8C1 8.55229 1.44772 9 2 9ZM15 14C15 14.5523 14.5523 15 14 15C13.4477 15 13 14.5523 13 14C13 13.4477 13.4477 13 14 13C14.5523 13 15 13.4477 15 14ZM14 9C14.5523 9 15 8.55229 15 8C15 7.44772 14.5523 7 14 7C13.4477 7 13 7.44772 13 8C13 8.55229 13.4477 9 14 9Z",
          fill: ""
        })
      }
    };
  });
  var ShieldCheckIcon = /*#__PURE__*/createIconComponent("ShieldCheckIcon", "oxygen-icon oxygen-icon-shield-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.33264 2.94382C5.68081 0.394379 10.3192 0.394379 13.6674 2.94382C13.877 3.10342 14 3.35175 14 3.6152V8.74258C14 10.3156 13.1786 11.7745 11.8335 12.5903L8.25928 14.758C8.09994 14.8546 7.90006 14.8546 7.74072 14.758L4.16645 12.5903C2.82143 11.7745 2 10.3156 2 8.74258V3.6152C2 3.35175 2.12304 3.10342 2.33264 2.94382ZM14.2732 2.14821C10.5671 -0.673751 5.4329 -0.673751 1.72683 2.14821C1.26884 2.49694 1 3.03956 1 3.6152V8.74258C1 10.6652 2.00397 12.4483 3.64789 13.4453L7.22215 15.613C7.70019 15.9029 8.29981 15.9029 8.77785 15.613L12.3521 13.4453C13.996 12.4483 15 10.6652 15 8.74258V3.6152C15 3.03956 14.7312 2.49694 14.2732 2.14821ZM11.3293 5.12372C11.5371 5.30556 11.5581 5.62144 11.3763 5.82926L7.87629 9.82926L7.52435 10.2315L7.14645 9.85356L5.14645 7.85356C4.95118 7.6583 4.95118 7.34172 5.14645 7.14646C5.34171 6.95119 5.65829 6.95119 5.85355 7.14646L7.47565 8.76855L10.6237 5.17076C10.8056 4.96294 11.1214 4.94188 11.3293 5.12372Z",
          fill: ""
        })
      }
    };
  });
  var ShieldSquareCheckIcon = /*#__PURE__*/createIconComponent("ShieldSquareCheckIcon", "oxygen-icon oxygen-icon-shield-square-check", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M13.6674 2.94382C10.3192 0.394379 5.68081 0.394379 2.33264 2.94382C2.12304 3.10342 2 3.35175 2 3.6152V9.3327C2 11.0999 3.03439 12.7036 4.64437 13.4323L4.95618 13.5734C5.20775 13.6873 5.31938 13.9835 5.20551 14.2351C5.09164 14.4867 4.79539 14.5983 4.54382 14.4844L4.23201 14.3433C2.26426 13.4526 1 11.4926 1 9.3327V3.6152C1 3.03956 1.26884 2.49694 1.72683 2.14821C5.4329 -0.673751 10.5671 -0.673751 14.2732 2.14821C14.7312 2.49694 15 3.03956 15 3.6152V5.3515C15 5.62764 14.7761 5.8515 14.5 5.8515C14.2239 5.8515 14 5.62764 14 5.3515V3.6152C14 3.35175 13.877 3.10342 13.6674 2.94382ZM15.8536 9.64645C16.0488 9.84171 16.0488 10.1583 15.8536 10.3536L10.8536 15.3536L10.5 15.7071L10.1464 15.3536L7.14645 12.3536C6.95118 12.1583 6.95118 11.8417 7.14645 11.6464C7.34171 11.4512 7.65829 11.4512 7.85355 11.6464L10.5 14.2929L15.1464 9.64645C15.3417 9.45119 15.6583 9.45119 15.8536 9.64645ZM7 4C6.17157 4 5.5 4.67158 5.5 5.5V7.5C5.5 8.32843 6.17157 9 7 9H9C9.82843 9 10.5 8.32843 10.5 7.5V5.5C10.5 4.67158 9.82843 4 9 4H7ZM6.5 5.5C6.5 5.22386 6.72386 5 7 5H9C9.27614 5 9.5 5.22386 9.5 5.5V7.5C9.5 7.77614 9.27614 8 9 8H7C6.72386 8 6.5 7.77614 6.5 7.5V5.5Z",
          fill: ""
        })
      }
    };
  });
  var ShieldUserIcon = /*#__PURE__*/createIconComponent("ShieldUserIcon", "oxygen-icon oxygen-icon-shield-user", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M2.33264 2.94382C5.68081 0.394379 10.3192 0.394379 13.6674 2.94382C13.877 3.10342 14 3.35175 14 3.6152V8.74258C14 10.3156 13.1786 11.7745 11.8335 12.5903L8.25928 14.758C8.09994 14.8546 7.90006 14.8546 7.74072 14.758L4.16645 12.5903C2.82143 11.7745 2 10.3156 2 8.74258V3.6152C2 3.35175 2.12304 3.10342 2.33264 2.94382ZM14.2732 2.14821C10.5671 -0.673751 5.4329 -0.673751 1.72683 2.14821C1.26884 2.49694 1 3.03956 1 3.6152V8.74258C1 10.6652 2.00397 12.4483 3.64789 13.4453L7.22215 15.613C7.70019 15.9029 8.29981 15.9029 8.77785 15.613L12.3521 13.4453C13.996 12.4483 15 10.6652 15 8.74258V3.6152C15 3.03956 14.7312 2.49694 14.2732 2.14821ZM8.00004 5.25007C8.55233 5.25007 9.00004 4.80236 9.00004 4.25007C9.00004 3.69779 8.55233 3.25007 8.00004 3.25007C7.44776 3.25007 7.00004 3.69779 7.00004 4.25007C7.00004 4.80236 7.44776 5.25007 8.00004 5.25007ZM8.00004 6.25007C9.10461 6.25007 10 5.35464 10 4.25007C10 3.1455 9.10461 2.25007 8.00004 2.25007C6.89547 2.25007 6.00004 3.1455 6.00004 4.25007C6.00004 5.35464 6.89547 6.25007 8.00004 6.25007ZM3.54644 10.3977C3.87075 8.31479 5.80309 6.99958 8.00028 6.99958C10.1976 6.99958 12.1292 8.31487 12.4535 10.3977C12.5537 11.0411 12.0151 11.4993 11.4732 11.4993L4.52704 11.4996C3.98508 11.4996 3.44624 11.0413 3.54644 10.3977ZM4.54314 10.4996L11.4568 10.4993C11.202 9.04754 9.8116 7.99958 8.00028 7.99958C6.18876 7.99958 4.79781 9.04773 4.54314 10.4996Z",
          fill: ""
        })
      }
    };
  });
  var ShieldUserPencilIcon = /*#__PURE__*/createIconComponent("ShieldUserPencilIcon", "oxygen-icon oxygen-icon-shield-user-pencil", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M13.6674 2.94382C10.3192 0.394379 5.68081 0.394379 2.33264 2.94382C2.12304 3.10342 2 3.35175 2 3.6152V9.3327C2 11.0999 3.03439 12.7036 4.64437 13.4323L4.95618 13.5734C5.20775 13.6873 5.31938 13.9835 5.20551 14.2351C5.09164 14.4867 4.79539 14.5983 4.54382 14.4844L4.23201 14.3433C2.26426 13.4526 1 11.4926 1 9.3327V3.6152C1 3.03956 1.26884 2.49694 1.72683 2.14821C5.4329 -0.673751 10.5671 -0.673751 14.2732 2.14821C14.7312 2.49694 15 3.03956 15 3.6152V5.3515C15 5.62764 14.7761 5.8515 14.5 5.8515C14.2239 5.8515 14 5.62764 14 5.3515V3.6152C14 3.35175 13.877 3.10342 13.6674 2.94382ZM8.99989 4.25049C8.99989 4.80278 8.55218 5.25049 7.99989 5.25049C7.44761 5.25049 6.99989 4.80278 6.99989 4.25049C6.99989 3.69821 7.44761 3.25049 7.99989 3.25049C8.55218 3.25049 8.99989 3.69821 8.99989 4.25049ZM9.99989 4.25049C9.99989 5.35506 9.10446 6.25049 7.99989 6.25049C6.89532 6.25049 5.99989 5.35506 5.99989 4.25049C5.99989 3.14592 6.89532 2.25049 7.99989 2.25049C9.10446 2.25049 9.99989 3.14592 9.99989 4.25049ZM8.00012 7C5.80293 7 3.8706 8.31521 3.54629 10.3981C3.44609 11.0417 3.98494 11.5 4.52689 11.5L6.99985 11.4999C7.27599 11.4999 7.49984 11.276 7.49983 10.9998C7.49982 10.7237 7.27595 10.4999 6.99981 10.4999L4.54299 10.5C4.79766 9.04815 6.18861 8 8.00012 8C8.65764 8 9.26591 8.1409 9.78279 8.38995C10.0316 8.50982 10.3304 8.40532 10.4503 8.15655C10.5701 7.90778 10.4656 7.60894 10.2169 7.48907C9.55724 7.17125 8.79958 7 8.00012 7ZM14.2846 8.56002C14.0894 8.36476 13.7728 8.36476 13.5775 8.56002L13.1543 8.98326L14.4258 10.2548L14.8491 9.83157C15.0443 9.63631 15.0443 9.31973 14.8491 9.12446L14.2846 8.56002ZM7.64156 13.0818L12.0874 8.63596L12.0936 8.62965L12.0999 8.62345L12.8704 7.85292C13.4562 7.26713 14.406 7.26713 14.9917 7.85292L15.5562 8.41736C16.142 9.00314 16.142 9.95289 15.5562 10.5387L10.3273 15.7675L10.1809 15.914H9.97377H7.99512H7.49512V15.414V13.4353V13.2282L7.64156 13.0818ZM13.7187 10.9619L12.4472 9.69037L8.49512 13.6424V14.914H9.76666L13.7187 10.9619Z",
          fill: ""
        })
      }
    };
  });
  var SquareMagnifyingGlassIcon = /*#__PURE__*/createIconComponent("SquareMagnifyingGlassIcon", "oxygen-icon oxygen-icon-square-magnifying-glass", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M0.166626 3.10204C0.166626 1.38883 1.55546 0 3.26867 0H11.7585C13.4717 0 14.8605 1.38883 14.8605 3.10204V10.9388C14.8605 11.2093 14.6412 11.4286 14.3707 11.4286C14.1002 11.4286 13.8809 11.2093 13.8809 10.9388V3.10204C13.8809 1.92984 12.9307 0.979592 11.7585 0.979592H3.26867C2.09647 0.979592 1.14622 1.92984 1.14622 3.10204V12.898C1.14622 14.0702 2.09647 15.0204 3.26867 15.0204H11.7585C12.029 15.0204 12.2483 15.2397 12.2483 15.5102C12.2483 15.7807 12.029 16 11.7585 16H3.26867C1.55546 16 0.166626 14.6112 0.166626 12.898V3.10204Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.8416 10.3088C11.4156 9.58482 11.7585 8.66918 11.7585 7.67347C11.7585 5.32908 9.85796 3.42857 7.51356 3.42857C5.16917 3.42857 3.26867 5.32908 3.26867 7.67347C3.26867 10.0179 5.16917 11.9184 7.51356 11.9184C8.50928 11.9184 9.42493 11.5755 10.1489 11.0015L15.004 15.8565C15.1952 16.0478 15.5054 16.0478 15.6966 15.8565C15.8879 15.6653 15.8879 15.3551 15.6966 15.1639L10.8416 10.3088ZM7.51356 10.9388C9.31694 10.9388 10.7789 9.47685 10.7789 7.67347C10.7789 5.87009 9.31694 4.40816 7.51356 4.40816C5.71019 4.40816 4.24826 5.87009 4.24826 7.67347C4.24826 9.47685 5.71019 10.9388 7.51356 10.9388Z",
          fill: ""
        }))
      }
    };
  });
  var SquarePlusIcon = /*#__PURE__*/createIconComponent("SquarePlusIcon", "oxygen-icon oxygen-icon-square-plus", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M3.5 8C3.5 8.27614 3.72386 8.5 4 8.5H7.5V12C7.5 12.2761 7.72386 12.5 8 12.5C8.27614 12.5 8.5 12.2761 8.5 12V8.5H12C12.2761 8.5 12.5 8.27614 12.5 8C12.5 7.72386 12.2761 7.5 12 7.5H8.5V4C8.5 3.72386 8.27614 3.5 8 3.5C7.72386 3.5 7.5 3.72386 7.5 4V7.5H4C3.72386 7.5 3.5 7.72386 3.5 8Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.73333 0H12.2667C14.3285 0 16 1.67147 16 3.73333V12.2667C16 14.3285 14.3285 16 12.2667 16H3.73333C1.67147 16 0 14.3285 0 12.2667V3.73333C0 1.67147 1.67147 0 3.73333 0ZM12.2667 1.06667H3.73333C2.26057 1.06667 1.06667 2.26057 1.06667 3.73333V12.2667C1.06667 13.7394 2.26057 14.9333 3.73333 14.9333H12.2667C13.7394 14.9333 14.9333 13.7394 14.9333 12.2667V3.73333C14.9333 2.26057 13.7394 1.06667 12.2667 1.06667Z",
          fill: ""
        }))
      }
    };
  });
  var SquareUserIcon = /*#__PURE__*/createIconComponent("SquareUserIcon", "oxygen-icon oxygen-icon-square-user", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5 2H11C12.6569 2 14 3.34315 14 5V11C14 12.6569 12.6569 14 11 14H5C3.34315 14 2 12.6569 2 11V5C2 3.34315 3.34315 2 5 2ZM1 5C1 2.79086 2.79086 1 5 1H11C13.2091 1 15 2.79086 15 5V11C15 13.2091 13.2091 15 11 15H5C2.79086 15 1 13.2091 1 11V5ZM8.0002 6C8.55248 6 9.0002 5.55228 9.0002 5C9.0002 4.44772 8.55248 4 8.0002 4C7.44791 4 7.0002 4.44772 7.0002 5C7.0002 5.55228 7.44791 6 8.0002 6ZM8.0002 7C9.10477 7 10.0002 6.10457 10.0002 5C10.0002 3.89543 9.10477 3 8.0002 3C6.89563 3 6.0002 3.89543 6.0002 5C6.0002 6.10457 6.89563 7 8.0002 7ZM3.54629 11.3981C3.8706 9.31521 5.80293 8 8.00012 8C10.1974 8 12.1291 9.31529 12.4534 11.3981C12.5535 12.0415 12.0149 12.4997 11.4731 12.4998L4.52689 12.5C3.98493 12.5 3.44609 12.0417 3.54629 11.3981ZM4.54299 11.5L11.4566 11.4998C11.2019 10.048 9.81145 9 8.00012 9C6.18861 9 4.79766 10.0481 4.54299 11.5Z",
          fill: ""
        })
      }
    };
  });
  var StackOverflowIcon = /*#__PURE__*/createIconComponent("StackOverflowIcon", "oxygen-icon oxygen-icon-stack-overflow", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_2681_41768)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.8724 14.5786V10.814H13.294V15.5002H1.5V10.814H1.92156V14.5786V15.0786H2.42156H12.3724H12.8724V14.5786Z",
          stroke: "black",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M11.3005 8.50889L11.1202 8.89588L5.55914 6.30591L5.73934 5.91894L11.3005 8.50889ZM12.3765 6.90867L12.1032 7.23677L7.38863 3.31079L7.66182 2.98277L12.3765 6.90867ZM13.7821 5.62229L13.4395 5.87706L9.77829 0.954438L10.1209 0.699608L13.7821 5.62229ZM4.65087 9.08703L10.654 10.3493L10.5663 10.7665L4.56308 9.50472L4.65087 9.08703ZM4.34326 12.2353H10.451V12.6569H4.34326V12.2353Z",
          stroke: "black",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_2681_41768"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "16",
          height: "16",
          fill: "white"
        }))))
      }
    };
  });
  var StarIcon = /*#__PURE__*/createIconComponent("StarIcon", "oxygen-icon oxygen-icon-star", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M9.12461 7.55826L8 4.09706L6.87539 7.55826H3.23607L6.18034 9.6974L5.05573 13.1586L8 11.0195L10.9443 13.1586L9.81966 9.6974L12.7639 7.55826H9.12461ZM0 6.5068H6.11146L8 0.694458L9.88854 6.5068H16L11.0557 10.099L12.9443 15.9114L8 12.3191L3.05573 15.9114L4.94427 10.099L0 6.5068Z",
          fill: ""
        })
      }
    };
  });
  var SunIcon = /*#__PURE__*/createIconComponent("SunIcon", "oxygen-icon oxygen-icon-sun", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M8 0C8.27614 0 8.5 0.223858 8.5 0.5V1.5C8.5 1.77614 8.27614 2 8 2C7.72386 2 7.5 1.77614 7.5 1.5V0.5C7.5 0.223858 7.72386 0 8 0ZM8 14C8.27614 14 8.5 14.2239 8.5 14.5V15.5C8.5 15.7761 8.27614 16 8 16C7.72386 16 7.5 15.7761 7.5 15.5V14.5C7.5 14.2239 7.72386 14 8 14ZM2 8C2 8.27614 1.77614 8.5 1.5 8.5H0.5C0.223858 8.5 0 8.27614 0 8C0 7.72386 0.223858 7.5 0.5 7.5H1.5C1.77614 7.5 2 7.72386 2 8ZM16 8C16 8.27614 15.7761 8.5 15.5 8.5H14.5C14.2239 8.5 14 8.27614 14 8C14 7.72386 14.2239 7.5 14.5 7.5H15.5C15.7761 7.5 16 7.72386 16 8ZM12.4464 3.54647C12.2512 3.35121 12.2512 3.03463 12.4464 2.83936L13.1535 2.13226C13.3488 1.937 13.6654 1.937 13.8606 2.13226C14.0559 2.32752 14.0559 2.6441 13.8606 2.83936L13.1535 3.54647C12.9583 3.74173 12.6417 3.74173 12.4464 3.54647ZM2.14645 2.15354C1.95118 2.3488 1.95118 2.66539 2.14645 2.86065L2.85355 3.56775C3.04882 3.76302 3.3654 3.76302 3.56066 3.56775C3.75592 3.37249 3.75592 3.05591 3.56066 2.86065L2.85355 2.15354C2.65829 1.95828 2.34171 1.95828 2.14645 2.15354ZM2.14645 13.8465C1.95118 13.6512 1.95118 13.3346 2.14645 13.1394L2.85355 12.4322C3.04882 12.237 3.3654 12.237 3.56066 12.4322C3.75592 12.6275 3.75592 12.9441 3.56066 13.1394L2.85355 13.8465C2.65829 14.0417 2.34171 14.0417 2.14645 13.8465ZM12.4464 12.4535C12.2512 12.6488 12.2512 12.9654 12.4464 13.1606L13.1535 13.8677C13.3488 14.063 13.6654 14.063 13.8606 13.8677C14.0559 13.6725 14.0559 13.3559 13.8606 13.1606L13.1535 12.4535C12.9583 12.2583 12.6417 12.2583 12.4464 12.4535ZM12 8C12 10.2091 10.2091 12 8 12C5.79086 12 4 10.2091 4 8C4 5.79086 5.79086 4 8 4C10.2091 4 12 5.79086 12 8ZM13 8C13 10.7614 10.7614 13 8 13C5.23858 13 3 10.7614 3 8C3 5.23858 5.23858 3 8 3C10.7614 3 13 5.23858 13 8Z",
          fill: ""
        })
      }
    };
  });
  var SunContrastIcon = /*#__PURE__*/createIconComponent("SunContrastIcon", "oxygen-icon oxygen-icon-sun-contrast", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8.5 0.5C8.5 0.223858 8.27614 0 8 0C7.72386 0 7.5 0.223858 7.5 0.5V1.5C7.5 1.77614 7.72386 2 8 2C8.27614 2 8.5 1.77614 8.5 1.5V0.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M8.5 14.5C8.5 14.2239 8.27614 14 8 14C7.72386 14 7.5 14.2239 7.5 14.5V15.5C7.5 15.7761 7.72386 16 8 16C8.27614 16 8.5 15.7761 8.5 15.5V14.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2 8C2 8.27614 1.77614 8.5 1.5 8.5H0.5C0.223858 8.5 0 8.27614 0 8C0 7.72386 0.223858 7.5 0.5 7.5H1.5C1.77614 7.5 2 7.72386 2 8Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M15.5 8.5C15.7761 8.5 16 8.27614 16 8C16 7.72386 15.7761 7.5 15.5 7.5H14.5C14.2239 7.5 14 7.72386 14 8C14 8.27614 14.2239 8.5 14.5 8.5H15.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.4464 3.54647C12.2512 3.35121 12.2512 3.03463 12.4464 2.83936L13.1535 2.13226C13.3488 1.937 13.6654 1.937 13.8606 2.13226C14.0559 2.32752 14.0559 2.6441 13.8606 2.83936L13.1535 3.54647C12.9583 3.74173 12.6417 3.74173 12.4464 3.54647Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.14645 2.86065C1.95118 2.66539 1.95118 2.3488 2.14645 2.15354C2.34171 1.95828 2.65829 1.95828 2.85355 2.15354L3.56066 2.86065C3.75592 3.05591 3.75592 3.37249 3.56066 3.56775C3.3654 3.76302 3.04882 3.76302 2.85355 3.56775L2.14645 2.86065Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M2.14645 13.8465C1.95118 13.6512 1.95118 13.3346 2.14645 13.1394L2.85355 12.4322C3.04882 12.237 3.3654 12.237 3.56066 12.4322C3.75592 12.6275 3.75592 12.9441 3.56066 13.1394L2.85355 13.8465C2.65829 14.0417 2.34171 14.0417 2.14645 13.8465Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M12.4464 13.1606C12.2512 12.9654 12.2512 12.6488 12.4464 12.4535C12.6417 12.2583 12.9583 12.2583 13.1535 12.4535L13.8606 13.1606C14.0559 13.3559 14.0559 13.6725 13.8606 13.8677C13.6654 14.063 13.3488 14.063 13.1535 13.8677L12.4464 13.1606Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M4 8C4 5.96019 5.52684 4.277 7.5 4.03095V11.9691C5.52684 11.723 4 10.0398 4 8ZM13 8C13 5.23858 10.7614 3 8 3C5.23858 3 3 5.23858 3 8C3 10.7614 5.23858 13 8 13C10.7614 13 13 10.7614 13 8ZM8.5 8.5H11.9691C11.9209 8.88649 11.8175 9.25585 11.6672 9.59998H8.5V8.5ZM8.5 10.6V11.9691C9.51298 11.8427 10.4083 11.3376 11.0399 10.6H8.5ZM11.6218 6.29999C11.7968 6.6722 11.9162 7.07579 11.9691 7.5H8.5V6.29999H11.6218ZM10.9513 5.29999C10.3259 4.61681 9.46651 4.15147 8.5 4.03095V5.29999H10.9513Z",
          fill: ""
        }))
      }
    };
  });
  var TalkingHeadsetIcon = /*#__PURE__*/createIconComponent("TalkingHeadsetIcon", "oxygen-icon oxygen-icon-talking-headset", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.1304 1.47826C10.1304 1.21413 10.3445 1 10.6086 1H14.5217C14.7857 1 14.9999 1.21411 14.9999 1.47826V3.43478C14.9999 3.69893 14.7857 3.91304 14.5217 3.91304H12.5652H10.6086H10.5317H10.4137L10.3082 3.96577L10.2393 4.0002L10.2392 4.00026L10.1304 4.05467V1.47826ZM10.6086 0C9.79226 0 9.13037 0.661831 9.13037 1.47826V4.73913V4.86368V5.49863C8.33455 4.71955 7.24507 4.23926 6.04341 4.23926C3.77318 4.23926 1.90334 5.95353 1.65772 8.15821C0.729787 8.23284 0 9.00952 0 9.95669C0 10.8946 0.715508 11.6652 1.63037 11.7527V12.6268C1.63037 13.9495 2.70266 15.0219 4.02543 15.0219H4.97788C5.18289 15.5922 5.72849 16 6.36937 16C7.18579 16 7.84764 15.3381 7.84764 14.5217C7.84764 13.7053 7.18576 13.0435 6.36937 13.0435C5.72838 13.0435 5.18267 13.4515 4.97775 14.0219H4.02543C3.25498 14.0219 2.63037 13.3973 2.63037 12.6268V8.6523C2.63037 6.76733 4.15844 5.23926 6.04341 5.23926C7.92838 5.23926 9.45646 6.76733 9.45646 8.6523V11.4648H9.63037V11.761H10.2825C11.279 11.761 12.0869 10.9533 12.0869 9.95669C12.0869 9.00949 11.3571 8.23282 10.4291 8.15821C10.3199 7.17767 9.88934 6.29413 9.24521 5.61527L9.85397 5.31089L10.6497 4.91304H12.5652H14.5217C15.3381 4.91304 15.9999 4.25119 15.9999 3.43478V1.47826C15.9999 0.661851 15.3381 0 14.5217 0H10.6086ZM11.5868 2.78255C11.7669 2.78255 11.9129 2.63655 11.9129 2.45646C11.9129 2.27637 11.7669 2.13037 11.5868 2.13037C11.4068 2.13037 11.2607 2.27637 11.2607 2.45646C11.2607 2.63655 11.4068 2.78255 11.5868 2.78255ZM12.8912 2.78255C13.0712 2.78255 13.2173 2.63655 13.2173 2.45646C13.2173 2.27637 13.0712 2.13037 12.8912 2.13037C12.7111 2.13037 12.5651 2.27637 12.5651 2.45646C12.5651 2.63655 12.7111 2.78255 12.8912 2.78255ZM11.0869 9.95669C11.0869 10.3412 10.8171 10.6627 10.4565 10.7421V9.1712C10.8171 9.25069 11.0869 9.57219 11.0869 9.95669ZM1.63037 10.7421V9.1712C1.26978 9.25071 1 9.57219 1 9.95669C1 10.3412 1.26976 10.6626 1.63037 10.7421ZM5.89111 14.5217C5.89111 14.2577 6.10522 14.0435 6.36937 14.0435C6.63352 14.0435 6.84764 14.2577 6.84764 14.5217C6.84764 14.7859 6.63349 15 6.36937 15C6.10525 15 5.89111 14.7859 5.89111 14.5217Z",
          fill: ""
        })
      }
    };
  });
  var TilesIcon = /*#__PURE__*/createIconComponent("TilesIcon", "oxygen-icon oxygen-icon-tiles", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.5 1C2.67157 1 2 1.67157 2 2.5V4.5C2 5.32843 2.67157 6 3.5 6H5.5C6.32843 6 7 5.32843 7 4.5V2.5C7 1.67157 6.32843 1 5.5 1H3.5ZM5.5 0C6.88071 0 8 1.11929 8 2.5V4.5C8 5.88071 6.88071 7 5.5 7H3.5C2.11929 7 1 5.88071 1 4.5V2.5C1 1.11929 2.11929 0 3.5 0H5.5ZM2.5 9C1.67157 9 1 9.67157 1 10.5V13.5C1 14.3284 1.67157 15 2.5 15H5.5C6.32843 15 7 14.3284 7 13.5V10.5C7 9.67157 6.32843 9 5.5 9H2.5ZM5.5 8C6.88071 8 8 9.11929 8 10.5V13.5C8 14.8807 6.88071 16 5.5 16H2.5C1.11929 16 0 14.8807 0 13.5V10.5C0 9.11929 1.11929 8 2.5 8H5.5ZM15 2.5C15 1.67157 14.3284 1 13.5 1H11.5C10.6716 1 10 1.67157 10 2.5V4.5C10 5.32843 10.6716 6 11.5 6H13.5C14.3284 6 15 5.32843 15 4.5V2.5ZM9 2.5C9 1.11929 10.1193 0 11.5 0H13.5C14.8807 0 16 1.11929 16 2.5V4.5C16 5.88071 14.8807 7 13.5 7H11.5C10.1193 7 9 5.88071 9 4.5V2.5ZM11.5 9C10.6716 9 10 9.67157 10 10.5V12.5C10 13.3284 10.6716 14 11.5 14H13.5C14.3284 14 15 13.3284 15 12.5V10.5C15 9.67157 14.3284 9 13.5 9H11.5ZM13.5 8C14.8807 8 16 9.11929 16 10.5V12.5C16 13.8807 14.8807 15 13.5 15H11.5C10.1193 15 9 13.8807 9 12.5V10.5C9 9.11929 10.1193 8 11.5 8H13.5Z",
          fill: ""
        })
      }
    };
  });
  var TrashIcon = /*#__PURE__*/createIconComponent("TrashIcon", "oxygen-icon oxygen-icon-trash", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M6.5 7C6.5 6.72386 6.27614 6.5 6 6.5C5.72386 6.5 5.5 6.72386 5.5 7V12C5.5 12.2761 5.72386 12.5 6 12.5C6.27614 12.5 6.5 12.2761 6.5 12V7Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M10 6.5C10.2761 6.5 10.5 6.72386 10.5 7V12C10.5 12.2761 10.2761 12.5 10 12.5C9.72386 12.5 9.5 12.2761 9.5 12V7C9.5 6.72386 9.72386 6.5 10 6.5Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M0.5 3C0.223858 3 0 3.22386 0 3.5C0 3.77614 0.223858 4 0.5 4H2V13C2 14.6569 3.34315 16 5 16H11C12.6569 16 14 14.6569 14 13V4H15.5C15.7761 4 16 3.77614 16 3.5C16 3.22386 15.7761 3 15.5 3H11C11 1.34315 9.65685 0 8 0C6.34315 0 5 1.34315 5 3L0.5 3ZM6 3L10 3C10 1.89543 9.10457 1 8 1C6.89543 1 6 1.89543 6 3ZM13 4H3V13C3 14.1046 3.89543 15 5 15H11C12.1046 15 13 14.1046 13 13V4Z",
          fill: ""
        }))
      }
    };
  });
  var UserIcon = /*#__PURE__*/createIconComponent("UserIcon", "oxygen-icon oxygen-icon-user", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.5314 3.53017C10.5314 4.92755 9.39859 6.06035 8.00121 6.06035C6.60384 6.06035 5.47104 4.92755 5.47104 3.53017C5.47104 2.1328 6.60384 1 8.00121 1C9.39859 1 10.5314 2.1328 10.5314 3.53017ZM11.5314 3.53017C11.5314 5.47983 9.95087 7.06035 8.00121 7.06035C6.05155 7.06035 4.47104 5.47983 4.47104 3.53017C4.47104 1.58051 6.05155 0 8.00121 0C9.95087 0 11.5314 1.58051 11.5314 3.53017ZM8.00057 8.20801C4.06455 8.20801 0.655177 10.4162 0.0826681 13.8776C-0.0608702 14.7455 0.66772 15.3858 1.43078 15.3858L14.5698 15.3854C15.3326 15.3853 16.0609 14.7452 15.9174 13.8776C15.3449 10.4163 11.9367 8.20801 8.00057 8.20801ZM1.06926 14.0408C1.53653 11.2157 4.37986 9.20801 8.00057 9.20801C11.6212 9.20801 14.4635 11.2156 14.9308 14.0408C14.9451 14.1274 14.9192 14.2041 14.8586 14.2679C14.7943 14.3356 14.6912 14.3854 14.5697 14.3854L1.43075 14.3858C1.30911 14.3858 1.20597 14.336 1.14155 14.2682C1.08083 14.2043 1.05493 14.1275 1.06926 14.0408Z",
          fill: ""
        })
      }
    };
  });
  var UserAsteriskIcon = /*#__PURE__*/createIconComponent("UserAsteriskIcon", "oxygen-icon oxygen-icon-user-asterisk", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.45376 2.5C7.45376 3.32843 6.78219 4 5.95376 4C5.12534 4 4.45376 3.32843 4.45376 2.5C4.45376 1.67157 5.12534 1 5.95376 1C6.78219 1 7.45376 1.67157 7.45376 2.5ZM8.45376 2.5C8.45376 3.88071 7.33447 5 5.95376 5C4.57305 5 3.45376 3.88071 3.45376 2.5C3.45376 1.11929 4.57305 0 5.95376 0C7.33447 0 8.45376 1.11929 8.45376 2.5ZM5.95326 6C2.91053 6 0.422402 8.25514 0.0124103 11.5381C-0.0918729 12.3731 0.600248 13 1.35509 13H3.49973C3.77588 13 3.99973 12.7761 3.99973 12.5C3.99973 12.2239 3.77588 12 3.49973 12H1.35509C1.11337 12 0.98549 11.8159 1.0047 11.662C1.35721 8.83933 3.4544 7 5.95326 7H6.40429C6.874 7 7.34028 7.07995 7.78316 7.23644C8.04353 7.32843 8.32917 7.19194 8.42117 6.93157C8.51317 6.67121 8.37667 6.38556 8.11631 6.29356C7.56643 6.09927 6.98749 6 6.40429 6H5.95326ZM14.1272 11.3369C14.0821 10.8877 13.4179 10.8877 13.3728 11.3369L13.2426 12.6336L12.0386 12.0964C11.6215 11.9103 11.2895 12.4774 11.6615 12.7405L12.7353 13.5L11.6615 14.2595C11.2895 14.5226 11.6215 15.0897 12.0386 14.9036L13.2426 14.3664L13.3728 15.6631C13.4179 16.1123 14.0821 16.1123 14.1272 15.6631L14.2574 14.3664L15.4614 14.9036C15.8785 15.0897 16.2105 14.5226 15.8385 14.2595L14.7647 13.5L15.8385 12.7405C16.2105 12.4774 15.8785 11.9103 15.4614 12.0964L14.2574 12.6336L14.1272 11.3369ZM7.87282 11.3369C7.91792 10.8877 8.58208 10.8877 8.62718 11.3369L8.75736 12.6336L9.96137 12.0964C10.3785 11.9103 10.7105 12.4774 10.3385 12.7405L9.26472 13.5L10.3385 14.2595C10.7105 14.5226 10.3785 15.0897 9.96137 14.9036L8.75736 14.3664L8.62718 15.6631C8.58208 16.1123 7.91792 16.1123 7.87282 15.6631L7.74264 14.3664L6.53863 14.9036C6.12154 15.0897 5.78945 14.5226 6.16145 14.2595L7.23528 13.5L6.16145 12.7405C5.78945 12.4774 6.12154 11.9103 6.53863 12.0964L7.74264 12.6336L7.87282 11.3369Z",
          fill: ""
        })
      }
    };
  });
  var UserBannerIcon = /*#__PURE__*/createIconComponent("UserBannerIcon", "oxygen-icon oxygen-icon-user-banner", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95351 4C6.78194 4 7.45351 3.32843 7.45351 2.5C7.45351 1.67157 6.78194 1 5.95351 1C5.12509 1 4.45351 1.67157 4.45351 2.5C4.45351 3.32843 5.12509 4 5.95351 4ZM5.95351 5C7.33423 5 8.45351 3.88071 8.45351 2.5C8.45351 1.11929 7.33423 0 5.95351 0C4.5728 0 3.45351 1.11929 3.45351 2.5C3.45351 3.88071 4.5728 5 5.95351 5ZM5.95328 6C2.91055 6 0.42242 8.25514 0.0124285 11.5381C-0.091855 12.3731 0.600285 13 1.35513 13L4.99977 12.9998C5.27591 12.9998 5.49976 12.7759 5.49975 12.4998C5.49974 12.2236 5.27587 11.9998 4.99973 11.9998L1.35509 12C1.11338 12 0.98551 11.8159 1.00472 11.662C1.35723 8.83933 3.45442 7 5.95328 7C5.96105 7 5.96877 6.99982 5.97645 6.99947C5.98413 6.99982 5.99185 7 5.99961 7C7.00631 7 7.9389 7.29661 8.71878 7.82716C8.9471 7.98248 9.2581 7.92331 9.41343 7.69499C9.56875 7.46667 9.50957 7.15567 9.28126 7.00034C8.33532 6.35683 7.20672 6 5.99961 6C5.99185 6 5.98413 6.00018 5.97645 6.00053C5.96877 6.00018 5.96105 6 5.95328 6ZM6.69995 10H5.9615L6.23569 10.6857L6.96125 12.5L6.23569 14.3143L5.9615 15H6.69995H8.49975C8.49975 15.5523 8.94747 16 9.49975 16H12.4998C13.052 16 13.4998 15.5523 13.4998 15H15.2498H15.9882L15.714 14.3143L14.9884 12.5L15.714 10.6857L15.9882 10H15.2498H13.4998C13.4998 9.44772 13.052 9 12.4998 9H9.49975C8.94747 9 8.49975 9.44771 8.49975 10H6.69995ZM8.49975 11H7.4384L7.964 12.3143L8.03825 12.5L7.964 12.6857L7.4384 14H8.49975V11ZM13.4998 11V14H14.5113L13.9857 12.6857L13.9114 12.5L13.9857 12.3143L14.5113 11H13.4998ZM9.49975 10H12.4998V15H9.49975V10Z",
          fill: ""
        })
      }
    };
  });
  var UserBriefcaseIcon = /*#__PURE__*/createIconComponent("UserBriefcaseIcon", "oxygen-icon oxygen-icon-user-briefcase", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.0124101 11.5381C0.422402 8.25514 2.91053 6 5.95326 6C6.22941 6 6.45326 6.22386 6.45326 6.5C6.45326 6.77614 6.22941 7 5.95326 7C3.4544 7 1.35721 8.83933 1.0047 11.662C0.985492 11.8159 1.11336 12 1.35507 12L4.99971 11.9998C5.27585 11.9998 5.49972 12.2236 5.49973 12.4998C5.49974 12.7759 5.2759 12.9998 4.99975 12.9998L1.35511 13C0.600267 13 -0.0918734 12.3731 0.0124101 11.5381ZM10.5 7C9.94772 7 9.5 7.44772 9.5 8V8.5H8.5C7.67157 8.5 7 9.17157 7 10V10.5V14.5C7 15.3284 7.67157 16 8.5 16H14.5C15.3284 16 16 15.3284 16 14.5V10.5V10C16 9.17157 15.3284 8.5 14.5 8.5H13.5V8C13.5 7.44772 13.0523 7 12.5 7H10.5ZM8 14.5V11.9146C8.15639 11.9699 8.32468 12 8.5 12H14.5C14.6753 12 14.8436 11.9699 15 11.9146V14.5C15 14.7761 14.7761 15 14.5 15H8.5C8.22386 15 8 14.7761 8 14.5ZM8.5 11C8.22386 11 8 10.7761 8 10.5V10C8 9.72386 8.22386 9.5 8.5 9.5H14.5C14.7761 9.5 15 9.72386 15 10V10.5C15 10.7761 14.7761 11 14.5 11H8.5ZM12.5 8.5V8H10.5V8.5H12.5Z",
          fill: ""
        })
      }
    };
  });
  var UserCircleDotIcon = /*#__PURE__*/createIconComponent("UserCircleDotIcon", "oxygen-icon oxygen-icon-user-circle-dot", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.45376 2.5C7.45376 3.32843 6.78219 4 5.95376 4C5.12534 4 4.45376 3.32843 4.45376 2.5C4.45376 1.67157 5.12534 1 5.95376 1C6.78219 1 7.45376 1.67157 7.45376 2.5ZM8.45376 2.5C8.45376 3.88071 7.33447 5 5.95376 5C4.57305 5 3.45376 3.88071 3.45376 2.5C3.45376 1.11929 4.57305 0 5.95376 0C7.33447 0 8.45376 1.11929 8.45376 2.5ZM5.95326 6C2.91053 6 0.422402 8.25514 0.01241 11.5381C-0.0918736 12.3731 0.600271 13 1.35511 13L4.99976 12.9998C5.2759 12.9998 5.49975 12.7759 5.49973 12.4997C5.49972 12.2236 5.27585 11.9998 4.99971 11.9998L1.35506 12C1.11336 12 0.985492 11.8159 1.0047 11.662C1.35721 8.83933 3.4544 7 5.95326 7C6.22941 7 6.45326 6.77614 6.45326 6.5C6.45326 6.22386 6.22941 6 5.95326 6ZM11.5 8C9.567 8 8 9.567 8 11.5C8 13.433 9.567 15 11.5 15C13.433 15 15 13.433 15 11.5C15 9.567 13.433 8 11.5 8ZM7 11.5C7 9.01472 9.01472 7 11.5 7C13.9853 7 16 9.01472 16 11.5C16 13.9853 13.9853 16 11.5 16C9.01472 16 7 13.9853 7 11.5ZM10.5 11.5C10.5 10.9477 10.9477 10.5 11.5 10.5C12.0523 10.5 12.5 10.9477 12.5 11.5C12.5 12.0523 12.0523 12.5 11.5 12.5C10.9477 12.5 10.5 12.0523 10.5 11.5ZM11.5 9.5C10.3954 9.5 9.5 10.3954 9.5 11.5C9.5 12.6046 10.3954 13.5 11.5 13.5C12.6046 13.5 13.5 12.6046 13.5 11.5C13.5 10.3954 12.6046 9.5 11.5 9.5Z",
          fill: ""
        })
      }
    };
  });
  var UserDatabaseIcon = /*#__PURE__*/createIconComponent("UserDatabaseIcon", "oxygen-icon oxygen-icon-user-database", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.01241 11.5381C0.422402 8.25514 2.91053 6 5.95326 6C6.22941 6 6.45326 6.22386 6.45326 6.5C6.45326 6.77614 6.22941 7 5.95326 7C3.4544 7 1.35721 8.83933 1.0047 11.662C0.985492 11.8159 1.11336 12 1.35506 12L4.99971 11.9998C5.27585 11.9998 5.49972 12.2236 5.49973 12.4997C5.49975 12.7759 5.2759 12.9998 4.99976 12.9998L1.35511 13C0.600271 13 -0.0918736 12.3731 0.01241 11.5381ZM8 9C8 8.98723 8.00511 8.91521 8.14604 8.79026C8.28639 8.66583 8.51801 8.53093 8.84713 8.4075C9.5017 8.16204 10.4395 8 11.5 8C12.5605 8 13.4983 8.16204 14.1529 8.4075C14.482 8.53093 14.7136 8.66583 14.854 8.79026C14.9949 8.91521 15 8.98723 15 9C15 9.01277 14.9949 9.08479 14.854 9.20974C14.7136 9.33417 14.482 9.46907 14.1529 9.59249C13.4983 9.83796 12.5605 10 11.5 10C10.4395 10 9.5017 9.83796 8.84713 9.59249C8.51801 9.46907 8.28639 9.33417 8.14604 9.20974C8.00511 9.08479 8 9.01277 8 9ZM14.504 10.5288C14.6787 10.4633 14.8454 10.3899 15 10.3081V11.5C15 11.5128 14.9949 11.5848 14.854 11.7097C14.7136 11.8342 14.482 11.9691 14.1529 12.0925C13.4983 12.338 12.5605 12.5 11.5 12.5C10.4395 12.5 9.5017 12.338 8.84713 12.0925C8.51801 11.9691 8.28639 11.8342 8.14604 11.7097C8.00511 11.5848 8 11.5128 8 11.5V10.3081C8.15455 10.3899 8.32131 10.4633 8.49601 10.5288C9.28916 10.8263 10.3513 11 11.5 11C12.6487 11 13.7108 10.8263 14.504 10.5288ZM7.48264 8.042C7.21875 8.27597 7 8.59855 7 9V11.5V14C7 14.4014 7.21875 14.724 7.48264 14.958C7.74711 15.1925 8.10128 15.3808 8.49601 15.5288C9.28916 15.8263 10.3513 16 11.5 16C12.6487 16 13.7108 15.8263 14.504 15.5288C14.8987 15.3808 15.2529 15.1925 15.5174 14.958C15.7813 14.724 16 14.4014 16 14V11.5V9C16 8.59855 15.7813 8.27597 15.5174 8.042C15.2529 7.80752 14.8987 7.6192 14.504 7.47118C13.7108 7.17374 12.6487 7 11.5 7C10.3513 7 9.28916 7.17374 8.49601 7.47118C8.10128 7.6192 7.74711 7.80752 7.48264 8.042ZM8 12.8081C8.15455 12.8899 8.32131 12.9633 8.49601 13.0288C9.28916 13.3263 10.3513 13.5 11.5 13.5C12.6487 13.5 13.7108 13.3263 14.504 13.0288C14.6787 12.9633 14.8454 12.8899 15 12.8081V14C15 14.0128 14.9949 14.0848 14.854 14.2097C14.7136 14.3342 14.482 14.4691 14.1529 14.5925C13.4983 14.838 12.5605 15 11.5 15C10.4395 15 9.5017 14.838 8.84713 14.5925C8.51801 14.4691 8.28639 14.3342 8.14604 14.2097C8.00511 14.0848 8 14.0128 8 14V12.8081Z",
          fill: ""
        })
      }
    };
  });
  var UserDocumentIcon = /*#__PURE__*/createIconComponent("UserDocumentIcon", "oxygen-icon oxygen-icon-user-document", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.01241 11.5381C0.422402 8.25514 2.91053 6 5.95326 6C6.22941 6 6.45326 6.22386 6.45326 6.5C6.45326 6.77614 6.22941 7 5.95326 7C3.4544 7 1.35721 8.83933 1.0047 11.662C0.985492 11.8159 1.11336 12 1.35506 12L4.99971 11.9998C5.27585 11.9998 5.49972 12.2236 5.49973 12.4997C5.49975 12.7759 5.2759 12.9998 4.99976 12.9998L1.35511 13C0.600271 13 -0.0918736 12.3731 0.01241 11.5381ZM9.5 6.5C8.39543 6.5 7.5 7.39543 7.5 8.5V14C7.5 15.1046 8.39543 16 9.5 16H12.4159C12.762 16 13.0975 15.8803 13.3655 15.6612L14.9496 14.3657C15.2979 14.0808 15.5 13.6546 15.5 13.2045V8.5C15.5 7.39543 14.6046 6.5 13.5 6.5H9.5ZM8.5 8.5C8.5 7.94772 8.94771 7.5 9.5 7.5H13.5C14.0523 7.5 14.5 7.94772 14.5 8.5V13.2045C14.5 13.3546 14.4326 13.4966 14.3165 13.5916L12.7324 14.8871C12.6431 14.9601 12.5313 15 12.4159 15H9.5C8.94772 15 8.5 14.5523 8.5 14V8.5ZM10 10C10 9.72386 10.2239 9.5 10.5 9.5H12.5C12.7761 9.5 13 9.72386 13 10C13 10.2761 12.7761 10.5 12.5 10.5H10.5C10.2239 10.5 10 10.2761 10 10ZM10.5 12C10.2239 12 10 12.2239 10 12.5C10 12.7761 10.2239 13 10.5 13H11.5C11.7761 13 12 12.7761 12 12.5C12 12.2239 11.7761 12 11.5 12H10.5Z",
          fill: ""
        })
      }
    };
  });
  var UserFlowIcon = /*#__PURE__*/createIconComponent("UserFlowIcon", "oxygen-icon oxygen-icon-user-flow", function () {
    return {
      "16": {
        "width": 17,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.19476 4.47845L2.22703 4.77944C3.83732 1.94728 7.35155 0.711998 10.421 2.01926C11.2078 2.35434 11.8934 2.82553 12.4629 3.39335C12.6585 3.58831 12.9751 3.58782 13.17 3.39226C13.365 3.19669 13.3645 2.88011 13.169 2.68515C12.5106 2.02885 11.7188 1.48508 10.8129 1.09923C7.30308 -0.395561 3.28932 0.990716 1.40902 4.19614L1.16507 3.4118C1.08306 3.14812 0.802822 3.00084 0.539139 3.08285C0.275456 3.16487 0.128182 3.44511 0.210193 3.70879L0.840203 5.7344L0.988698 6.21184L1.46614 6.06334L3.49175 5.43333C3.75543 5.35132 3.9027 5.07108 3.82069 4.8074C3.73868 4.54371 3.45844 4.39644 3.19476 4.47845ZM2.57812 12.6067C2.77308 12.4112 3.08966 12.4107 3.28522 12.6056C3.85479 13.1734 4.54039 13.6446 5.32714 13.9797C8.49868 15.3305 12.145 13.9667 13.6754 10.9318L12.9486 11.3789C12.7134 11.5236 12.4054 11.4502 12.2607 11.215C12.116 10.9798 12.1894 10.6719 12.4246 10.5272L14.2314 9.41561L14.6572 9.15361L14.9192 9.57947L16.0308 11.3862C16.1755 11.6214 16.1021 11.9294 15.8669 12.0741C15.6317 12.2188 15.3238 12.1454 15.1791 11.9102L14.6936 11.1212C13.0093 14.8055 8.68472 16.4966 4.93531 14.8998C4.02933 14.5139 3.23753 13.9701 2.57921 13.3138C2.38364 13.1189 2.38316 12.8023 2.57812 12.6067ZM7.70223 5.98883C8.2514 5.98883 8.69659 5.54364 8.69659 4.99447C8.69659 4.44531 8.2514 4.00012 7.70223 4.00012C7.15306 4.00012 6.70787 4.44531 6.70787 4.99447C6.70787 5.54364 7.15306 5.98883 7.70223 5.98883ZM7.70223 6.98883C8.80369 6.98883 9.69659 6.09593 9.69659 4.99447C9.69659 3.89302 8.80369 3.00012 7.70223 3.00012C6.60078 3.00012 5.70787 3.89302 5.70787 4.99447C5.70787 6.09593 6.60078 6.98883 7.70223 6.98883ZM4.71455 10.4096L10.6881 10.4095C10.2319 9.56297 9.16802 8.91955 7.70165 8.91955C6.23506 8.91955 5.1708 9.56314 4.71455 10.4096ZM11.4129 11.4094C11.7031 11.4094 11.9429 11.1726 11.8955 10.8862C11.6018 9.1104 9.83623 7.91955 7.70165 7.91955C5.56708 7.91955 3.80086 9.1104 3.50715 10.8862C3.45977 11.1727 3.69967 11.4097 3.99007 11.4097L11.4129 11.4094Z",
          fill: ""
        })
      }
    };
  });
  var UserGearIcon = /*#__PURE__*/createIconComponent("UserGearIcon", "oxygen-icon oxygen-icon-user-gear", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.01241 11.5381C0.422402 8.25514 2.91053 6 5.95326 6C6.22941 6 6.45326 6.22386 6.45326 6.5C6.45326 6.77614 6.22941 7 5.95326 7C3.4544 7 1.35721 8.83933 1.0047 11.662C0.985492 11.8159 1.11336 12 1.35506 12L4.99971 11.9998C5.27585 11.9998 5.49972 12.2236 5.49973 12.4997C5.49975 12.7759 5.2759 12.9998 4.99976 12.9998L1.35511 13C0.600271 13 -0.0918736 12.3731 0.01241 11.5381ZM12.5532 7.67V7.91723L12.6346 7.94155C12.8349 8.00535 13.029 8.08594 13.2151 8.18232L13.2881 8.22208L13.4634 8.04721C13.6889 7.82166 14.0386 7.78862 14.3118 7.96719L14.3621 8.00315L14.4112 8.04721L14.9528 8.58883C15.1924 8.82847 15.2148 9.20825 14.9968 9.48759L14.9529 9.53657L14.7775 9.71149L14.8177 9.78493C14.9141 9.97102 14.9947 10.1651 15.0584 10.3654L15.0824 10.4464L15.3298 10.4468C15.6519 10.4468 15.9245 10.6751 15.988 10.9979L15.9969 11.0558L16 11.117V11.883C16 12.2241 15.744 12.5096 15.391 12.5501L15.3298 12.5532L15.0824 12.5528L15.0585 12.6343C14.9947 12.8347 14.9141 13.0288 14.8177 13.215L14.7775 13.2877L14.9528 13.4634C15.1991 13.7097 15.2136 14.1001 14.9963 14.3634L14.9528 14.4112L14.4112 14.9528C14.1494 15.2145 13.7251 15.2145 13.4634 14.9529L13.2877 14.7775L13.215 14.8177C13.0288 14.9141 12.8347 14.9947 12.6343 15.0585L12.5528 15.0824L12.5532 15.3298C12.5532 15.6814 12.2824 15.9698 11.9379 15.9978L11.883 16H11.117C10.7469 16 10.4468 15.6999 10.4468 15.33L10.4464 15.0824L10.3654 15.0584C10.1651 14.9947 9.97102 14.9141 9.78493 14.8177L9.71149 14.7775L9.53665 14.9528C9.29031 15.1991 8.89992 15.2136 8.63664 14.9963L8.58883 14.9528L8.04721 14.4112C7.78548 14.1494 7.78548 13.7251 8.04713 13.4634L8.22208 13.2877L8.18227 13.215C8.08586 13.0288 8.00526 12.8347 7.94145 12.6343L7.91723 12.5528L7.67021 12.5532C7.31857 12.5532 7.03018 12.2824 7.00222 11.9379L7 11.883V11.117C7 10.7469 7.30006 10.4468 7.67 10.4468L7.91723 10.4464L7.94155 10.3654C8.00535 10.1651 8.08594 9.97102 8.18232 9.78493L8.22208 9.71149L8.04721 9.53665C7.82166 9.3111 7.78862 8.96142 7.96719 8.68818L8.00315 8.63789L8.04721 8.58883L8.58883 8.04721C8.82847 7.80757 9.20825 7.78525 9.48759 8.00315L9.53657 8.04713L9.71187 8.22208L9.78502 8.18227C9.97118 8.08586 10.1653 8.00526 10.3657 7.94145L10.4468 7.91723V7.67021C10.4468 7.34805 10.6751 7.07547 10.9979 7.01204L11.0558 7.00305L11.117 7H11.883C12.2241 7 12.5096 7.25598 12.5501 7.60901L12.5532 7.67ZM11.735 8.52685L12.393 8.72326C12.5441 8.77183 12.6908 8.83271 12.8318 8.90523L13.4336 9.23279L13.9372 8.73028L14.2695 9.06261L13.7653 9.56557L14.0951 10.1688C14.1673 10.3092 14.2279 10.4554 14.2764 10.6059L14.4706 11.2637L15.1818 11.2648V11.7348L14.4694 11.7337L14.2761 12.3948C14.2279 12.5445 14.1676 12.6899 14.0959 12.8296L13.764 13.4304L14.2697 13.9372L13.9372 14.2697L13.4304 13.764L12.8296 14.0959C12.6899 14.1676 12.5445 14.2279 12.3948 14.2761L11.7337 14.4694L11.7348 15.1818H11.2648L11.2637 14.4706L10.6059 14.2764C10.4554 14.2279 10.3092 14.1673 10.1688 14.0951L9.56557 13.7653L9.06261 14.2695L8.73017 13.937L9.23344 13.4317L8.9048 12.831C8.83251 12.6903 8.7718 12.544 8.72334 12.3932L8.52743 11.7337L7.81818 11.7348V11.2648L8.52631 11.2637L8.72312 10.6075C8.77179 10.4559 8.83285 10.3088 8.90561 10.1675L9.23214 9.56438L8.73039 9.06273L9.06284 8.73028L9.56635 9.23278L10.1683 8.90519C10.3093 8.83265 10.4561 8.77176 10.6073 8.72319L11.265 8.52689V7.81818H11.735V8.52685ZM13.1875 11.5C13.1875 12.432 12.432 13.1875 11.5 13.1875C10.568 13.1875 9.8125 12.432 9.8125 11.5C9.8125 10.568 10.568 9.8125 11.5 9.8125C12.432 9.8125 13.1875 10.568 13.1875 11.5ZM12.3693 11.5C12.3693 11.9801 11.9801 12.3693 11.5 12.3693C11.0199 12.3693 10.6307 11.9801 10.6307 11.5C10.6307 11.0199 11.0199 10.6307 11.5 10.6307C11.9801 10.6307 12.3693 11.0199 12.3693 11.5Z",
          fill: ""
        })
      }
    };
  });
  var UserGroupIcon = /*#__PURE__*/createIconComponent("UserGroupIcon", "oxygen-icon oxygen-icon-user-group", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M10.6889 4.16667C10.6889 5.63943 9.49253 6.83333 8.0167 6.83333C6.54086 6.83333 5.34447 5.63943 5.34447 4.16667C5.34447 2.69391 6.54086 1.5 8.0167 1.5C9.49253 1.5 10.6889 2.69391 10.6889 4.16667ZM9.68684 4.16667C9.68684 5.08714 8.93909 5.83333 8.0167 5.83333C7.0943 5.83333 6.34655 5.08714 6.34655 4.16667C6.34655 3.24619 7.0943 2.5 8.0167 2.5C8.93909 2.5 9.68684 3.24619 9.68684 4.16667ZM14.8309 5.5C14.8309 6.60457 13.9336 7.5 12.8267 7.5C11.7198 7.5 10.8226 6.60457 10.8226 5.5C10.8226 4.39543 11.7198 3.5 12.8267 3.5C13.9336 3.5 14.8309 4.39543 14.8309 5.5ZM13.8288 5.5C13.8288 6.05228 13.3802 6.5 12.8267 6.5C12.2733 6.5 11.8246 6.05228 11.8246 5.5C11.8246 4.94772 12.2733 4.5 12.8267 4.5C13.3802 4.5 13.8288 4.94772 13.8288 5.5ZM12.3257 8.83333C12.3257 8.55719 12.55 8.33333 12.8267 8.33333C14.6778 8.33333 16 10.1595 16 12.1667V12.6667H14C13.7233 12.6667 13.499 12.4428 13.499 12.1667C13.499 11.8905 13.7233 11.6667 14 11.6667H14.965C14.7772 10.2657 13.814 9.33333 12.8267 9.33333C12.55 9.33333 12.3257 9.10948 12.3257 8.83333ZM3.17328 7.5C2.0664 7.5 1.1691 6.60457 1.1691 5.5C1.1691 4.39543 2.0664 3.5 3.17328 3.5C4.28015 3.5 5.17745 4.39543 5.17745 5.5C5.17745 6.60457 4.28015 7.5 3.17328 7.5ZM3.17328 6.5C2.61984 6.5 2.17119 6.05228 2.17119 5.5C2.17119 4.94772 2.61984 4.5 3.17328 4.5C3.72671 4.5 4.17536 4.94772 4.17536 5.5C4.17536 6.05228 3.72671 6.5 3.17328 6.5ZM3.17328 8.33333C3.45 8.33333 3.67432 8.55719 3.67432 8.83333C3.67432 9.10948 3.45 9.33333 3.17328 9.33333C2.18599 9.33333 1.22279 10.2657 1.03498 11.6667H1.99896C2.27568 11.6667 2.5 11.8905 2.5 12.1667C2.5 12.4428 2.27568 12.6667 1.99896 12.6667H0V12.1667C0 10.1595 1.32217 8.33333 3.17328 8.33333ZM11.9527 13.4995L4.0472 13.4999C4.36752 10.1344 6.20326 8.5 7.99583 8.5C9.79005 8.5 11.6322 10.1365 11.9527 13.4995ZM7.99583 7.5C5.66253 7.5 3.70598 9.4418 3.15494 12.6325C3.09991 12.9511 3.0589 13.2822 3.03292 13.625C2.99639 14.1073 3.39214 14.5 3.87583 14.4999L12.1248 14.4994C12.6082 14.4994 13.0036 14.107 12.9671 13.625C12.681 9.84899 10.5621 7.5 7.99583 7.5Z",
          fill: ""
        })
      }
    };
  });
  var UserKeyIcon = /*#__PURE__*/createIconComponent("UserKeyIcon", "oxygen-icon oxygen-icon-user-key", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.0124103 11.5381C0.422402 8.25514 2.91053 6 5.95326 6H6.40429C6.98749 6 7.56643 6.09927 8.11631 6.29356C8.37667 6.38556 8.51317 6.67121 8.42117 6.93157C8.32917 7.19194 8.04353 7.32843 7.78316 7.23644C7.34028 7.07995 6.874 7 6.40429 7H5.95326C3.4544 7 1.35721 8.83933 1.0047 11.662C0.98549 11.8159 1.11337 12 1.35509 12H3.49973C3.77588 12 3.99973 12.2239 3.99973 12.5C3.99973 12.7761 3.77588 13 3.49973 13H1.35509C0.600248 13 -0.0918729 12.3731 0.0124103 11.5381ZM12.5 12.5C13.8807 12.5 15 11.3807 15 10C15 8.61929 13.8807 7.5 12.5 7.5C11.1193 7.5 10 8.61929 10 10C10 11.3807 11.1193 12.5 12.5 12.5ZM12.5 13.5C14.433 13.5 16 11.933 16 10C16 8.067 14.433 6.5 12.5 6.5C10.567 6.5 9 8.067 9 10C9 10.2444 9.02505 10.483 9.07273 10.7132L5.69497 13.8039C5.57075 13.9175 5.5 14.0782 5.5 14.2465V15.4C5.5 15.7314 5.76863 16 6.1 16H7.905C8.05707 16 8.20346 15.9423 8.31459 15.8385L8.80958 15.3761C8.93105 15.2626 9 15.1038 9 14.9376V14.7025H9.57167C9.72374 14.7025 9.87013 14.6447 9.98125 14.5409L11.3155 13.2945C11.6855 13.4275 12.0843 13.5 12.5 13.5ZM6.5 14.4227L9.45201 11.7216C9.68843 12.1393 10.0082 12.5036 10.3888 12.7918L9.4139 13.7025H8.6C8.26863 13.7025 8 13.9711 8 14.3025V14.7639L7.74724 15H6.5V14.4227Z",
          fill: ""
        })
      }
    };
  });
  var UserPencilIcon = /*#__PURE__*/createIconComponent("UserPencilIcon", "oxygen-icon oxygen-icon-user-pencil", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.9535 4C6.78192 4 7.4535 3.32843 7.4535 2.5C7.4535 1.67157 6.78192 1 5.9535 1C5.12507 1 4.4535 1.67157 4.4535 2.5C4.4535 3.32843 5.12507 4 5.9535 4ZM5.9535 5C7.33421 5 8.4535 3.88071 8.4535 2.5C8.4535 1.11929 7.33421 0 5.9535 0C4.57278 0 3.4535 1.11929 3.4535 2.5C3.4535 3.88071 4.57278 5 5.9535 5ZM5.95326 6C2.91053 6 0.422402 8.25514 0.0124101 11.5381C-0.0918734 12.3731 0.600267 13 1.35511 13L4.99975 12.9998C5.2759 12.9998 5.49974 12.7759 5.49973 12.4998C5.49972 12.2236 5.27585 11.9998 4.99971 11.9998L1.35507 12C1.11336 12 0.985492 11.8159 1.0047 11.662C1.35721 8.83933 3.4544 7 5.95326 7C5.96103 7 5.96875 6.99982 5.97643 6.99947C5.98411 6.99982 5.99183 7 5.99959 7C7.00629 7 7.93888 7.29661 8.71876 7.82716C8.94708 7.98248 9.25808 7.92331 9.41341 7.69499C9.56873 7.46667 9.50956 7.15567 9.28124 7.00034C8.3353 6.35683 7.2067 6 5.99959 6C5.99183 6 5.98411 6.00018 5.97643 6.00053C5.96875 6.00018 5.96103 6 5.95326 6ZM14.253 8.56051C14.0577 8.36525 13.7411 8.36525 13.5459 8.56051L13.1065 8.99985L14.3994 10.2927L14.8388 9.8534C15.034 9.65814 15.034 9.34156 14.8388 9.1463L14.253 8.56051ZM12.8388 7.8534L12.0459 8.6463L7.54586 13.1463L7.39941 13.2927V13.4998V15.4998V15.9998H7.89941H9.89941H10.1065L10.253 15.8534L14.7528 11.3535L14.753 11.3534L14.7531 11.3533L15.5459 10.5605C16.1316 9.97472 16.1316 9.02498 15.5459 8.43919L14.9601 7.8534C14.3743 7.26762 13.4245 7.26762 12.8388 7.8534ZM9.69231 14.9998L13.6923 10.9998L12.3994 9.70696L8.39941 13.707V14.9998H9.69231Z",
          fill: ""
        })
      }
    };
  });
  var UserPlusIcon = /*#__PURE__*/createIconComponent("UserPlusIcon", "oxygen-icon oxygen-icon-user-plus", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.95376 4C6.78219 4 7.45376 3.32843 7.45376 2.5C7.45376 1.67157 6.78219 1 5.95376 1C5.12534 1 4.45376 1.67157 4.45376 2.5C4.45376 3.32843 5.12534 4 5.95376 4ZM5.95376 5C7.33447 5 8.45376 3.88071 8.45376 2.5C8.45376 1.11929 7.33447 0 5.95376 0C4.57305 0 3.45376 1.11929 3.45376 2.5C3.45376 3.88071 4.57305 5 5.95376 5ZM0.01241 11.5381C0.422402 8.25514 2.91053 6 5.95326 6C6.22941 6 6.45326 6.22386 6.45326 6.5C6.45326 6.77614 6.22941 7 5.95326 7C3.4544 7 1.35721 8.83933 1.0047 11.662C0.985492 11.8159 1.11336 12 1.35506 12L4.99971 11.9998C5.27585 11.9998 5.49972 12.2236 5.49973 12.4997C5.49975 12.7759 5.2759 12.9998 4.99976 12.9998L1.35511 13C0.600271 13 -0.0918736 12.3731 0.01241 11.5381ZM11.1969 6.94097C11.4731 6.94096 11.6969 7.16481 11.697 7.44095L11.6971 10.6664L14.9235 10.6666C15.1997 10.6666 15.4235 10.8904 15.4235 11.1666C15.4235 11.4427 15.1996 11.6666 14.9235 11.6666L11.6971 11.6664L11.6973 14.893C11.6973 15.1691 11.4734 15.393 11.1973 15.393C10.9211 15.393 10.6973 15.1692 10.6973 14.893L10.6971 11.6664L7.47147 11.6662C7.19533 11.6662 6.97148 11.4424 6.97149 11.1662C6.9715 10.8901 7.19537 10.6662 7.47151 10.6662L10.6971 10.6664L10.697 7.44099C10.6969 7.16485 10.9208 6.94098 11.1969 6.94097Z",
          fill: ""
        })
      }
    };
  });
  var UsersIcon = /*#__PURE__*/createIconComponent("UsersIcon", "oxygen-icon oxygen-icon-users", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M7.75607 5.95567C7.75607 6.92519 6.97011 7.71115 6.00059 7.71115C5.03107 7.71115 4.24512 6.92519 4.24512 5.95567C4.24512 4.98615 5.03107 4.2002 6.00059 4.2002C6.97011 4.2002 7.75607 4.98615 7.75607 5.95567ZM8.75607 5.95567C8.75607 7.47748 7.5224 8.71115 6.00059 8.71115C4.47879 8.71115 3.24512 7.47748 3.24512 5.95567C3.24512 4.43386 4.47879 3.2002 6.00059 3.2002C7.5224 3.2002 8.75607 4.43386 8.75607 5.95567ZM6.00085 9.57772C3.04247 9.57772 0.480303 11.344 0.0512571 14.0996C-0.0658599 14.8518 0.563735 15.3998 1.21564 15.3998L10.7857 15.3995C11.4374 15.3994 12.0667 14.8516 11.9496 14.0996C11.5206 11.3441 8.95933 9.57772 6.00085 9.57772ZM1.03935 14.2535C1.37433 12.1021 3.4066 10.5777 6.00085 10.5777C8.59501 10.5777 10.6266 12.102 10.9615 14.2535C10.9666 14.2861 10.9586 14.3138 10.9321 14.3415C10.9023 14.3728 10.8506 14.3995 10.7856 14.3995L1.21561 14.3998C1.15058 14.3998 1.09876 14.3731 1.06883 14.3417C1.04234 14.3139 1.03426 14.2862 1.03935 14.2535Z",
          fill: ""
        }), /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M9.77049 2.116C9.77049 2.73235 10.2701 3.232 10.8865 3.232C11.5028 3.232 12.0025 2.73235 12.0025 2.116C12.0025 1.49965 11.5028 1 10.8865 1C10.2701 1 9.77049 1.49965 9.77049 2.116ZM8.77049 2.116C8.77049 3.28463 9.71786 4.232 10.8865 4.232C12.0551 4.232 13.0025 3.28463 13.0025 2.116C13.0025 0.947365 12.0551 0 10.8865 0C9.71786 0 8.77049 0.947365 8.77049 2.116ZM10.8859 5.00146C13.5031 5.00146 15.6391 6.94215 15.9905 9.7562C16.0853 10.5153 15.4561 11.0799 14.7778 11.0798L12.693 11.0797C12.4168 11.0797 12.193 10.8558 12.193 10.5797C12.193 10.3035 12.4169 10.0797 12.693 10.0797L14.7779 10.0798C14.8529 10.0798 14.915 10.0493 14.9536 10.0092C14.9896 9.97181 15.0043 9.92891 14.9982 9.88012C14.7042 7.52634 12.9592 6.00146 10.8859 6.00146C10.6098 6.00146 10.3859 5.77761 10.3859 5.50146C10.3859 5.22532 10.6098 5.00146 10.8859 5.00146Z",
          fill: ""
        }))
      }
    };
  });
  var VerticleFilterBarsIcon = /*#__PURE__*/createIconComponent("VerticleFilterBarsIcon", "oxygen-icon oxygen-icon-verticle-filter-bars", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M3.5 0C3.77614 0 4 0.223858 4 0.5V2C4 2.01186 3.99959 2.02362 3.99878 2.03527C5.69552 2.27736 7 3.73634 7 5.5C7 7.26324 5.69615 8.72194 4 8.96456V15.5C4 15.7761 3.77614 16 3.5 16C3.22386 16 3 15.7761 3 15.5V8.96456C1.30385 8.72194 0 7.26324 0 5.5C0 3.73634 1.30448 2.27736 3.00122 2.03527C3.00041 2.02362 3 2.01186 3 2V0.5C3 0.223858 3.22386 0 3.5 0ZM6 5.5C6 6.88071 4.88071 8 3.5 8C2.11929 8 1 6.88071 1 5.5C1 4.11929 2.11929 3 3.5 3C4.88071 3 6 4.11929 6 5.5ZM10 10.5C10 9.11929 11.1193 8 12.5 8C13.8807 8 15 9.11929 15 10.5C15 11.8807 13.8807 13 12.5 13C11.1193 13 10 11.8807 10 10.5ZM12 7.03544C10.3039 7.27806 9 8.73676 9 10.5C9 12.2632 10.3039 13.7219 12 13.9646V15.5C12 15.7761 12.2239 16 12.5 16C12.7761 16 13 15.7761 13 15.5V13.9646C14.6961 13.7219 16 12.2632 16 10.5C16 8.73676 14.6961 7.27806 13 7.03544V0.5C13 0.223857 12.7761 0 12.5 0C12.2239 0 12 0.223858 12 0.5V7.03544Z",
          fill: ""
        })
      }
    };
  });
  var WebhookIcon = /*#__PURE__*/createIconComponent("WebhookIcon", "oxygen-icon oxygen-icon-webhook", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement("g", {
          clipPath: "url(#clip0_26_46)"
        }, /*#__PURE__*/React__default["default"].createElement("path", {
          d: "M3.8969 16C2.81383 16 1.89362 15.5941 1.13626 14.7822C0.378752 13.9704 0 12.9897 0 11.84C0 10.9245 0.246274 10.1066 0.738823 9.38629C1.23137 8.66613 1.86923 8.16945 2.65241 7.89623V9.17623C2.19608 9.42476 1.82531 9.78522 1.54011 10.2576C1.2549 10.7301 1.1123 11.2576 1.1123 11.84C1.1123 12.6606 1.38381 13.3609 1.92684 13.941C2.46973 14.5213 3.12513 14.8114 3.89305 14.8114C4.66096 14.8114 5.31636 14.5213 5.85925 13.941C6.40228 13.3609 6.6738 12.6606 6.6738 11.84V11.2457H11.4306C11.4998 11.125 11.5963 11.0315 11.7202 10.9653C11.8443 10.8991 11.9732 10.8661 12.107 10.8661C12.3592 10.8661 12.5742 10.961 12.7519 11.1509C12.9296 11.3407 13.0184 11.5704 13.0184 11.84C13.0184 12.1096 12.9296 12.3393 12.7519 12.5291C12.5742 12.719 12.3592 12.8139 12.107 12.8139C11.9676 12.8139 11.8374 12.7823 11.7161 12.7191C11.5949 12.6558 11.4998 12.5609 11.4306 12.4343H7.75487C7.60242 13.4904 7.159 14.3487 6.4246 15.0091C5.69034 15.6697 4.84777 16 3.8969 16ZM12.1029 16C11.4342 16 10.8191 15.837 10.2575 15.5111C9.69597 15.1853 9.23415 14.7341 8.87209 14.1575H10.3611C10.5915 14.3484 10.8588 14.5051 11.1628 14.6277C11.467 14.7502 11.7817 14.8114 12.107 14.8114C12.8749 14.8114 13.5303 14.5213 14.0732 13.941C14.6162 13.3609 14.8877 12.6606 14.8877 11.84C14.8877 11.0194 14.6162 10.3191 14.0732 9.73897C13.5303 9.1587 12.8749 8.86857 12.107 8.86857C11.7668 8.86857 11.4504 8.93509 11.1576 9.06811C10.8647 9.20114 10.5998 9.38255 10.3628 9.61234L8.24513 5.04251C8.07401 5.00396 7.92399 4.90057 7.79508 4.73234C7.66631 4.56411 7.60193 4.37333 7.60193 4.16C7.60193 3.89044 7.69077 3.66072 7.86845 3.47086C8.04613 3.28099 8.26111 3.18606 8.51337 3.18606C8.76563 3.18606 8.98061 3.28099 9.15829 3.47086C9.33597 3.66072 9.42481 3.89044 9.42481 4.16C9.42481 4.208 9.41305 4.26423 9.38952 4.32869C9.36599 4.3933 9.34595 4.44084 9.32941 4.47131L10.9305 7.86629C11.118 7.82057 11.3089 7.77813 11.5033 7.73897C11.6977 7.69966 11.8989 7.68 12.107 7.68C13.1829 7.68 14.1007 8.0864 14.8603 8.8992C15.6201 9.712 16 10.694 16 11.8453C16 12.9963 15.6198 13.9765 14.8593 14.7858C14.0988 15.5953 13.18 16 12.1029 16ZM3.89305 12.8139C3.64078 12.8139 3.42581 12.719 3.24813 12.5291C3.07045 12.3393 2.9816 12.1096 2.9816 11.84C2.9816 11.6034 3.04984 11.3977 3.18631 11.2231C3.32292 11.0483 3.50752 10.9522 3.74011 10.9346L5.92684 7.2704C5.50702 6.88457 5.18431 6.42271 4.95872 5.8848C4.73312 5.34674 4.62032 4.77181 4.62032 4.16C4.62032 3.01029 5.00064 2.02956 5.76128 1.21783C6.52193 0.405944 7.44093 0 8.51829 0C9.59551 0 10.5128 0.405944 11.2702 1.21783C12.0277 2.02956 12.4064 3.01029 12.4064 4.16H11.2941C11.2941 3.33943 11.0226 2.63909 10.4796 2.05897C9.93668 1.47871 9.28128 1.18857 8.51337 1.18857C7.74545 1.18857 7.09005 1.47871 6.54717 2.05897C6.00414 2.63909 5.73262 3.33699 5.73262 4.15269C5.73262 4.79802 5.90431 5.36968 6.2477 5.86766C6.59094 6.36549 7.03515 6.72876 7.58032 6.95749L4.73882 11.643C4.75522 11.6489 4.77027 11.6636 4.78396 11.6871C4.79765 11.7106 4.80449 11.731 4.80449 11.7486C4.80449 12.0334 4.72278 12.2821 4.55936 12.4949C4.39594 12.7076 4.17383 12.8139 3.89305 12.8139Z",
          fill: ""
        })), /*#__PURE__*/React__default["default"].createElement("defs", null, /*#__PURE__*/React__default["default"].createElement("clipPath", {
          id: "clip0_26_46"
        }, /*#__PURE__*/React__default["default"].createElement("rect", {
          width: "16",
          height: "16",
          fill: "white"
        }))))
      }
    };
  });
  var XMarkIcon = /*#__PURE__*/createIconComponent("XMarkIcon", "oxygen-icon oxygen-icon-x-mark", function () {
    return {
      "16": {
        "width": 16,
        "path": /*#__PURE__*/React__default["default"].createElement("path", {
          fillRule: "evenodd",
          clipRule: "evenodd",
          d: "M5.17162 4.46432C4.97635 4.26906 4.65977 4.26906 4.46451 4.46432C4.26925 4.65958 4.26925 4.97616 4.46451 5.17142L7.2926 7.99951L4.46383 10.8283C4.26857 11.0235 4.26857 11.3401 4.46383 11.5354C4.65909 11.7306 4.97567 11.7306 5.17094 11.5354L7.9997 8.70662L10.8285 11.5354C11.0237 11.7306 11.3403 11.7306 11.5356 11.5354C11.7308 11.3401 11.7308 11.0235 11.5356 10.8283L8.70681 7.99951L11.5349 5.17142C11.7302 4.97616 11.7302 4.65958 11.5349 4.46432C11.3396 4.26906 11.0231 4.26906 10.8278 4.46432L7.9997 7.2924L5.17162 4.46432Z",
          fill: ""
        })
      }
    };
  });

  exports.AppleIcon = AppleIcon;
  exports.ArrowDownIcon = ArrowDownIcon;
  exports.ArrowLeftArrowRightIcon = ArrowLeftArrowRightIcon;
  exports.ArrowLeftIcon = ArrowLeftIcon;
  exports.ArrowLoopRightUserIcon = ArrowLoopRightUserIcon;
  exports.ArrowRightFromBracketIcon = ArrowRightFromBracketIcon;
  exports.ArrowRightIcon = ArrowRightIcon;
  exports.ArrowRightToBracketIcon = ArrowRightToBracketIcon;
  exports.ArrowRightToBracketPencilIcon = ArrowRightToBracketPencilIcon;
  exports.ArrowUpIcon = ArrowUpIcon;
  exports.ArrowUpRightFromSquareIcon = ArrowUpRightFromSquareIcon;
  exports.BanIcon = BanIcon;
  exports.BarsIcon = BarsIcon;
  exports.BoltIcon = BoltIcon;
  exports.BriefcaseBuildingIcon = BriefcaseBuildingIcon;
  exports.BriefcaseIcon = BriefcaseIcon;
  exports.BuildingAltIcon = BuildingAltIcon;
  exports.BuildingAsteriskIcon = BuildingAsteriskIcon;
  exports.BuildingCheckIcon = BuildingCheckIcon;
  exports.BuildingCircleCheckIcon = BuildingCircleCheckIcon;
  exports.BuildingGearIcon = BuildingGearIcon;
  exports.BuildingIcon = BuildingIcon;
  exports.BuildingPenIcon = BuildingPenIcon;
  exports.CalenderBoltIcon = CalenderBoltIcon;
  exports.CameraIcon = CameraIcon;
  exports.CheckIcon = CheckIcon;
  exports.ChevronDownIcon = ChevronDownIcon;
  exports.ChevronLeftIcon = ChevronLeftIcon;
  exports.ChevronRightIcon = ChevronRightIcon;
  exports.ChevronUpIcon = ChevronUpIcon;
  exports.ChevronsLeftIcon = ChevronsLeftIcon;
  exports.ChevronsRightIcon = ChevronsRightIcon;
  exports.CircleCheckFilledIcon = CircleCheckFilledIcon;
  exports.CircleDotIcon = CircleDotIcon;
  exports.CircleInfoFilledIcon = CircleInfoFilledIcon;
  exports.CircleInfoIcon = CircleInfoIcon;
  exports.CirclePlusRaysIcon = CirclePlusRaysIcon;
  exports.CircleStarIcon = CircleStarIcon;
  exports.CircleUserIcon = CircleUserIcon;
  exports.CirclesOverlapIcon = CirclesOverlapIcon;
  exports.ClockAsteriskIcon = ClockAsteriskIcon;
  exports.CloneIcon = CloneIcon;
  exports.CloudNodesIcon = CloudNodesIcon;
  exports.CommentLinesIcon = CommentLinesIcon;
  exports.CopyIcon = CopyIcon;
  exports.CrescentBrightIcon = CrescentBrightIcon;
  exports.DatabaseDocumentIcon = DatabaseDocumentIcon;
  exports.DatabaseIcon = DatabaseIcon;
  exports.DiamondIcon = DiamondIcon;
  exports.DiscordIcon = DiscordIcon;
  exports.DocumentCheckIcon = DocumentCheckIcon;
  exports.DocumentGearIcon = DocumentGearIcon;
  exports.DocumentIcon = DocumentIcon;
  exports.DocumentPenIcon = DocumentPenIcon;
  exports.DocumentPencilIcon = DocumentPencilIcon;
  exports.DownloadIcon = DownloadIcon;
  exports.DrawingPencilIcon = DrawingPencilIcon;
  exports.EclipseIcon = EclipseIcon;
  exports.EllipsisIcon = EllipsisIcon;
  exports.EllipsisVerticalIcon = EllipsisVerticalIcon;
  exports.EnvelopeAsteriskIcon = EnvelopeAsteriskIcon;
  exports.EnvelopeAtIcon = EnvelopeAtIcon;
  exports.EnvelopeGearIcon = EnvelopeGearIcon;
  exports.EnvelopeIcon = EnvelopeIcon;
  exports.EnvelopeLinkIcon = EnvelopeLinkIcon;
  exports.EnvelopeMagnifyingGlassIcon = EnvelopeMagnifyingGlassIcon;
  exports.EnvelopesIcon = EnvelopesIcon;
  exports.EyeIcon = EyeIcon;
  exports.EyeSlashIcon = EyeSlashIcon;
  exports.GearIcon = GearIcon;
  exports.GithubIcon = GithubIcon;
  exports.GlobeIcon = GlobeIcon;
  exports.GridDotsVerticalIcon = GridDotsVerticalIcon;
  exports.HexagonTwoIcon = HexagonTwoIcon;
  exports.HierarchyIcon = HierarchyIcon;
  exports.HomeContainedIcon = HomeContainedIcon;
  exports.HomeFilledIcon = HomeFilledIcon;
  exports.HomeIcon = HomeIcon;
  exports.HorizontalBarsFilterIcon = HorizontalBarsFilterIcon;
  exports.KeyFlowIcon = KeyFlowIcon;
  exports.LanguageIcon = LanguageIcon;
  exports.LightbulbOnIcon = LightbulbOnIcon;
  exports.LinearNodesIcon = LinearNodesIcon;
  exports.LinkIcon = LinkIcon;
  exports.LogsDocumentIcon = LogsDocumentIcon;
  exports.MagnifyingGlassIcon = MagnifyingGlassIcon;
  exports.MessageAsteriskIcon = MessageAsteriskIcon;
  exports.MinusIcon = MinusIcon;
  exports.NodesIcon = NodesIcon;
  exports.PadlockAsteriskFlowIcon = PadlockAsteriskFlowIcon;
  exports.PadlockAsteriskIcon = PadlockAsteriskIcon;
  exports.PaletteIcon = PaletteIcon;
  exports.PenToCircleIcon = PenToCircleIcon;
  exports.PenToSquareIcon = PenToSquareIcon;
  exports.PlusIcon = PlusIcon;
  exports.ProfileFlowIcon = ProfileFlowIcon;
  exports.ProgressFlowIcon = ProgressFlowIcon;
  exports.ReceiptIcon = ReceiptIcon;
  exports.RectangleLineIcon = RectangleLineIcon;
  exports.ShareNodesIcon = ShareNodesIcon;
  exports.ShieldCheckIcon = ShieldCheckIcon;
  exports.ShieldSquareCheckIcon = ShieldSquareCheckIcon;
  exports.ShieldUserIcon = ShieldUserIcon;
  exports.ShieldUserPencilIcon = ShieldUserPencilIcon;
  exports.SquareMagnifyingGlassIcon = SquareMagnifyingGlassIcon;
  exports.SquarePlusIcon = SquarePlusIcon;
  exports.SquareUserIcon = SquareUserIcon;
  exports.StackOverflowIcon = StackOverflowIcon;
  exports.StarIcon = StarIcon;
  exports.SunContrastIcon = SunContrastIcon;
  exports.SunIcon = SunIcon;
  exports.TalkingHeadsetIcon = TalkingHeadsetIcon;
  exports.TilesIcon = TilesIcon;
  exports.TrashIcon = TrashIcon;
  exports.UserAsteriskIcon = UserAsteriskIcon;
  exports.UserBannerIcon = UserBannerIcon;
  exports.UserBriefcaseIcon = UserBriefcaseIcon;
  exports.UserCircleDotIcon = UserCircleDotIcon;
  exports.UserDatabaseIcon = UserDatabaseIcon;
  exports.UserDocumentIcon = UserDocumentIcon;
  exports.UserFlowIcon = UserFlowIcon;
  exports.UserGearIcon = UserGearIcon;
  exports.UserGroupIcon = UserGroupIcon;
  exports.UserIcon = UserIcon;
  exports.UserKeyIcon = UserKeyIcon;
  exports.UserPencilIcon = UserPencilIcon;
  exports.UserPlusIcon = UserPlusIcon;
  exports.UsersIcon = UsersIcon;
  exports.VerticleFilterBarsIcon = VerticleFilterBarsIcon;
  exports.WebhookIcon = WebhookIcon;
  exports.XMarkIcon = XMarkIcon;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
